@@ -20,19 +20,19 @@ TestDecorator::~TestDecorator()
 }
 
 
-int TestDecorator::countTestCases()
+int TestDecorator::countTestCases() const
 {
 	return _test->countTestCases();
 }
 
 
-void TestDecorator::run(TestResult* result)
+void TestDecorator::run(TestResult* result, const Test::Callback& callback)
 {
 	_test->run(result);
-} 
+}
 
 
-std::string TestDecorator::toString()
+std::string TestDecorator::toString() const
 {
 	return _test->toString();
 }
