@@ -22,20 +22,25 @@
 #include "Poco/Crypto/Crypto.h"
 #include "Poco/Crypto/CryptoException.h"
 #include "Poco/StreamCopier.h"
+#include "Poco/Format.h"
 #include <openssl/ec.h>
 #include <openssl/rsa.h>
 #include <openssl/evp.h>
 #include <openssl/pem.h>
 #include <sstream>
 #include <typeinfo>
+#include <map>
 
 
 namespace Poco {
 namespace Crypto {
 
-
+//@deprecated
 class ECKey;
+//@deprecated
 class RSAKey;
+class PKCS12Container;
+class X509Certificate;
 
 
 class Crypto_API EVPPKey
@@ -55,10 +60,40 @@ public:
 		/// Only EC keys can be wrapped by an EVPPKey
 		/// created using this constructor.
 
+	EVPPKey(const X509Certificate& cert);
+		/// Constructs EVPPKey from the given certificate.
+
+	EVPPKey(const PKCS12Container& cert);
+		/// Constructs EVPPKey from the given container.
+
+#if OPENSSL_VERSION_NUMBER >= 0x10000000L
+
+	EVPPKey(int type, int param);
+		/// Creates the EVPPKey.
+		/// Creates a new public/private keypair using the given parameters.
+		/// Can be used to sign data and verify signatures.
+		///
+		/// Suported types:
+		///   - EVP_PKEY_RSA
+		///   - EVP_PKEY_EC
+		///
+		/// Parameters:
+		///   - for EVP_PKEY_RSA: key length in bits
+		///   - for EVP_PKEY_EC: curve NID
+		///
+		/// This constructor is not available for OpenSSL version < 1.0.0
+
+#endif // OPENSSL_VERSION_NUMBER >= 0x10000000L
+
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+	explicit EVPPKey(const std::vector<unsigned char>* publicKey, const std::vector<unsigned char>* privateKey, unsigned long exponent, int type);
+#endif
+	
 	explicit EVPPKey(EVP_PKEY* pEVPPKey);
 		/// Constructs EVPPKey from EVP_PKEY pointer.
 		/// The content behind the supplied pointer is internally duplicated.
 
+	//@ deprecated
 	template<typename K>
 	explicit EVPPKey(K* pKey): _pEVPPKey(EVP_PKEY_new())
 		/// Constructs EVPPKey from a "native" OpenSSL (RSA or EC_KEY),
@@ -124,6 +159,9 @@ public:
 	int type() const;
 		/// Retuns the EVPPKey type NID.
 
+	const std::string& name() const;
+		/// Retuns the EVPPKey name.
+
 	bool isSupported(int type) const;
 		/// Returns true if OpenSSL type is supported
 
@@ -135,19 +173,27 @@ public:
 
 	static EVP_PKEY* duplicate(const EVP_PKEY* pFromKey, EVP_PKEY** pToKey);
 		/// Duplicates pFromKey into *pToKey and returns
-		// the pointer to duplicated EVP_PKEY.
+		/// the pointer to duplicated EVP_PKEY.
 
 private:
 	EVPPKey();
-
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L	
+	void setKeyFromParameters(OSSL_PARAM* parameters);
+#endif
 	static int type(const EVP_PKEY* pEVPPKey);
+	void checkType();
 	void newECKey(const char* group);
 	void duplicate(EVP_PKEY* pEVPPKey);
 
+	//@ deprecated
 	void setKey(ECKey* pKey);
+	//@ deprecated
 	void setKey(RSAKey* pKey);
+	//@ deprecated
 	void setKey(EC_KEY* pKey);
+	//@ deprecated
 	void setKey(RSA* pKey);
+
 	static int passCB(char* buf, int size, int, void* pass);
 
 	typedef EVP_PKEY* (*PEM_read_FILE_Key_fn)(FILE*, EVP_PKEY**, pem_password_cb*, void*);
@@ -180,7 +226,7 @@ private:
 #if defined(_MSC_VER)
 #pragma warning(push)
 #pragma warning(disable:4996) // deprecation warnings
-#endif				
+#endif
 				pFile = fopen(keyFile.c_str(), "r");
 #if defined(_MSC_VER)
 #pragma warning(pop)
@@ -211,8 +257,10 @@ private:
 				}
 				else
 				{
+					std::string msg = Poco::format("EVPPKey::loadKey('%s')\n", keyFile);
+					getError(msg);
 					if (getFunc) EVP_PKEY_free(pKey);
-					throw IOException("ECKeyImpl, cannot open file", keyFile);
+					throw IOException(msg);
 				}
 			}
 			else goto error;
@@ -220,8 +268,10 @@ private:
 		return false;
 
 	error:
+		std::string msg = Poco::format("EVPPKey::loadKey('%s')\n", keyFile);
+		getError(msg);
 		if (pFile) fclose(pFile);
-		throw OpenSSLException("EVPKey::loadKey(string)");
+		throw OpenSSLException(msg);
 	}
 
 	template <typename K, typename F>
@@ -277,13 +327,18 @@ private:
 		return false;
 
 	error:
+		std::string msg = "EVPPKey::loadKey(istream)\n";
+		getError(msg);
 		if (pBIO) BIO_free(pBIO);
-		throw OpenSSLException("EVPKey::loadKey(stream)");
+		throw OpenSSLException(msg);
 	}
 
-	EVP_PKEY* _pEVPPKey;
+	EVP_PKEY* _pEVPPKey = 0;
+	static const std::map<int, std::string> KNOWN_TYPES;
 
+	//@deprecated
 	friend class ECKeyImpl;
+	//@deprecated
 	friend class RSAKeyImpl;
 };
 
@@ -297,7 +352,11 @@ inline bool EVPPKey::operator == (const EVPPKey& other) const
 {
 	poco_check_ptr (other._pEVPPKey);
 	poco_check_ptr (_pEVPPKey);
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+	return (1 == EVP_PKEY_eq(_pEVPPKey, other._pEVPPKey));
+#else
 	return (1 == EVP_PKEY_cmp(_pEVPPKey, other._pEVPPKey));
+#endif
 }
 
 
@@ -311,7 +370,7 @@ inline int EVPPKey::type(const EVP_PKEY* pEVPPKey)
 {
 	if (!pEVPPKey) return NID_undef;
 
-	return EVP_PKEY_type(EVP_PKEY_id(pEVPPKey));
+	return EVP_PKEY_type(EVP_PKEY_base_id(pEVPPKey));
 }
 
 
@@ -339,20 +398,6 @@ inline EVPPKey::operator EVP_PKEY*()
 }
 
 
-inline void EVPPKey::setKey(EC_KEY* pKey)
-{
-	if (!EVP_PKEY_set1_EC_KEY(_pEVPPKey, pKey))
-		throw OpenSSLException();
-}
-
-
-inline void EVPPKey::setKey(RSA* pKey)
-{
-	if (!EVP_PKEY_set1_RSA(_pEVPPKey, pKey))
-		throw OpenSSLException();
-}
-
-
 } } // namespace Poco::Crypto
 
 
