@@ -21,6 +21,7 @@
 #include "EVPTest.h"
 #include "DigestEngineTest.h"
 #include "PKCS12ContainerTest.h"
+#include "EnvelopeTest.h"
 
 
 CppUnit::Test* CryptoTestSuite::suite()
@@ -33,5 +34,6 @@ CppUnit::Test* CryptoTestSuite::suite()
 	pSuite->addTest(EVPTest::suite());
 	pSuite->addTest(DigestEngineTest::suite());
 	pSuite->addTest(PKCS12ContainerTest::suite());
+	pSuite->addTest(EnvelopeTest::suite());
 	return pSuite;
 }
