@@ -13,6 +13,7 @@
 #include "CppUnit/TestRunner.h"
 #include "CryptoTestSuite.h"
 #include "Poco/Crypto/Crypto.h"
+#include "Poco/Exception.h"
 
 
 class CryptoInitializer
@@ -22,7 +23,7 @@ public:
 	{
 		Poco::Crypto::initializeCrypto();
 	}
-	
+
 	~CryptoInitializer()
 	{
 		Poco::Crypto::uninitializeCrypto();
@@ -33,11 +34,12 @@ public:
 int main(int ac, char **av)
 {
 	CryptoInitializer ci;
-	
+
 	std::vector<std::string> args;
 	for (int i = 0; i < ac; ++i)
 		args.push_back(std::string(av[i]));
 	CppUnit::TestRunner runner;
 	runner.addTest("CryptoTestSuite", CryptoTestSuite::suite());
-	return runner.run(args) ? 0 : 1;
+	CppUnitPocoExceptionText (exc);
+	return runner.run(args, exc) ? 0 : 1;
 }
