@@ -153,14 +153,14 @@ void SessionHandle::close()
 
 void SessionHandle::startTransaction()
 {
-	int rc = mysql_autocommit(_pHandle, false);
+	int rc = mysql_query(_pHandle, "BEGIN");
 	if (rc != 0)
 	{
 		// retry if connection lost
 		int err = mysql_errno(_pHandle);
 		if (err == 2006 /* CR_SERVER_GONE_ERROR */ || err == 2013 /* CR_SERVER_LOST */)
 		{
-			rc = mysql_autocommit(_pHandle, false);
+			rc = mysql_query(_pHandle, "BEGIN");
 		}
 	}
 	if (rc != 0) throw TransactionException("Start transaction failed.", _pHandle);
@@ -181,6 +181,13 @@ void SessionHandle::rollback()
 }
 
 
+void SessionHandle::autoCommit(bool val)
+{
+	if (mysql_autocommit(_pHandle, val) != 0)
+		throw TransactionException("Setting autocommit mode failed.", _pHandle);
+}
+
+
 void SessionHandle::reset()
 {
 #if ((defined (MYSQL_VERSION_ID)) && (MYSQL_VERSION_ID >= 50700)) || ((defined (MARIADB_PACKAGE_VERSION_ID)) && (MARIADB_PACKAGE_VERSION_ID >= 30000))
