@@ -83,6 +83,12 @@ public:
 	void dateTime();
 	void date();
 	void time();
+	void timestamp();
+	void longBlob();
+	void longText();
+#ifdef POCO_MYSQL_JSON
+	void json();
+#endif
 	void unsignedInts();
 	void floats();
 	void doubles();
@@ -97,6 +103,7 @@ public:
 	void transaction(const std::string& connect);
 
 	void reconnect();
+	void sessionPoolAndUnicode(const std::string& connString);
 
 private:
 	void setTransactionIsolation(Poco::Data::Session& session, Poco::UInt32 ti);
