@@ -44,7 +44,7 @@ using Poco::DateTime;
 	#define POSTGRESQL_DSN "PocoDataPgSQLTestW"
 #else
 	#ifdef POCO_PTR_IS_64_BIT
-		#define POSTGRESQL_ODBC_DRIVER "PostgreSQL ANSI(x64)"
+		#define POSTGRESQL_ODBC_DRIVER "PostgreSQL ANSI"
 	#else
 		#define POSTGRESQL_ODBC_DRIVER "PostgreSQL ANSI"
 	#endif
@@ -59,8 +59,8 @@ using Poco::DateTime;
 #define POSTGRESQL_PORT    "5432"
 #define POSTGRESQL_DB      "postgres"
 #define POSTGRESQL_UID     "postgres"
-#define POSTGRESQL_PWD     "poco"
-#define POSTGRESQL_VERSION "10"
+#define POSTGRESQL_PWD     "postgres"
+#define POSTGRESQL_VERSION "16"
 
 #ifdef POCO_OS_FAMILY_WINDOWS
 const std::string ODBCPostgreSQLTest::_libDir = "C:\\\\Program Files\\\\PostgreSQL\\\\pg" POSTGRESQL_VERSION "\\\\lib\\\\";
@@ -75,7 +75,7 @@ std::string          ODBCPostgreSQLTest::_driver = POSTGRESQL_ODBC_DRIVER;
 std::string          ODBCPostgreSQLTest::_dsn = POSTGRESQL_DSN;
 std::string          ODBCPostgreSQLTest::_uid = POSTGRESQL_UID;
 std::string          ODBCPostgreSQLTest::_pwd = POSTGRESQL_PWD;
-std::string ODBCPostgreSQLTest::_connectString = 
+std::string ODBCPostgreSQLTest::_connectString =
 	"DRIVER=" POSTGRESQL_ODBC_DRIVER ";"
 	"DATABASE=" POSTGRESQL_DB ";"
 	"SERVER=" POSTGRESQL_SERVER ";"
@@ -114,7 +114,7 @@ std::string ODBCPostgreSQLTest::_connectString =
 	"ReadOnly=0;";
 
 
-ODBCPostgreSQLTest::ODBCPostgreSQLTest(const std::string& name): 
+ODBCPostgreSQLTest::ODBCPostgreSQLTest(const std::string& name):
 	ODBCTest(name, _pSession, _pExecutor, _dsn, _uid, _pwd, _connectString)
 {
 }
@@ -179,7 +179,7 @@ void ODBCPostgreSQLTest::testBLOB()
 		executor().blob(maxFldSize);
 		fail ("must fail");
 	}
-	catch (DataException&) 
+	catch (DataException&)
 	{
 		session().setProperty("maxFieldSize", Poco::Any(maxFldSize));
 	}
@@ -207,7 +207,7 @@ void ODBCPostgreSQLTest::testStoredFunction()
 		session().setFeature("autoExtract", bindValue(k+1));
 
 		dropObject("FUNCTION", "storedFunction()");
-		try 
+		try
 		{
 			session() << "CREATE FUNCTION storedFunction() RETURNS INTEGER AS '"
 				"BEGIN "
@@ -223,7 +223,7 @@ void ODBCPostgreSQLTest::testStoredFunction()
 		assertTrue (-1 == i);
 		dropObject("FUNCTION", "storedFunction()");
 
-		try 
+		try
 		{
 			session() << "CREATE FUNCTION storedFunction(INTEGER) RETURNS INTEGER AS '"
 				"BEGIN "
@@ -241,7 +241,7 @@ void ODBCPostgreSQLTest::testStoredFunction()
 		dropObject("FUNCTION", "storedFunction(INTEGER)");
 
 		dropObject("FUNCTION", "storedFunction(TIMESTAMP)");
-		try 
+		try
 		{
 			session() << "CREATE FUNCTION storedFunction(TIMESTAMP) RETURNS TIMESTAMP AS '"
 				"BEGIN "
@@ -259,23 +259,23 @@ void ODBCPostgreSQLTest::testStoredFunction()
 		dropObject("FUNCTION", "storedFunction(TIMESTAMP)");
 
 		dropObject("FUNCTION", "storedFunction(TEXT, TEXT)");
-		try 
+		try
 		{
 			session() << "CREATE FUNCTION storedFunction(TEXT,TEXT) RETURNS TEXT AS '"
 				"BEGIN "
 				" RETURN $1 || '', '' || $2 || ''!'';"
 				"END;'"
-				"LANGUAGE 'plpgsql'" , now; 
+				"LANGUAGE 'plpgsql'" , now;
 		}
 		catch(ConnectionException& ce){ std::cout << ce.toString() << std::endl; fail (func); }
 		catch(StatementException& se){ std::cout << se.toString() << std::endl; fail (func); }
-		
+
 		std::string param1 = "Hello";
 		std::string param2 = "world";
 		std::string ret;
-		try 
+		try
 		{
-			session() << "{? = call storedFunction(?,?)}", out(ret), in(param1), in(param2), now; 
+			session() << "{? = call storedFunction(?,?)}", out(ret), in(param1), in(param2), now;
 		}
 		catch(ConnectionException& ce){ std::cout << ce.toString() << std::endl; fail (func); }
 		catch(StatementException& se){ std::cout << se.toString() << std::endl; fail (func); }
@@ -346,13 +346,13 @@ void ODBCPostgreSQLTest::configurePLPgSQL()
 			"RETURNS OPAQUE "
 			"AS '%splpgsql.dll' "
 			"LANGUAGE 'C';", _libDir), now;
-		
+
 		session() << "CREATE LANGUAGE 'plpgsql' "
 			"HANDLER plpgsql_call_handler "
 			"LANCOMPILER 'PL/pgSQL'", now;
 
-	}catch(StatementException& ex) 
-	{  
+	}catch(StatementException& ex)
+	{
 		if (1 != ex.diagnostics().nativeError(0))
 			throw;
 	}
@@ -522,15 +522,15 @@ void ODBCPostgreSQLTest::recreateBoolTable()
 void ODBCPostgreSQLTest::recreateMiscTable()
 {
 	dropObject("TABLE", "MiscTest");
-	try 
-	{ 
+	try
+	{
 		// Mammoth does not bind columns properly
 		session() << "CREATE TABLE MiscTest "
 			"(First VARCHAR(30),"
 			"Second BYTEA,"
 			"Third INTEGER,"
 			"Fourth FLOAT,"
-			"Fifth TIMESTAMP)", now; 
+			"Fifth TIMESTAMP)", now;
 	} catch(ConnectionException& ce){ std::cout << ce.toString() << std::endl; fail ("recreateMiscTable()"); }
 	catch(StatementException& se){ std::cout << se.toString() << std::endl; fail ("recreateMiscTable()"); }
 }
@@ -541,20 +541,20 @@ void ODBCPostgreSQLTest::recreateLogTable()
 	dropObject("TABLE", "T_POCO_LOG");
 	dropObject("TABLE", "T_POCO_LOG_ARCHIVE");
 
-	try 
-	{ 
+	try
+	{
 		std::string sql = "CREATE TABLE %s "
 			"(Source VARCHAR,"
 			"Name VARCHAR,"
 			"ProcessId INTEGER,"
 			"Thread VARCHAR, "
-			"ThreadId INTEGER," 
+			"ThreadId INTEGER,"
 			"Priority INTEGER,"
 			"Text VARCHAR,"
-			"DateTime TIMESTAMP)"; 
+			"DateTime TIMESTAMP)";
 
-		session() << sql, "T_POCO_LOG", now; 
-		session() << sql, "T_POCO_LOG_ARCHIVE", now; 
+		session() << sql, "T_POCO_LOG", now;
+		session() << sql, "T_POCO_LOG_ARCHIVE", now;
 
 	} catch(ConnectionException& ce){ std::cout << ce.toString() << std::endl; fail ("recreateLogTable()"); }
 	catch(StatementException& se){ std::cout << se.toString() << std::endl; fail ("recreateLogTable()"); }
@@ -583,6 +583,9 @@ CppUnit::Test* ODBCPostgreSQLTest::suite()
 		CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("ODBCPostgreSQLTest");
 
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testBareboneODBC);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testConnection);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSession);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSessionPool);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testZeroRows);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSimpleAccess);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testComplexType);
@@ -668,6 +671,9 @@ CppUnit::Test* ODBCPostgreSQLTest::suite()
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testMultipleResults);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSQLChannel);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSQLLogger);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testAutoCommit);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSessionTransactionNoAutoCommit);
+		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testTransactionIsolation);
 		CppUnit_addTest(pSuite, ODBCPostgreSQLTest, testSessionTransaction);
 		// (postgres bug?)
 		// local session claims to be capable of reading uncommitted changes,
