@@ -140,6 +140,32 @@ void PostgreSQLTest::testConnectNoDB()
 	}
 }
 
+
+void PostgreSQLTest::testFailedConnect()
+{
+	std::string dbConnString;
+	dbConnString +=  "host=" + getHost();
+	dbConnString += " user=invalid";
+	dbConnString +=	" password=invalid";
+	dbConnString += " port=" + getPort();
+
+	try
+	{
+		std::cout << "Attempting to Connect to [" << dbConnString << "] with invalid credentials: " << std::endl;
+		Session session(PostgreSQL::Connector::KEY, dbConnString);
+		fail ("must fail");
+	}
+	catch (ConnectionFailedException& ex)
+	{
+		std::cout  << ex.displayText() << std::endl;
+	}
+	catch (ConnectionException& ex)
+	{
+		std::cout << ex.displayText() << std::endl;
+	}
+}
+
+
 void PostgreSQLTest::testPostgreSQLOIDs()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -309,6 +335,7 @@ void PostgreSQLTest::testBarebonePostgreSQL()
 }
 
 
+
 void PostgreSQLTest::testSimpleAccess()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -647,6 +674,7 @@ void PostgreSQLTest::testBLOB()
 	catch (DataException&) { }
 }
 
+
 void PostgreSQLTest::testCLOBStmt()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -655,6 +683,7 @@ void PostgreSQLTest::testCLOBStmt()
 	_pExecutor->clobStmt();
 }
 
+
 void PostgreSQLTest::testBLOBStmt()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -663,6 +692,7 @@ void PostgreSQLTest::testBLOBStmt()
 	_pExecutor->blobStmt();
 }
 
+
 void PostgreSQLTest::testUnsignedInts()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -698,6 +728,7 @@ void PostgreSQLTest::testUUID()
 	_pExecutor->uuids();
 }
 
+
 void PostgreSQLTest::testTuple()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -743,6 +774,15 @@ void PostgreSQLTest::testSessionTransaction()
 }
 
 
+void PostgreSQLTest::testSessionTransactionNoAutoCommit()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	recreatePersonTable();
+	_pExecutor->sessionTransactionNoAutoCommit(_dbConnString);
+}
+
+
 void PostgreSQLTest::testTransaction()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -761,6 +801,20 @@ void PostgreSQLTest::testReconnect()
 }
 
 
+void PostgreSQLTest::testSqlState()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	try
+	{
+		*_pSession << "syntax error", now;
+	}
+	catch (const Poco::Data::PostgreSQL::PostgreSQLException & exception)
+	{
+		assertTrue(exception.sqlState() == std::string("42601"));
+	}
+}
+
 void PostgreSQLTest::testNullableInt()
 {
 	if (!_pSession) fail ("Test not available.");
@@ -888,10 +942,133 @@ void PostgreSQLTest::testTupleWithNullable()
 
 	assertTrue (result[5].get<1>() == std::string("B"));
 	assertTrue (result[5].get<2>() == null);
-
 }
 
 
+void PostgreSQLTest::testBinarySimpleAccess()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonTable();
+	_pExecutor->simpleAccess();
+}
+
+
+void PostgreSQLTest::testBinaryComplexType()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonTable();
+	_pExecutor->complexType();
+}
+
+
+void PostgreSQLTest::testBinarySimpleAccessVector()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonTable();
+	_pExecutor->simpleAccessVector();
+}
+
+
+void PostgreSQLTest::testBinaryComplexTypeVector()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonTable();
+	_pExecutor->complexTypeVector();
+}
+
+
+void PostgreSQLTest::testBinaryInts()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreateUnsignedIntsTable();
+	_pExecutor->unsignedInts();
+}
+
+
+void PostgreSQLTest::testBinaryFloat()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreateFloatsTable();
+	_pExecutor->floats();
+}
+
+
+void PostgreSQLTest::testBinaryDouble()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreateFloatsTable();
+	_pExecutor->doubles();
+}
+
+
+void PostgreSQLTest::testBinaryUUID()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreateUUIDsTable();
+	_pExecutor->uuids();
+}
+
+
+void PostgreSQLTest::testBinaryDateTime()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonDateTimeTable();
+	_pExecutor->dateTime();
+	recreatePersonDateTable();
+	_pExecutor->date();
+	recreatePersonTimeTable();
+	_pExecutor->time();
+}
+
+
+void PostgreSQLTest::testBinaryCLOBStmt()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonCLOBTable();
+	_pExecutor->clobStmt();
+}
+
+
+void PostgreSQLTest::testBinaryBLOBStmt()
+{
+	if (!_pSession) fail ("Test not available.");
+
+	_pSession->setFeature("binaryExtraction", true);
+
+	recreatePersonBLOBTable();
+	_pExecutor->blobStmt();
+}
+
 void PostgreSQLTest::dropTable(const std::string& tableName)
 {
 	try
@@ -994,6 +1171,14 @@ void PostgreSQLTest::recreateFloatsTable()
 }
 
 
+void PostgreSQLTest::recreateDoublesTable()
+{
+	dropTable("Strings");
+	try { *_pSession << "CREATE TABLE Strings (str DOUBLE)", now; }
+	catch(ConnectionException& ce){ std::cout << ce.displayText() << std::endl; fail ("recreateDoublesTable()"); }
+	catch(StatementException& se){ std::cout << se.displayText() << std::endl; fail ("recreateDoublesTable()"); }
+}
+
 void PostgreSQLTest::recreateUUIDsTable()
 {
 	dropTable("Strings");
@@ -1055,6 +1240,7 @@ void PostgreSQLTest::tearDown()
 {
 	dropTable("Person");
 	dropTable("Strings");
+	_pSession->setFeature("binaryExtraction", false);
 }
 
 
@@ -1086,6 +1272,7 @@ CppUnit::Test* PostgreSQLTest::suite()
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("PostgreSQLTest");
 
 	CppUnit_addTest(pSuite, PostgreSQLTest, testConnectNoDB);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testFailedConnect);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testPostgreSQLOIDs);
 	//CppUnit_addTest(pSuite, PostgreSQLTest, testBarebonePostgreSQL);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testSimpleAccess);
@@ -1135,7 +1322,22 @@ CppUnit::Test* PostgreSQLTest::suite()
 	CppUnit_addTest(pSuite, PostgreSQLTest, testNullableInt);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testNullableString);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testTupleWithNullable);
+        CppUnit_addTest(pSuite, PostgreSQLTest, testSqlState);
+
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinarySimpleAccess);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryComplexType);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinarySimpleAccessVector);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryComplexTypeVector);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryInts);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryFloat);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryDouble);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryUUID);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryDateTime);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryCLOBStmt);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryBLOBStmt);
+
 	CppUnit_addTest(pSuite, PostgreSQLTest, testSessionTransaction);
+	CppUnit_addTest(pSuite, PostgreSQLTest, testSessionTransactionNoAutoCommit);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testTransaction);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testReconnect);
 
