@@ -40,6 +40,8 @@ namespace SQLite {
 
 
 const std::string SessionImpl::DEFERRED_BEGIN_TRANSACTION("BEGIN DEFERRED");
+const std::string SessionImpl::EXCLUSIVE_BEGIN_TRANSACTION("BEGIN EXCLUSIVE");
+const std::string SessionImpl::IMMEDIATE_BEGIN_TRANSACTION("BEGIN IMMEDIATE");
 const std::string SessionImpl::COMMIT_TRANSACTION("COMMIT");
 const std::string SessionImpl::ABORT_TRANSACTION("ROLLBACK");
 
@@ -49,7 +51,8 @@ SessionImpl::SessionImpl(const std::string& fileName, std::size_t loginTimeout):
 	_connector(Connector::KEY),
 	_pDB(0),
 	_connected(false),
-	_isTransaction(false)
+	_isTransaction(false),
+	_transactionType(TransactionType::DEFERRED)
 {
 	open();
 	setConnectionTimeout(loginTimeout);
@@ -58,6 +61,7 @@ SessionImpl::SessionImpl(const std::string& fileName, std::size_t loginTimeout):
 		&SessionImpl::autoCommit,
 		&SessionImpl::isAutoCommit);
 	addProperty("connectionTimeout", &SessionImpl::setConnectionTimeout, &SessionImpl::getConnectionTimeout);
+	addProperty(Utility::TRANSACTION_TYPE_PROPERTY_KEY, &SessionImpl::setTransactionType, &SessionImpl::getTransactionType);
 }
 
 
@@ -85,7 +89,18 @@ void SessionImpl::begin()
 {
 	Poco::Mutex::ScopedLock l(_mutex);
 	SQLiteStatementImpl tmp(*this, _pDB);
-	tmp.add(DEFERRED_BEGIN_TRANSACTION);
+	switch (_transactionType)
+	{
+	case TransactionType::DEFERRED:
+		tmp.add(DEFERRED_BEGIN_TRANSACTION);
+		break;
+	case TransactionType::EXCLUSIVE:
+		tmp.add(EXCLUSIVE_BEGIN_TRANSACTION);
+		break;
+	case TransactionType::IMMEDIATE:
+		tmp.add(IMMEDIATE_BEGIN_TRANSACTION);
+		break;
+	}
 	tmp.execute();
 	_isTransaction = true;
 }
@@ -161,6 +176,8 @@ void SessionImpl::open(const std::string& connect)
 			rc = sqlite3_open_v2(connectionString().c_str(), &_pDB,
 				SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE | SQLITE_OPEN_URI, NULL);
 			if (rc == SQLITE_OK) break;
+			if (!_pDB)
+				throw ConnectionFailedException(std::string(sqlite3_errstr(rc)));
 			if (sw.elapsedSeconds() >= tout)
 			{
 				Utility::throwException(_pDB, rc);
@@ -223,14 +240,23 @@ Poco::Any SessionImpl::getConnectionTimeout(const std::string& prop) const
 	return Poco::Any(_timeout/1000);
 }
 
+void SessionImpl::setTransactionType(TransactionType transactionType) 
+{
+	_transactionType = transactionType;
+}
+
+void SessionImpl::setTransactionType(const std::string &prop, const Poco::Any& value) 
+{
+	setTransactionType(Poco::RefAnyCast<TransactionType>(value));
+}
+
+Poco::Any SessionImpl::getTransactionType(const std::string& prop) const 
+{
+	return Poco::Any(_transactionType);
+}
 
 void SessionImpl::autoCommit(const std::string&, bool)
 {
-	// The problem here is to decide whether to call commit or rollback
-	// when autocommit is set to true. Hence, it is best not to implement
-	// this explicit call and only implicitly support autocommit setting.
-	throw NotImplementedException(
-		"SQLite autocommit is implicit with begin/commit/rollback.");
 }
 
 
