@@ -36,9 +36,9 @@ class Data_API ArchiveStrategy
 public:
 	static const std::string DEFAULT_ARCHIVE_DESTINATION;
 
-	ArchiveStrategy(const std::string& connector, 
-		const std::string& connect, 
-		const std::string& source, 
+	ArchiveStrategy(const std::string& connector,
+		const std::string& connect,
+		const std::string& source,
 		const std::string& destination = DEFAULT_ARCHIVE_DESTINATION);
 		/// Creates archive strategy.
 
@@ -83,7 +83,7 @@ protected:
 	Statement& getDeleteStatement();
 	Statement& getCountStatement();
 private:
-	
+
 	ArchiveStrategy();
 	ArchiveStrategy(const ArchiveStrategy&);
 	ArchiveStrategy& operator = (const ArchiveStrategy&);
@@ -177,11 +177,12 @@ class Data_API ArchiveByAgeStrategy: public ArchiveStrategy
 	/// Archives rows scheduled for archiving.
 {
 public:
-	ArchiveByAgeStrategy(const std::string& connector, 
-		const std::string& connect, 
-		const std::string& sourceTable, 
-		const std::string& destinationTable = DEFAULT_ARCHIVE_DESTINATION);
-	
+	ArchiveByAgeStrategy(const std::string& connector,
+		const std::string& connect,
+		const std::string& sourceTable,
+		const std::string& destinationTable = DEFAULT_ARCHIVE_DESTINATION,
+		const std::string& age = "");
+
 	~ArchiveByAgeStrategy();
 
 	void archive();
