@@ -26,7 +26,7 @@ namespace Data {
 const std::size_t RowIterator::POSITION_END = std::numeric_limits<std::size_t>::max();
 
 
-RowIterator::RowIterator(RecordSet* pRecordSet, bool positionEnd): 
+RowIterator::RowIterator(RecordSet* pRecordSet, bool positionEnd):
 	_pRecordSet(pRecordSet),
 	_position(positionEnd ? POSITION_END : 0)
 {
@@ -67,10 +67,10 @@ RowIterator& RowIterator::operator = (RowIterator&& other) noexcept
 }
 
 
-void RowIterator::swap(RowIterator& other)
+void RowIterator::swap(RowIterator& other) noexcept
 {
 	using std::swap;
-	
+
 	swap(_pRecordSet, other._pRecordSet);
 	swap(_position, other._position);
 }
