@@ -20,7 +20,7 @@ namespace Poco {
 namespace Data {
 
 
-SessionImpl::SessionImpl(const std::string& connectionString, std::size_t timeout): 
+SessionImpl::SessionImpl(const std::string& connectionString, std::size_t timeout):
 	_connectionString(connectionString),
 	_loginTimeout(timeout)
 {
@@ -49,4 +49,10 @@ void SessionImpl::setConnectionString(const std::string& connectionString)
 }
 
 
+bool SessionImpl::isGood() const
+{
+	return isConnected();
+}
+
+
 } } // namespace Poco::Data
