@@ -9,6 +9,7 @@
 
 
 #include "DataTest.h"
+#include "Extractor.h"
 #include "CppUnit/TestCaller.h"
 #include "CppUnit/TestSuite.h"
 #include "Poco/Data/Session.h"
@@ -20,6 +21,7 @@
 #include "Poco/Data/Date.h"
 #include "Poco/Data/Time.h"
 #include "Poco/Data/SimpleRowFormatter.h"
+#include "Poco/Data/JSONRowFormatter.h"
 #include "Poco/Data/DataException.h"
 #include "Connector.h"
 #include "Poco/BinaryReader.h"
@@ -29,6 +31,7 @@
 #include "Poco/Dynamic/Var.h"
 #include "Poco/Data/DynamicLOB.h"
 #include "Poco/Data/DynamicDateTime.h"
+#include "Poco/Latin1Encoding.h"
 #include "Poco/Exception.h"
 #include <cstring>
 #include <sstream>
@@ -36,6 +39,8 @@
 #include <set>
 
 
+using namespace Poco;
+using namespace Poco::Data;
 using namespace Poco::Data::Keywords;
 
 
@@ -45,6 +50,7 @@ using Poco::UInt32;
 using Poco::Int64;
 using Poco::UInt64;
 using Poco::DateTime;
+using Poco::Latin1Encoding;
 using Poco::Dynamic::Var;
 using Poco::InvalidAccessException;
 using Poco::IllegalStateException;
@@ -62,9 +68,12 @@ using Poco::Data::CLOBOutputStream;
 using Poco::Data::MetaColumn;
 using Poco::Data::Column;
 using Poco::Data::Row;
+using Poco::Data::RowFormatter;
 using Poco::Data::SimpleRowFormatter;
+using Poco::Data::JSONRowFormatter;
 using Poco::Data::Date;
 using Poco::Data::Time;
+using Poco::Data::AbstractExtractor;
 using Poco::Data::AbstractExtraction;
 using Poco::Data::AbstractExtractionVec;
 using Poco::Data::AbstractExtractionVecVec;
@@ -105,7 +114,7 @@ void DataTest::testSession()
 	sess << "DROP TABLE IF EXISTS Test", now;
 	int count;
 	sess << "SELECT COUNT(*) FROM PERSON", into(count), now;
-	
+
 	std::string str;
 	Statement stmt = (sess << "SELECT * FROM Strings", into(str), limit(50));
 	stmt.execute();
@@ -116,28 +125,45 @@ void DataTest::testSession()
 
 	try
 	{
-		stmt.execute(); 
+		stmt.execute();
 		fail ("must fail");
 	} catch (NotConnectedException&) { }
 
+	assertTrue(stmt.done());
+
 	try
 	{
-		sess << "SELECT * FROM Strings", now; 
+		sess << "SELECT * FROM Strings", now;
 		fail ("must fail");
 	} catch (NotConnectedException&) { }
 
 	sess.open();
 	assertTrue (sess.getFeature("connected"));
 	assertTrue (sess.isConnected());
-	
-	sess << "SELECT * FROM Strings", now; 
+
+	// ensure that throwing during execution leaves
+	// statement in valid state (ST_DONE)
+	sess.setFeature("throwOnHasNext", true);
+	Statement stmt1 = (sess << "SELECT * FROM Strings", into(str), limit(50));
+	assertTrue (sess.getFeature("throwOnHasNext"));
+	try
+	{
+		stmt1.execute();
+		fail ("must trow UnknownDataBaseException");
+	}
+	catch(const Poco::Data::UnknownDataBaseException&) {}
+	assertTrue(stmt1.done());
+
+	// reset session back to normal operation
+	sess.setFeature("throwOnHasNext", false);
+	sess << "SELECT * FROM Strings", now;
 	stmt.execute();
 
 	sess.reconnect();
 	assertTrue (sess.getFeature("connected"));
 	assertTrue (sess.isConnected());
-	
-	sess << "SELECT * FROM Strings", now; 
+
+	sess << "SELECT * FROM Strings", now;
 	stmt.execute();
 }
 
@@ -146,9 +172,9 @@ void DataTest::testStatementFormatting()
 {
 	Session sess(SessionFactory::instance().create("test", "cs"));
 
-	Statement stmt = (sess << "SELECT %s%c%s,%d,%u,%f,%s FROM Person WHERE Name LIKE 'Simp%%'", 
+	Statement stmt = (sess << "SELECT %s%c%s,%d,%u,%f,%s FROM Person WHERE Name LIKE 'Simp%%'",
 		"'",'a',"'",-1, 1u, 1.5, "42", now);
-	
+
 	assertTrue ("SELECT 'a',-1,1,1.500000,42 FROM Person WHERE Name LIKE 'Simp%'" == stmt.toString());
 }
 
@@ -156,11 +182,52 @@ void DataTest::testStatementFormatting()
 void DataTest::testFeatures()
 {
 	Session sess(SessionFactory::instance().create("test", "cs"));
-	
+
+	// AbstractSession features
+	assertTrue (sess.hasFeature("bulk"));
+	assertTrue (!sess.getFeature("bulk"));
+	sess.setFeature("bulk", true);
+	assertTrue (sess.getFeature("bulk"));
+	sess.setFeature("bulk", false);
+	assertTrue (!sess.getFeature("bulk"));
+
+	assertTrue (sess.hasFeature("emptyStringIsNull"));
+	assertTrue (!sess.getFeature("emptyStringIsNull"));
+	sess.setFeature("emptyStringIsNull", true);
+	assertTrue (sess.getFeature("emptyStringIsNull"));
+	sess.setFeature("emptyStringIsNull", false);
+	assertTrue (!sess.getFeature("emptyStringIsNull"));
+
+	assertTrue (sess.hasFeature("forceEmptyString"));
+	assertTrue (!sess.getFeature("forceEmptyString"));
+	sess.setFeature("forceEmptyString", true);
+	assertTrue (sess.getFeature("forceEmptyString"));
+	sess.setFeature("forceEmptyString", false);
+	assertTrue (!sess.getFeature("forceEmptyString"));
+
+	assertTrue (sess.hasFeature("sqlParse"));
+	assertTrue (sess.getFeature("sqlParse"));
+	sess.setFeature("sqlParse", false);
+	assertTrue (!sess.getFeature("sqlParse"));
+	sess.setFeature("sqlParse", true);
+	assertTrue (sess.getFeature("sqlParse"));
+
+	assertTrue (sess.hasFeature("autoCommit"));
+	assertTrue (sess.getFeature("autoCommit"));
+	sess.setFeature("autoCommit", false);
+	assertTrue (!sess.getFeature("autoCommit"));
+	sess.setFeature("autoCommit", true);
+	assertTrue (sess.getFeature("autoCommit"));
+
+	// Session implementation features
 	sess.setFeature("f1", true);
 	assertTrue (sess.getFeature("f1"));
 	assertTrue (sess.getFeature("f2"));
-	
+
+	sess.setFeature("f1", true);
+	assertTrue (sess.getFeature("f1"));
+	assertTrue (sess.getFeature("f2"));
+
 	try
 	{
 		sess.setFeature("f2", false);
@@ -168,10 +235,10 @@ void DataTest::testFeatures()
 	catch (NotImplementedException&)
 	{
 	}
-	
+
 	sess.setFeature("f3", false);
 	assertTrue (!sess.getFeature("f2"));
-	
+
 	try
 	{
 		sess.setFeature("f3", true);
@@ -179,7 +246,7 @@ void DataTest::testFeatures()
 	catch (NotImplementedException&)
 	{
 	}
-	
+
 	try
 	{
 		sess.setFeature("f4", false);
@@ -193,13 +260,23 @@ void DataTest::testFeatures()
 void DataTest::testProperties()
 {
 	Session sess(SessionFactory::instance().create("test", "cs"));
-		
+
+	// AbstractSession properties
+	sess.setProperty("storage", "myStorage"s);
+	Poco::Any s1 = sess.getProperty("storage");
+	assertTrue (Poco::AnyCast<std::string>(s1) == "myStorage"s);
+
+	sess.setProperty("handle", 1);
+	Poco::Any h1 = sess.getProperty("handle");
+	assertTrue (Poco::AnyCast<int>(h1) == 1);
+
+	// Session implementation properties
 	sess.setProperty("p1", 1);
 	Poco::Any v1 = sess.getProperty("p1");
 	assertTrue (Poco::AnyCast<int>(v1) == 1);
 	Poco::Any v2 = sess.getProperty("p2");
 	assertTrue (Poco::AnyCast<int>(v2) == 1);
-	
+
 	try
 	{
 		sess.setProperty("p2", 2);
@@ -207,11 +284,11 @@ void DataTest::testProperties()
 	catch (NotImplementedException&)
 	{
 	}
-	
+
 	sess.setProperty("p3", 2);
 	v1 = sess.getProperty("p2");
 	assertTrue (Poco::AnyCast<int>(v1) == 2);
-	
+
 	try
 	{
 		sess.setProperty("p3", 3);
@@ -219,7 +296,7 @@ void DataTest::testProperties()
 	catch (NotImplementedException&)
 	{
 	}
-	
+
 	try
 	{
 		sess.setProperty("p4", 4);
@@ -250,7 +327,7 @@ void DataTest::testLOB()
 	assertTrue (*lobNum1.begin() == 0);
 	Poco::Data::LOB<int>::Iterator it1 = lobNum1.end();
 	assertTrue (*(--it1) == 9);
-	
+
 	Poco::Data::LOB<int> lobNum2(lobNum1);
 	assertTrue (lobNum2.size() == lobNum1.size());
 	assertTrue (lobNum2 == lobNum1);
@@ -265,7 +342,7 @@ void DataTest::testCLOB()
 	std::string strAlpha = "abcdefghijklmnopqrstuvwxyz";
 	std::vector<char> vecAlpha(strAlpha.begin(), strAlpha.end());
 	std::vector<char> vecDigit(strDigit.begin(), strDigit.end());
-	
+
 	CLOB blobNumStr(strDigit.c_str(), strDigit.size());
 	assertTrue (blobNumStr.size() == strDigit.size());
 	assertTrue (0 == std::strncmp(strDigit.c_str(), blobNumStr.rawContent(), blobNumStr.size()));
@@ -344,19 +421,19 @@ void DataTest::writeToCLOB(BinaryWriter& writer)
 	writer << (unsigned) 123456;
 	writer << (long) -1234567890;
 	writer << (unsigned long) 1234567890;
-	
+
 	writer << (Int64) -1234567890;
 	writer << (UInt64) 1234567890;
 
 	writer << (float) 1.5;
 	writer << (double) -1.5;
-	
+
 	writer << "foo";
 	writer << "";
 
 	writer << std::string("bar");
 	writer << std::string();
-	
+
 	writer.write7BitEncoded((UInt32) 100);
 	writer.write7BitEncoded((UInt32) 1000);
 	writer.write7BitEncoded((UInt32) 10000);
@@ -380,7 +457,7 @@ void DataTest::readFromCLOB(BinaryReader& reader)
 	assertTrue (b);
 	reader >> b;
 	assertTrue (!b);
-	
+
 	char c = ' ';
 	reader >> c;
 	assertTrue (c == 'a');
@@ -412,7 +489,7 @@ void DataTest::readFromCLOB(BinaryReader& reader)
 	Int64 int64v = 0;
 	reader >> int64v;
 	assertTrue (int64v == -1234567890);
-	
+
 	UInt64 uint64v = 0;
 	reader >> uint64v;
 	assertTrue (uint64v == 1234567890);
@@ -420,7 +497,7 @@ void DataTest::readFromCLOB(BinaryReader& reader)
 	float floatv = 0.0;
 	reader >> floatv;
 	assertTrue (floatv == 1.5);
-	
+
 	double doublev = 0.0;
 	reader >> doublev;
 	assertTrue (doublev == -1.5);
@@ -430,7 +507,7 @@ void DataTest::readFromCLOB(BinaryReader& reader)
 	assertTrue (str == "foo");
 	reader >> str;
 	assertTrue (str == "");
-	
+
 	reader >> str;
 	assertTrue (str == "bar");
 	reader >> str;
@@ -481,7 +558,7 @@ void DataTest::testColumnVector()
 	pData->push_back(3);
 	pData->push_back(4);
 	pData->push_back(5);
-	
+
 	Column<std::vector<int>> c(mc, pData);
 
 	assertTrue (c.rowCount() == 5);
@@ -498,7 +575,7 @@ void DataTest::testColumnVector()
 
 	try
 	{
-		int i; i = c[100]; // to silence gcc
+		POCO_UNUSED int i; i = c[100];
 		fail ("must fail");
 	}
 	catch (RangeException&) { }
@@ -549,7 +626,7 @@ void DataTest::testColumnVector()
 	pV2->push_back(1);
 	Column<std::vector<int>> c3(mc, pV1);
 	Column<std::vector<int>> c4(mc, pV2);
-	
+
 	Poco::Data::swap(c3, c4);
 	assertTrue (c3[0] == 5);
 	assertTrue (c3[1] == 4);
@@ -588,7 +665,7 @@ void DataTest::testColumnVectorBool()
 	pData->push_back(true);
 	pData->push_back(false);
 	pData->push_back(true);
-	
+
 	Column<std::vector<bool>> c(mc, pData);
 
 	assertTrue (c.rowCount() == 5);
@@ -601,7 +678,7 @@ void DataTest::testColumnVectorBool()
 
 	try
 	{
-		bool b; b = c[100]; // to silence gcc
+		POCO_UNUSED bool b; b = c[100];
 		fail ("must fail");
 	}
 	catch (RangeException&) { }
@@ -660,7 +737,7 @@ void DataTest::testColumnDeque()
 	pData->push_back(3);
 	pData->push_back(4);
 	pData->push_back(5);
-	
+
 	ColumnType c(mc, pData);
 
 	assertTrue (c.rowCount() == 5);
@@ -677,7 +754,7 @@ void DataTest::testColumnDeque()
 
 	try
 	{
-		int i; i = c[100]; // to silence gcc
+		POCO_UNUSED int i; i = c[100];
 		fail ("must fail");
 	}
 	catch (RangeException&) { }
@@ -728,7 +805,7 @@ void DataTest::testColumnDeque()
 	pV2->push_back(1);
 	Column<ContainerType> c3(mc, pV1);
 	Column<ContainerType> c4(mc, pV2);
-	
+
 	Poco::Data::swap(c3, c4);
 	assertTrue (c3[0] == 5);
 	assertTrue (c3[1] == 4);
@@ -777,7 +854,7 @@ void DataTest::testColumnList()
 	pData->push_back(3);
 	pData->push_back(4);
 	pData->push_back(5);
-	
+
 	ColumnType c(mc, pData);
 
 	assertTrue (c.rowCount() == 5);
@@ -794,7 +871,7 @@ void DataTest::testColumnList()
 
 	try
 	{
-		int i; i = c[100]; // to silence gcc
+		POCO_UNUSED int i; i = c[100];
 		fail ("must fail");
 	}
 	catch (RangeException&) { }
@@ -843,7 +920,7 @@ void DataTest::testColumnList()
 	pV2->push_back(1);
 	Column<ContainerType> c3(mc, pV1);
 	Column<ContainerType> c4(mc, pV2);
-	
+
 	Poco::Data::swap(c3, c4);
 	assertTrue (c3[0] == 5);
 	assertTrue (c3[1] == 4);
@@ -901,13 +978,13 @@ void DataTest::testRow()
 
 	try
 	{
-		int i; i = row[5].convert<int>(); // to silence gcc
+		POCO_UNUSED int i; i = row[5].convert<int>();
 		fail ("must fail");
 	}catch (RangeException&) {}
 
 	try
 	{
-		int i; i = row["a bad name"].convert<int>(); // to silence gcc
+		POCO_UNUSED int i; i = row["a bad name"].convert<int>();
 		fail ("must fail");
 	}catch (NotFoundException&) {}
 
@@ -1152,7 +1229,7 @@ void DataTest::testRowStrictWeak(const Row& row1, const Row& row2, const Row& ro
 }
 
 
-void DataTest::testRowFormat()
+void DataTest::testSimpleRowFormatter()
 {
 	Row row1;
 	row1.append("field0", 0);
@@ -1168,7 +1245,7 @@ void DataTest::testRowFormat()
 	std::string line(std::string::size_type(sz * 5 + sp * 4), '-');
 	std::string spacer(sp, ' ');
 	std::ostringstream os;
-	os << std::left 
+	os << std::left
 		<< std::setw(sz) << "field0"
 		<< spacer
 		<< std::setw(sz) << "field1"
@@ -1177,12 +1254,12 @@ void DataTest::testRowFormat()
 		<< spacer
 		<< std::setw(sz) << "field3"
 		<< spacer
-		<< std::setw(sz) << "field4" << std::endl 
+		<< std::setw(sz) << "field4" << std::endl
 		<< line << std::endl;
 	assertTrue (row1.namesToString() == os.str());
 
 	os.str("");
-	os << std::right 
+	os << std::right
 		<< std::setw(sz) << "0"
 		<< spacer
 		<< std::setw(sz) << "1"
@@ -1196,6 +1273,38 @@ void DataTest::testRowFormat()
 }
 
 
+void DataTest::testJSONRowFormatter()
+{
+	Row row1;
+	row1.append("field0", 0);
+	row1.append("field1", "1");
+	row1.append("field2", DateTime(2007, 3, 13, 8, 12, 15));
+	row1.append("field3", Var());
+	row1.append("field4", 4);
+	row1.setFormatter(new JSONRowFormatter);
+
+	assertTrue(row1.getFormatter().prefix() == "{");
+	assertTrue(row1.getFormatter().postfix() == "]}");
+	assertTrue(row1.getFormatter().getMode() == RowFormatter::FORMAT_PROGRESSIVE);
+	assertTrue(row1.namesToString() == "\"names\":[\"field0\",\"field1\",\"field2\",\"field3\",\"field4\"]");
+	assertTrue(row1.valuesToString() == ",\"values\":[[0,\"1\",\"2007-03-13T08:12:15Z\",null,4]");
+
+	row1.setFormatter(new JSONRowFormatter(JSONRowFormatter::JSON_FMT_MODE_SMALL));
+	assertTrue(row1.getFormatter().getMode() == RowFormatter::FORMAT_PROGRESSIVE);
+	assertTrue(row1.namesToString() == "");
+	assertTrue(row1.valuesToString() == "[[0,\"1\",\"2007-03-13T08:12:15Z\",null,4]");
+	assertTrue(row1.valuesToString() == ",[0,\"1\",\"2007-03-13T08:12:15Z\",null,4]");
+
+	row1.setFormatter(new JSONRowFormatter(JSONRowFormatter::JSON_FMT_MODE_FULL));
+	assertTrue(row1.getFormatter().prefix() == "{\"count\":0,[");
+	assertTrue(row1.getFormatter().postfix() == "]}");
+	assertTrue(row1.getFormatter().getMode() == RowFormatter::FORMAT_PROGRESSIVE);
+	assertTrue(row1.namesToString() == "");
+	assertTrue(row1.valuesToString() == "{\"field0\":0,\"field1\":\"1\",\"field2\":\"2007-03-13T08:12:15Z\",\"field3\":null,\"field4\":4}");
+	assertTrue(row1.valuesToString() == ",{\"field0\":0,\"field1\":\"1\",\"field2\":\"2007-03-13T08:12:15Z\",\"field3\":null,\"field4\":4}");
+}
+
+
 void DataTest::testDateAndTime()
 {
 	DateTime dt;
@@ -1209,7 +1318,7 @@ void DataTest::testDateAndTime()
 	assertTrue (dt.hour() == t.hour());
 	assertTrue (dt.minute() == t.minute());
 	assertTrue (dt.second() == t.second());
-	
+
 	Date d1(2007, 6, 15);
 	d1.assign(d.year() - 1, d.month(), (d.month() == 2 && d.day() == 29) ? 28 : d.day());
 	assertTrue (d1 < d); assertTrue (d1 != d);
@@ -1225,7 +1334,7 @@ void DataTest::testDateAndTime()
 
 	d1.assign(d.year() + 1, d.month(), (d.month() == 2 && d.day() == 29) ? 28 : d.day());
 	assertTrue (d1 > d); assertTrue (d1 != d);
-	
+
 	d1.assign(d.year() + 1, 1, d.day());
 	assertTrue (d1 > d); assertTrue (d1 != d);
 
@@ -1234,7 +1343,7 @@ void DataTest::testDateAndTime()
 		d1.assign(d.year(), d.month(), d.day() + 1);
 		assertTrue (d1 > d); assertTrue (d1 != d);
 	}
-	
+
 	d1.assign(d.year(), d.month(), d.day());
 	assertTrue (d1 == d);
 
@@ -1246,7 +1355,7 @@ void DataTest::testDateAndTime()
 	catch (InvalidArgumentException&) { }
 
 	Time t1(12, 30, 15);
-	
+
 	if (t.hour() > 1)
 	{
 		t1.assign(t.hour() - 1, t.minute(), t.second());
@@ -1258,14 +1367,14 @@ void DataTest::testDateAndTime()
 		t1.assign(t.hour(), t.minute() - 1, t.second());
 		assertTrue (t1 < t); assertTrue (t1 != t);
 	}
-	
+
 	if (t.second() > 1)
 	{
 		t1.assign(t.hour(), t.minute(), t.second() - 1);
 		assertTrue (t1 < t); assertTrue (t1 != t);
 	}
 
-	if (t.hour() < 23) 
+	if (t.hour() < 23)
 	{
 		t1.assign(t.hour() + 1, t.minute(), t.second());
 		assertTrue (t1 > t); assertTrue (t1 != t);
@@ -1358,6 +1467,105 @@ void DataTest::testExternalBindingAndExtraction()
 }
 
 
+void DataTest::testTranscode()
+{
+	Latin1Encoding::Ptr pL2E = new Latin1Encoding();
+
+	const unsigned char latin1Chars[] = { 'g', 252, 'n', 't', 'e', 'r', 0 };
+	const unsigned char utf8Chars[] = { 'g', 195, 188, 'n', 't', 'e', 'r', 0 };
+	std::string latin1Text((const char*)latin1Chars);
+	std::string utf8Text((const char*)utf8Chars);
+
+	Poco::Data::Test::Extractor ext;
+	ext.setString(latin1Text);
+	std::string latin1Out;
+	assertTrue (ext.extract(0, latin1Out));
+	assertTrue(latin1Out == latin1Text);
+
+	Poco::Data::Test::Extractor ext2(new Latin1Encoding());
+	ext2.setString(latin1Text);
+	std::string utf8Out;
+	assertTrue(ext2.extract(0, utf8Out));
+	assertTrue(utf8Out == utf8Text);
+}
+
+
+void DataTest::testSQLParse()
+{
+	Session sess(SessionFactory::instance().create("test", "cs"));
+
+	assertTrue (sess.getFeature("autoCommit"));
+	sess.setFeature("autoCommit", false);
+	assertTrue (!sess.getFeature("autoCommit"));
+
+	Statement stmt = (sess << "SELECT %s%c%s,%d,%u,%f,%s FROM Person WHERE Name LIKE 'Simp%%'",
+		"'",'a',"'",-1, 1u, 1.5, "42", now);
+
+	assertTrue ("SELECT 'a',-1,1,1.500000,42 FROM Person WHERE Name LIKE 'Simp%'" == stmt.toString());
+
+#ifndef POCO_DATA_NO_SQL_PARSER
+
+	assertEqual (1u, stmt.statementsCount().value());
+	assertTrue (stmt.isSelect().value());
+	assertTrue (stmt.hasSelect().value());
+	assertTrue (!stmt.isUpdate().value());
+	assertTrue (!stmt.hasUpdate().value());
+	assertTrue (!stmt.isInsert().value());
+	assertTrue (!stmt.hasInsert().value());
+	assertTrue (!stmt.isDelete().value());
+	assertTrue (!stmt.hasDelete().value());
+
+	stmt.reset();
+	stmt = (sess << "INSERT INTO Test VALUES ('1', 2, 3.5);"
+		"SELECT * FROM Test WHERE First = ?;"
+		"UPDATE Test SET value=1 WHERE First = '1';"
+		"DELETE FROM Test WHERE First = ?;"
+		"DROP TABLE table_name;"
+		"ALTER TABLE mytable DROP COLUMN IF EXISTS mycolumn;"
+		"PREPARE prep_inst FROM 'INSERT INTO test VALUES (?, ?, ?)';"
+		"EXECUTE prep_inst(1, 2, 3);");
+	stmt.execute();
+	assertEqual (8u, stmt.statementsCount().value());
+	assertTrue (!stmt.isSelect().value());
+	assertTrue (stmt.hasSelect().value());
+	assertTrue (!stmt.isUpdate().value());
+	assertTrue (stmt.hasUpdate().value());
+	assertTrue (!stmt.isInsert().value());
+	assertTrue (stmt.hasInsert().value());
+	assertTrue (!stmt.isDelete().value());
+	assertTrue (stmt.hasDelete().value());
+
+	sess.setFeature("sqlParse", false);
+	assertTrue (!sess.getFeature("sqlParse"));
+
+#else
+
+	std::cout << "partial test (parser not available)";
+
+#endif // POCO_DATA_NO_SQL_PARSER
+
+	stmt.reset();
+	stmt = (sess << "INSERT INTO Test VALUES ('1', 2, 3.5);"
+		"SELECT * FROM Test WHERE First = ?;"
+		"UPDATE Test SET value=1 WHERE First = '1';"
+		"DELETE FROM Test WHERE First = ?;"
+		"DROP TABLE table_name;"
+		"ALTER TABLE mytable DROP COLUMN IF EXISTS mycolumn;"
+		"PREPARE prep_inst FROM 'INSERT INTO test VALUES (?, ?, ?)';"
+		"EXECUTE prep_inst(1, 2, 3);");
+
+	stmt.execute();
+	assertTrue (!stmt.isSelect().isSpecified());
+	assertTrue (!stmt.hasSelect().isSpecified());
+	assertTrue (!stmt.isUpdate().isSpecified());
+	assertTrue (!stmt.hasUpdate().isSpecified());
+	assertTrue (!stmt.isInsert().isSpecified());
+	assertTrue (!stmt.hasInsert().isSpecified());
+	assertTrue (!stmt.isDelete().isSpecified());
+	assertTrue (!stmt.hasDelete().isSpecified());
+}
+
+
 void DataTest::setUp()
 {
 }
@@ -1385,9 +1593,12 @@ CppUnit::Test* DataTest::suite()
 	CppUnit_addTest(pSuite, DataTest, testColumnList);
 	CppUnit_addTest(pSuite, DataTest, testRow);
 	CppUnit_addTest(pSuite, DataTest, testRowSort);
-	CppUnit_addTest(pSuite, DataTest, testRowFormat);
+	CppUnit_addTest(pSuite, DataTest, testSimpleRowFormatter);
+	CppUnit_addTest(pSuite, DataTest, testJSONRowFormatter);
 	CppUnit_addTest(pSuite, DataTest, testDateAndTime);
 	CppUnit_addTest(pSuite, DataTest, testExternalBindingAndExtraction);
+	CppUnit_addTest(pSuite, DataTest, testTranscode);
+	CppUnit_addTest(pSuite, DataTest, testSQLParse);
 
 	return pSuite;
 }
