@@ -11,6 +11,9 @@
 #include "DataTestSuite.h"
 #include "DataTest.h"
 #include "SessionPoolTest.h"
+#ifndef POCO_DATA_NO_SQL_PARSER
+#include "SQLParserTest.h"
+#endif //  POCO_DATA_NO_SQL_PARSER
 
 
 CppUnit::Test* DataTestSuite::suite()
@@ -19,6 +22,9 @@ CppUnit::Test* DataTestSuite::suite()
 
 	pSuite->addTest(DataTest::suite());
 	pSuite->addTest(SessionPoolTest::suite());
+#ifndef POCO_DATA_NO_SQL_PARSER
+	pSuite->addTest(SQLParserTest::suite());
+#endif //  POCO_DATA_NO_SQL_PARSER
 
 	return pSuite;
 }
