@@ -43,6 +43,17 @@ public:
 		FMT_ON_OFF
 	};
 
+	enum class Options
+		/// Options to control the format of the generated string.
+	{
+		DEFAULT = 0,
+			/// formatHex defaults: No 0x prefix, uppercase hexadecimal values
+		PREFIX = 1 << 0,
+			/// formatHex: Prepend prefix 0x
+		LOWERCASE = 1 << 1
+			/// formatHex: Use lowercase letters for hexadecimal values
+	};
+
 	static const unsigned NF_MAX_INT_STRING_LEN = 32; // increase for 64-bit binary formatting support
 	static const unsigned NF_MAX_FLT_STRING_LEN = POCO_MAX_FLT_STRING_LEN;
 
@@ -59,18 +70,18 @@ public:
 		/// right justified and zero-padded in a field
 		/// having at least the specified width.
 
-	static std::string formatHex(int value, bool prefix = false);
+	static std::string formatHex(int value, Options options = Options::DEFAULT);
 		/// Formats an int value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 		/// The value is treated as unsigned.
 
-	static std::string formatHex(int value, int width, bool prefix = false);
-		/// Formats a int value in hexadecimal notation,
+	static std::string formatHex(int value, int width, Options options = Options::DEFAULT);
+		/// Formats an int value in hexadecimal notation,
 		/// right justified and zero-padded in
 		/// a field having at least the specified width.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 		/// The value is treated as unsigned.
 
 	static std::string format(unsigned value);
@@ -86,17 +97,17 @@ public:
 		/// right justified and zero-padded in a field having at
 		/// least the specified width.
 
-	static std::string formatHex(unsigned value, bool prefix = false);
+	static std::string formatHex(unsigned value, Options options = Options::DEFAULT);
 		/// Formats an unsigned int value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(unsigned value, int width, bool prefix = false);
-		/// Formats a int value in hexadecimal notation,
+	static std::string formatHex(unsigned value, int width, Options options = Options::DEFAULT);
+		/// Formats an unsigned value in hexadecimal notation,
 		/// right justified and zero-padded in
 		/// a field having at least the specified width.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
 	static std::string format(long value);
 		/// Formats a long value in decimal notation.
@@ -111,19 +122,17 @@ public:
 		/// right justified and zero-padded in a field
 		/// having at least the specified width.
 
-	static std::string formatHex(long value, bool prefix = false);
-		/// Formats an unsigned long value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
-		/// The value is treated as unsigned.
+	static std::string formatHex(long value, Options options = Options::DEFAULT);
+		/// Formats a long value in hexadecimal notation.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(long value, int width, bool prefix = false);
-		/// Formats an unsigned long value in hexadecimal notation,
-		/// right justified and zero-padded in a field having at least the
-		/// specified width.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
-		/// The value is treated as unsigned.
+	static std::string formatHex(long value, int width, Options options = Options::DEFAULT);
+		/// Formats a long value in hexadecimal notation,
+		/// right justified and zero-padded in
+		/// a field having at least the specified width.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
 	static std::string format(unsigned long value);
 		/// Formats an unsigned long value in decimal notation.
@@ -138,21 +147,20 @@ public:
 		/// right justified and zero-padded
 		/// in a field having at least the specified width.
 
-	static std::string formatHex(unsigned long value, bool prefix = false);
+	static std::string formatHex(unsigned long value, Options options = Options::DEFAULT);
 		/// Formats an unsigned long value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(unsigned long value, int width, bool prefix = false);
+	static std::string formatHex(unsigned long value, int width, Options options = Options::DEFAULT);
 		/// Formats an unsigned long value in hexadecimal notation,
-		/// right justified and zero-padded in a field having at least the
-		/// specified width.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+		/// right justified and zero-padded in
+		/// a field having at least the specified width.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
 #ifdef POCO_HAVE_INT64
-
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	static std::string format(long long value);
 		/// Formats a 64-bit integer value in decimal notation.
@@ -166,18 +174,18 @@ public:
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-	static std::string formatHex(long long value, bool prefix = false);
+	static std::string formatHex(long long value, Options options = Options::DEFAULT);
 		/// Formats a 64-bit integer value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
-		/// The value is treated as unsigned.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(long long value, int width, bool prefix = false);
+	static std::string formatHex(long long value, int width, Options options = Options::DEFAULT);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 		/// The value is treated as unsigned.
-		/// If prefix is true, "0x" prefix is prepended to the resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
 	static std::string format(unsigned long long value);
 		/// Formats an unsigned 64-bit integer value in decimal notation.
@@ -191,18 +199,20 @@ public:
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
 
-	static std::string formatHex(unsigned long long value, bool prefix = false);
-		/// Formats a 64-bit integer value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+	static std::string formatHex(unsigned long long value, Options options = Options::DEFAULT);
+		/// Formats an unsigned 64-bit value in hexadecimal notation.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(unsigned long long value, int width, bool prefix = false);
-		/// Formats a 64-bit integer value in hexadecimal notation,
+	static std::string formatHex(unsigned long long value, int width, Options options = Options::DEFAULT);
+		/// Formats an unsigned 64-bit value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
-		/// the specified width. If prefix is true, "0x" prefix is
-		/// prepended to the resulting string.
+		/// the specified width.
+		/// The value is treated as unsigned.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-#else // ifndef POCO_LONG_IS_64_BIT
+#else // ifndef POCO_INT64_IS_LONG
 
 	static std::string format(Int64 value);
 		/// Formats a 64-bit integer value in decimal notation.
@@ -216,18 +226,18 @@ public:
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-	static std::string formatHex(Int64 value, bool prefix = false);
+	static std::string formatHex(Int64 value, Options options = Options::DEFAULT);
 		/// Formats a 64-bit integer value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
-		/// The value is treated as unsigned.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(Int64 value, int width, bool prefix = false);
+	static std::string formatHex(Int64 value, int width, Options options = Options::DEFAULT);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 		/// The value is treated as unsigned.
-		/// If prefix is true, "0x" prefix is prepended to the resulting string.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
 	static std::string format(UInt64 value);
 		/// Formats an unsigned 64-bit integer value in decimal notation.
@@ -241,19 +251,20 @@ public:
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
 
-	static std::string formatHex(UInt64 value, bool prefix = false);
-		/// Formats a 64-bit integer value in hexadecimal notation.
-		/// If prefix is true, "0x" prefix is prepended to the 
-		/// resulting string.
+	static std::string formatHex(UInt64 value, Options options = Options::DEFAULT);
+		/// Formats an unsigned 64-bit integer in hexadecimal notation.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
-	static std::string formatHex(UInt64 value, int width, bool prefix = false);
-		/// Formats a 64-bit integer value in hexadecimal notation,
+	static std::string formatHex(UInt64 value, int width, Options options = Options::DEFAULT);
+		/// Formats an unsigned 64-bit integer in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
-		/// the specified width. If prefix is true, "0x" prefix is
-		/// prepended to the resulting string.
-
-#endif // ifdef POCO_LONG_IS_64_BIT
+		/// the specified width.
+		/// The value is treated as unsigned.
+		/// Options (see NumberFormatter::Options) define the format of the
+		/// generated string.
 
+#endif // ifdef POCO_INT64_IS_LONG
 #endif // ifdef POCO_HAVE_INT64
 
 	static std::string format(float value);
@@ -304,11 +315,11 @@ public:
 		/// right justified and zero-padded in a field
 		/// having at least the specified width.
 
-	static void appendHex(std::string& str, int value);
+	static void appendHex(std::string& str, int value, bool lowercase = false);
 		/// Formats an int value in hexadecimal notation.
 		/// The value is treated as unsigned.
 
-	static void appendHex(std::string& str, int value, int width);
+	static void appendHex(std::string& str, int value, int width, bool lowercase = false);
 		/// Formats a int value in hexadecimal notation,
 		/// right justified and zero-padded in
 		/// a field having at least the specified width.
@@ -327,10 +338,10 @@ public:
 		/// right justified and zero-padded in a field having at
 		/// least the specified width.
 
-	static void appendHex(std::string& str, unsigned value);
+	static void appendHex(std::string& str, unsigned value, bool lowercase = false);
 		/// Formats an unsigned int value in hexadecimal notation.
 
-	static void appendHex(std::string& str, unsigned value, int width);
+	static void appendHex(std::string& str, unsigned value, int width, bool lowercase = false);
 		/// Formats a int value in hexadecimal notation,
 		/// right justified and zero-padded in
 		/// a field having at least the specified width.
@@ -348,11 +359,11 @@ public:
 		/// right justified and zero-padded in a field
 		/// having at least the specified width.
 
-	static void appendHex(std::string& str, long value);
+	static void appendHex(std::string& str, long value, bool lowercase = false);
 		/// Formats an unsigned long value in hexadecimal notation.
 		/// The value is treated as unsigned.
 
-	static void appendHex(std::string& str, long value, int width);
+	static void appendHex(std::string& str, long value, int width, bool lowercase = false);
 		/// Formats an unsigned long value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
@@ -371,17 +382,16 @@ public:
 		/// right justified and zero-padded
 		/// in a field having at least the specified width.
 
-	static void appendHex(std::string& str, unsigned long value);
+	static void appendHex(std::string& str, unsigned long value, bool lowercase = false);
 		/// Formats an unsigned long value in hexadecimal notation.
 
-	static void appendHex(std::string& str, unsigned long value, int width);
+	static void appendHex(std::string& str, unsigned long value, int width, bool lowercase = false);
 		/// Formats an unsigned long value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
 
 #ifdef POCO_HAVE_INT64
-
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	static void append(std::string& str, long long value);
 		/// Formats a 64-bit integer value in decimal notation.
@@ -395,11 +405,11 @@ public:
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-	static void appendHex(std::string& str, long long value);
+	static void appendHex(std::string& str, long long value, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation.
 		/// The value is treated as unsigned.
 
-	static void appendHex(std::string& str, long long value, int width);
+	static void appendHex(std::string& str, long long value, int width, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
@@ -417,15 +427,15 @@ public:
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
 
-	static void appendHex(std::string& str, unsigned long long value);
+	static void appendHex(std::string& str, unsigned long long value, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation.
 
-	static void appendHex(std::string& str, unsigned long long value, int width);
+	static void appendHex(std::string& str, unsigned long long value, int width, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-#else // ifndef POCO_LONG_IS_64_BIT
+#else // ifndef POCO_INT64_IS_LONG
 
 	static void append(std::string& str, Int64 value);
 		/// Formats a 64-bit integer value in decimal notation.
@@ -439,11 +449,11 @@ public:
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-	static void appendHex(std::string& str, Int64 value);
+	static void appendHex(std::string& str, Int64 value, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation.
 		/// The value is treated as unsigned.
 
-	static void appendHex(std::string& str, Int64 value, int width);
+	static void appendHex(std::string& str, Int64 value, int width, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
@@ -461,16 +471,15 @@ public:
 		/// right justified and zero-padded in a field having at least the
 		/// specified width.
 
-	static void appendHex(std::string& str, UInt64 value);
+	static void appendHex(std::string& str, UInt64 value, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation.
 
-	static void appendHex(std::string& str, UInt64 value, int width);
+	static void appendHex(std::string& str, UInt64 value, int width, bool lowercase = false);
 		/// Formats a 64-bit integer value in hexadecimal notation,
 		/// right justified and zero-padded in a field having at least
 		/// the specified width.
 
-#endif // ifdef POCO_LONG_IS_64_BIT
-
+#endif // ifdef POCO_INT64_IS_LONG
 #endif // ifdef POCO_HAVE_INT64
 
 	static void append(std::string& str, float value);
@@ -504,7 +513,137 @@ public:
 		/// sixteen (64-bit architectures) characters wide
 		/// field in hexadecimal notation.
 
+//
+// Deprecated functions
+//
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(int value, bool prefix);
+		/// Formats an int value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(int value, int width, bool prefix);
+		/// Formats an int value in hexadecimal notation,
+		/// right justified and zero-padded in
+		/// a field having at least the specified width.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned value, bool prefix);
+		/// Formats an unsigned int value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned value, int width, bool prefix);
+		/// Formats an unsigned value in hexadecimal notation,
+		/// right justified and zero-padded in
+		/// a field having at least the specified width.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(long value, bool prefix);
+		/// Formats a long value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(long value, int width, bool prefix);
+		/// Formats a long value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least the
+		/// specified width.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned long value, bool prefix);
+		/// Formats an unsigned long value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned long value, int width, bool prefix);
+		/// Formats an unsigned long value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least the
+		/// specified width.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+#ifdef POCO_HAVE_INT64
+#ifdef POCO_INT64_IS_LONG
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(long long value, bool prefix);
+		/// Formats a 64-bit integer value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(long long value, int width, bool prefix);
+		/// Formats a 64-bit integer value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least
+		/// the specified width.
+		/// The value is treated as unsigned.
+		/// If prefix is true, "0x" prefix is prepended to the resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned long long value, bool prefix);
+		/// Formats an unsigned 64-bit integer value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(unsigned long long value, int width, bool prefix);
+		/// Formats an unsigned 64-bit integer value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least
+		/// the specified width. If prefix is true, "0x" prefix is
+		/// prepended to the resulting string.
+
+#else // ifndef POCO_INT64_IS_LONG
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(Int64 value, bool prefix);
+		/// Formats a 64-bit integer value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+		/// The value is treated as unsigned.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(Int64 value, int width, bool prefix);
+		/// Formats a 64-bit integer value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least
+		/// the specified width.
+		/// The value is treated as unsigned.
+		/// If prefix is true, "0x" prefix is prepended to the resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(UInt64 value, bool prefix);
+		/// Formats an unsigned 64-bit integer value in hexadecimal notation.
+		/// If prefix is true, "0x" prefix is prepended to the
+		/// resulting string.
+
+	[[deprecated("use formatHex with options instead")]]
+	static std::string formatHex(UInt64 value, int width, bool prefix);
+		/// Formats an unsigned 64-bit integer value in hexadecimal notation,
+		/// right justified and zero-padded in a field having at least
+		/// the specified width. If prefix is true, "0x" prefix is
+		/// prepended to the resulting string.
+
+#endif // ifdef POCO_INT64_IS_LONG
+#endif // ifdef POCO_HAVE_INT64
+
 private:
+
+	static bool isEnabled(NumberFormatter::Options options, NumberFormatter::Options opt);
 };
 
 
@@ -512,6 +651,42 @@ private:
 // inlines
 //
 
+
+inline NumberFormatter::Options operator | (NumberFormatter::Options lhs, NumberFormatter::Options rhs)
+{
+    using T = std::underlying_type_t<NumberFormatter::Options>;
+    return static_cast<NumberFormatter::Options>(static_cast<T>(lhs) | static_cast<T>(rhs));
+}
+
+
+inline NumberFormatter::Options& operator |= (NumberFormatter::Options& lhs, NumberFormatter::Options rhs)
+{
+    lhs = lhs | rhs;
+    return lhs;
+}
+
+
+inline NumberFormatter::Options operator & (NumberFormatter::Options lhs, NumberFormatter::Options rhs)
+{
+    using T = std::underlying_type_t<NumberFormatter::Options>;
+    return static_cast<NumberFormatter::Options>(static_cast<T>(lhs) & static_cast<T>(rhs));
+}
+
+
+inline NumberFormatter::Options& operator &= (NumberFormatter::Options& lhs, NumberFormatter::Options rhs)
+{
+    lhs = lhs & rhs;
+    return lhs;
+}
+
+
+inline bool NumberFormatter::isEnabled(Options options, Options opt)
+{
+	using T = std::underlying_type_t<Options>;
+    return static_cast<T>(options & opt) != 0;
+}
+
+
 inline std::string NumberFormatter::format(int value)
 {
 	std::string result;
@@ -536,26 +711,22 @@ inline std::string NumberFormatter::format0(int value, int width)
 }
 
 
-inline std::string NumberFormatter::formatHex(int value, bool prefix)
+inline std::string NumberFormatter::formatHex(int value, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned int>(value), 0x10, result, prefix);
-	return result;
+	return formatHex(static_cast<unsigned int>(value), options);
 }
 
 
-inline std::string NumberFormatter::formatHex(int value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(int value, int width, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned int>(value), 0x10, result, prefix, width, '0');
-	return result;
+	return formatHex(static_cast<unsigned int>(value), width, options);
 }
 
 
 inline std::string NumberFormatter::format(unsigned value)
 {
 	std::string result;
-	uIntToStr(value, 10, result);
+	intToStr(value, 10, result);
 	return result;
 }
 
@@ -563,7 +734,7 @@ inline std::string NumberFormatter::format(unsigned value)
 inline std::string NumberFormatter::format(unsigned value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, ' ');
+	intToStr(value, 10, result, false, width, ' ');
 	return result;
 }
 
@@ -571,23 +742,23 @@ inline std::string NumberFormatter::format(unsigned value, int width)
 inline std::string NumberFormatter::format0(unsigned int value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, '0');
+	intToStr(value, 10, result, false, width, '0');
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned value, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned value, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix);
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX),-1, ' ', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned value, int width, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix, width, '0');
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), width, '0', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
@@ -616,26 +787,22 @@ inline std::string NumberFormatter::format0(long value, int width)
 }
 
 
-inline std::string NumberFormatter::formatHex(long value, bool prefix)
+inline std::string NumberFormatter::formatHex(long value, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned long>(value), 0x10, result, prefix);
-	return result;
+	return formatHex(static_cast<unsigned long>(value), options);
 }
 
 
-inline std::string NumberFormatter::formatHex(long value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(long value, int width, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned long>(value), 0x10, result, prefix, width, '0');
-	return result;
+	return formatHex(static_cast<unsigned long>(value), width, options);
 }
 
 
 inline std::string NumberFormatter::format(unsigned long value)
 {
 	std::string result;
-	uIntToStr(value, 10, result);
+	intToStr(value, 10, result);
 	return result;
 }
 
@@ -643,7 +810,7 @@ inline std::string NumberFormatter::format(unsigned long value)
 inline std::string NumberFormatter::format(unsigned long value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, ' ');
+	intToStr(value, 10, result, false, width, ' ');
 	return result;
 }
 
@@ -651,30 +818,28 @@ inline std::string NumberFormatter::format(unsigned long value, int width)
 inline std::string NumberFormatter::format0(unsigned long value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, '0');
+	intToStr(value, 10, result, false, width, '0');
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned long value, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned long value, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix);
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), -1, ' ', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned long value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned long value, int width, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix, width, '0');
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), width, '0', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
-
 #ifdef POCO_HAVE_INT64
-
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 
 inline std::string NumberFormatter::format(long long value)
@@ -701,26 +866,22 @@ inline std::string NumberFormatter::format0(long long value, int width)
 }
 
 
-inline std::string NumberFormatter::formatHex(long long value, bool prefix)
+inline std::string NumberFormatter::formatHex(long long value, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned long long>(value), 0x10, result, prefix);
-	return result;
+	return formatHex(static_cast<unsigned long long>(value), options);
 }
 
 
-inline std::string NumberFormatter::formatHex(long long value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(long long value, int width, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<unsigned long long>(value), 0x10, result, prefix, width, '0');
-	return result;
+	return formatHex(static_cast<unsigned long long>(value), width, options);
 }
 
 
 inline std::string NumberFormatter::format(unsigned long long value)
 {
 	std::string result;
-	uIntToStr(value, 10, result);
+	intToStr(value, 10, result);
 	return result;
 }
 
@@ -728,7 +889,7 @@ inline std::string NumberFormatter::format(unsigned long long value)
 inline std::string NumberFormatter::format(unsigned long long value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, ' ');
+	intToStr(value, 10, result, false, width, ' ');
 	return result;
 }
 
@@ -736,23 +897,23 @@ inline std::string NumberFormatter::format(unsigned long long value, int width)
 inline std::string NumberFormatter::format0(unsigned long long value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, '0');
+	intToStr(value, 10, result, false, width, '0');
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned long long value, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned long long value, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix);
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), -1, ' ', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(unsigned long long value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(unsigned long long value, int width, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix, width, '0');
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), width, '0', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
@@ -784,26 +945,22 @@ inline std::string NumberFormatter::format0(Int64 value, int width)
 }
 
 
-inline std::string NumberFormatter::formatHex(Int64 value, bool prefix)
+inline std::string NumberFormatter::formatHex(Int64 value, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<UInt64>(value), 0x10, result, prefix);
-	return result;
+	return formatHex(static_cast<UInt64>(value), options);
 }
 
 
-inline std::string NumberFormatter::formatHex(Int64 value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(long long value, int width, Options options)
 {
-	std::string result;
-	uIntToStr(static_cast<UInt64>(value), 0x10, result, prefix, width, '0');
-	return result;
+	return formatHex(static_cast<UInt64>(value), width, options);
 }
 
 
 inline std::string NumberFormatter::format(UInt64 value)
 {
 	std::string result;
-	uIntToStr(value, 10, result);
+	intToStr(value, 10, result);
 	return result;
 }
 
@@ -811,7 +968,7 @@ inline std::string NumberFormatter::format(UInt64 value)
 inline std::string NumberFormatter::format(UInt64 value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, ' ');
+	intToStr(value, 10, result, false, width, ' ');
 	return result;
 }
 
@@ -819,29 +976,28 @@ inline std::string NumberFormatter::format(UInt64 value, int width)
 inline std::string NumberFormatter::format0(UInt64 value, int width)
 {
 	std::string result;
-	uIntToStr(value, 10, result, false, width, '0');
+	intToStr(value, 10, result, false, width, '0');
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(UInt64 value, bool prefix)
+inline std::string NumberFormatter::formatHex(UInt64 value, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix);
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), -1, ' ', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
 
-inline std::string NumberFormatter::formatHex(UInt64 value, int width, bool prefix)
+inline std::string NumberFormatter::formatHex(UInt64 value, int width, Options options)
 {
 	std::string result;
-	uIntToStr(value, 0x10, result, prefix, width, '0');
+	intToStr(value, 0x10, result, isEnabled(options, Options::PREFIX), width, '0', 0, isEnabled(options, Options::LOWERCASE));
 	return result;
 }
 
 
-#endif // ifdef POCO_LONG_IS_64_BIT
-
+#endif // ifdef POCO_INT64_IS_LONG
 #endif // ifdef POCO_HAVE_INT64
 
 
@@ -855,6 +1011,8 @@ inline std::string NumberFormatter::format(float value)
 
 inline std::string NumberFormatter::format(float value, int precision)
 {
+	if (precision < 0)
+		throw InvalidArgumentException("NumberFormatter::format() requires non-negative precision.");
 	char buffer[POCO_MAX_FLT_STRING_LEN];
 	floatToFixedStr(buffer, POCO_MAX_FLT_STRING_LEN, value, precision);
 	return std::string(buffer);
@@ -863,6 +1021,8 @@ inline std::string NumberFormatter::format(float value, int precision)
 
 inline std::string NumberFormatter::format(float value, int width, int precision)
 {
+	if (precision < 0)
+		throw InvalidArgumentException("NumberFormatter::format() requires non-negative precision.");
 	std::string result;
 	floatToFixedStr(result, value, precision, width);
 	return result;
@@ -879,6 +1039,8 @@ inline std::string NumberFormatter::format(double value)
 
 inline std::string NumberFormatter::format(double value, int precision)
 {
+	if (precision < 0)
+		throw InvalidArgumentException("NumberFormatter::format() requires non-negative precision.");
 	char buffer[POCO_MAX_FLT_STRING_LEN];
 	doubleToFixedStr(buffer, POCO_MAX_FLT_STRING_LEN, value, precision);
 	return std::string(buffer);
@@ -887,6 +1049,8 @@ inline std::string NumberFormatter::format(double value, int precision)
 
 inline std::string NumberFormatter::format(double value, int width, int precision)
 {
+	if (precision < 0)
+		throw InvalidArgumentException("NumberFormatter::format() requires non-negative precision.");
 	std::string result;
 	doubleToFixedStr(result, value, precision, width);
 	return result;
