@@ -68,13 +68,16 @@ public:
 		Pipe* inPipe,
 		Pipe* outPipe,
 		Pipe* errPipe,
-		const EnvImpl& env);
+		const EnvImpl& env,
+		int options = 0);
 	static void killImpl(ProcessHandleImpl& handle);
 	static void killImpl(PIDImpl pid);
 	static bool isRunningImpl(const ProcessHandleImpl& handle);
 	static bool isRunningImpl(PIDImpl pid);
 	static void requestTerminationImpl(PIDImpl pid);
 	static std::string terminationEventName(PIDImpl pid);
+	static bool mustEscapeArg(const std::string& arg);
+	static std::string escapeArg(const std::string& arg);
 };
 
 
