@@ -34,7 +34,7 @@ class NotificationCenter;
 
 
 class Foundation_API Task: public Runnable, public RefCountedObject
-	/// A Task is a subclass of Runnable that has a name 
+	/// A Task is a subclass of Runnable that has a name
 	/// and supports progress reporting and cancellation.
 	///
 	/// A TaskManager object can be used to take care of the
@@ -49,13 +49,13 @@ public:
 		TASK_CANCELLING,
 		TASK_FINISHED
 	};
-	
+
 	Task(const std::string& name);
 		/// Creates the Task.
 
 	const std::string& name() const;
-		/// Returns the task's name.	
-		
+		/// Returns the task's name.
+
 	float progress() const;
 		/// Returns the task's progress.
 		/// The value will be between 0.0 (just started)
@@ -72,11 +72,13 @@ public:
 
 	bool isCancelled() const;
 		/// Returns true if cancellation of the task has been
-		/// requested. 
+		/// requested.
 		///
 		/// A Task's runTask() method should periodically
 		/// call this method and stop whatever it is doing in an
 		/// orderly way when this method returns true.
+		/// If task is cancelled before it had a chance to run,
+		/// runTask() will never be called.
 
 	TaskState state() const;
 		/// Returns the task's current state.
@@ -84,15 +86,20 @@ public:
 	void reset();
 		/// Sets the task's progress to zero and clears the
 		/// cancel flag.
-		
+
 	virtual void runTask() = 0;
 		/// Do whatever the task needs to do. Must
 		/// be overridden by subclasses.
-		
-	void run();
-		/// Calls the task's runTask() method and notifies the owner
-		/// of the task's start and completion.
 
+	void run();
+		/// If task has not been cancelled prior to this call, it
+		/// calls the task's runTask() method and notifies the owner of
+		/// the task's start and completion.
+		/// If task has been cancelled prior to this call, it only sets
+		/// the state to TASK_FINISHED and notifies the owner.
+
+	bool hasOwner() const;
+		/// Returns true iff the task has an owner.
 protected:
 	bool sleep(long milliseconds);
 		/// Suspends the current thread for the specified
@@ -107,7 +114,7 @@ protected:
 		/// A Task should use this method in favor of Thread::sleep().
 
 	bool yield();
-	    /// Yields cpu to other threads
+		/// Yields cpu to other threads
 		///
 		/// If the task is cancelled while it is suspended,
 		/// yield() will return true. If the tasks resumes
@@ -130,28 +137,28 @@ protected:
 
 	void setOwner(TaskManager* pOwner);
 		/// Sets the (optional) owner of the task.
-		
+
 	TaskManager* getOwner() const;
 		/// Returns the owner of the task, which may be NULL.
 
-	void setState(TaskState state);
+	TaskState setState(TaskState state);
 		/// Sets the task's state.
 
 	virtual ~Task();
 		/// Destroys the Task.
-		
+
 private:
 	Task();
 	Task(const Task&);
 	Task& operator = (const Task&);
-	
-	std::string       _name;
-	TaskManager*      _pOwner;
-	float             _progress;
-	TaskState         _state;
-	Event             _cancelEvent;
-	mutable FastMutex _mutex;
-	
+
+	std::string               _name;
+	std::atomic<TaskManager*> _pOwner;
+	std::atomic<float>        _progress;
+	std::atomic<TaskState>    _state;
+	Event                     _cancelEvent;
+	mutable FastMutex         _mutex;
+
 	friend class TaskManager;
 };
 
@@ -167,8 +174,6 @@ inline const std::string& Task::name() const
 
 inline float Task::progress() const
 {
-	FastMutex::ScopedLock lock(_mutex);
-
 	return _progress;
 }
 
@@ -187,12 +192,16 @@ inline Task::TaskState Task::state() const
 
 inline TaskManager* Task::getOwner() const
 {
-	FastMutex::ScopedLock lock(_mutex);
-
 	return _pOwner;
 }
 
 
+inline bool Task::hasOwner() const
+{
+	return _pOwner != nullptr;
+}
+
+
 } // namespace Poco
 
 
