@@ -14,6 +14,8 @@
 
 #include "Poco/DateTime.h"
 #include "Poco/Timespan.h"
+#include "Poco/Exception.h"
+#include "Poco/Format.h"
 #include <algorithm>
 #include <cmath>
 #include <ctime>
@@ -70,16 +72,28 @@ DateTime::DateTime(int year, int month, int day, int hour, int minute, int secon
 	_millisecond(millisecond),
 	_microsecond(microsecond)
 {
-	poco_assert (year >= 0 && year <= 9999);
-	poco_assert (month >= 1 && month <= 12);
-	poco_assert (day >= 1 && day <= daysOfMonth(year, month));
-	poco_assert (hour >= 0 && hour <= 23);
-	poco_assert (minute >= 0 && minute <= 59);
-	poco_assert (second >= 0 && second <= 60); // allow leap seconds
-	poco_assert (millisecond >= 0 && millisecond <= 999);
-	poco_assert (microsecond >= 0 && microsecond <= 999);
-	
-	_utcTime = toUtcTime(toJulianDay(year, month, day)) + 10*(hour*Timespan::HOURS + minute*Timespan::MINUTES + second*Timespan::SECONDS + millisecond*Timespan::MILLISECONDS + microsecond);
+	if (isValid(_year, _month, _day, _hour, _minute, _second, _millisecond, _microsecond))
+	{
+		_utcTime = toUtcTime(toJulianDay(year, month, day)) +
+			10 * (hour*Timespan::HOURS + minute*Timespan::MINUTES + second*Timespan::SECONDS +
+				  millisecond*Timespan::MILLISECONDS + microsecond);
+	}
+	else
+	{
+		throw Poco::InvalidArgumentException(Poco::format("Date time is %d-%d-%dT%d:%d:%d.%d.%d\n"
+			"Valid values:\n"
+			"0 <= year <= 9999\n"
+			"1 <= month <= 12\n"
+			"1 <= day <=  %d\n"
+			"0 <= hour <= 23\n"
+			"0 <= minute <= 59\n"
+			"0 <= second <= 59\n"
+			"0 <= millisecond <= 999\n"
+			"0 <= microsecond <= 999",
+			_year, _month, _day, _hour, _minute,
+			_second, _millisecond, _microsecond,
+			daysOfMonth(_year, _month)));
+	}
 }
 
 
@@ -134,7 +148,7 @@ DateTime& DateTime::operator = (const DateTime& dateTime)
 	return *this;
 }
 
-	
+
 DateTime& DateTime::operator = (const Timestamp& timestamp)
 {
 	_utcTime = timestamp.utcTime();
@@ -172,12 +186,12 @@ DateTime& DateTime::assign(int year, int month, int day, int hour, int minute, i
 	_second      = second;
 	_millisecond = millisecond;
 	_microsecond = microsecond;
-	
+
 	return *this;
 }
 
 
-void DateTime::swap(DateTime& dateTime)
+void DateTime::swap(DateTime& dateTime) noexcept
 {
 	std::swap(_utcTime, dateTime._utcTime);
 	std::swap(_year, dateTime._year);
@@ -212,7 +226,7 @@ int DateTime::daysOfMonth(int year, int month)
 	poco_assert (month >= 1 && month <= 12);
 
 	static int daysOfMonthTable[] = {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
-	
+
 	if (month == 2 && isLeapYear(year))
 		return 29;
 	else
@@ -243,7 +257,7 @@ int DateTime::week(int firstDayOfWeek) const
 	while (DateTime(_year, 1, baseDay).dayOfWeek() != firstDayOfWeek) ++baseDay;
 
 	int doy  = dayOfYear();
-	int offs = baseDay <= 4 ? 0 : 1; 
+	int offs = baseDay <= 4 ? 0 : 1;
 	if (doy < baseDay)
 		return offs;
 	else
@@ -320,7 +334,7 @@ void DateTime::makeUTC(int tzd)
 	operator -= (Timespan(((Timestamp::TimeDiff) tzd)*Timespan::SECONDS));
 }
 
-	
+
 void DateTime::makeLocal(int tzd)
 {
 	operator += (Timespan(((Timestamp::TimeDiff) tzd)*Timespan::SECONDS));
@@ -331,7 +345,7 @@ double DateTime::toJulianDay(int year, int month, int day, int hour, int minute,
 {
 	// lookup table for (153*month - 457)/5 - note that 3 <= month <= 14.
 	static int lookup[] = {-91, -60, -30, 0, 31, 61, 92, 122, 153, 184, 214, 245, 275, 306, 337};
- 
+
 	// day to double
 	double dday = double(day) + ((double((hour*60 + minute)*60 + second)*1000 + millisecond)*1000 + microsecond)/86400000000.0;
 	if (month < 3)
@@ -420,7 +434,14 @@ void DateTime::computeGregorian(double julianDay)
 
 void DateTime::computeDaytime()
 {
-	Timespan span(_utcTime/10);
+	Timestamp::UtcTimeVal ut(_utcTime);
+	if (ut < 0) {
+		// GH3723: UtcTimeVal is negative for pre-gregorian dates
+		// move it 1600 years to the future
+		// keeping hour, minute, second,... for corrections
+		ut += Int64(86400)*1000*1000*10*1600*365;
+	}
+	Timespan span(ut/10);
 	int hour = span.hours();
 	// Due to double rounding issues, the previous call to computeGregorian()
 	// may have crossed into the next or previous day. We need to correct that.
