@@ -92,7 +92,7 @@ std::string EnvironmentImpl::osNameImpl()
 
 std::string EnvironmentImpl::osDisplayNameImpl()
 {
-	OSVERSIONINFOEX vi;	// OSVERSIONINFOEX is supported starting at Windows 2000 
+	OSVERSIONINFOEX vi;	// OSVERSIONINFOEX is supported starting at Windows 2000
 	vi.dwOSVersionInfoSize = sizeof(vi);
 	if (GetVersionEx((OSVERSIONINFO*) &vi) == 0) throw SystemException("Cannot get OS version information");
 	switch (vi.dwMajorVersion)
@@ -101,7 +101,14 @@ std::string EnvironmentImpl::osDisplayNameImpl()
 		switch (vi.dwMinorVersion)
 		{
 		case 0:
-			return vi.wProductType == VER_NT_WORKSTATION ? "Windows 10" : "Windows Server 2016";
+			if (vi.dwBuildNumber >= 22000)
+				return "Windows 11";
+			else if (vi.dwBuildNumber >= 20348 && vi.wProductType != VER_NT_WORKSTATION)
+				return "Windows Server 2022";
+			else if (vi.dwBuildNumber >= 17763 && vi.wProductType != VER_NT_WORKSTATION)
+				return "Windows Server 2019";
+			else
+				return vi.wProductType == VER_NT_WORKSTATION ? "Windows 10" : "Windows Server 2016";
 		}
 	case 6:
 		switch (vi.dwMinorVersion)
@@ -195,37 +202,60 @@ void EnvironmentImpl::nodeIdImpl(NodeId& id)
 {
 	std::memset(&id, 0, sizeof(id));
 
-	PIP_ADAPTER_INFO pAdapterInfo;
-	PIP_ADAPTER_INFO pAdapter = 0;
+	auto pAdapterInfo = std::make_unique<IP_ADAPTER_INFO[]>(1);
 	ULONG len    = sizeof(IP_ADAPTER_INFO);
-	pAdapterInfo = reinterpret_cast<IP_ADAPTER_INFO*>(new char[len]);
+
 	// Make an initial call to GetAdaptersInfo to get
 	// the necessary size into len
-	DWORD rc = GetAdaptersInfo(pAdapterInfo, &len);
-	if (rc == ERROR_BUFFER_OVERFLOW) 
+	const DWORD rc = GetAdaptersInfo(pAdapterInfo.get(), &len);
+
+	if (rc == ERROR_BUFFER_OVERFLOW)
 	{
-		delete [] reinterpret_cast<char*>(pAdapterInfo);
-		pAdapterInfo = reinterpret_cast<IP_ADAPTER_INFO*>(new char[len]);
+		pAdapterInfo = std::make_unique<IP_ADAPTER_INFO[]>(len / sizeof(IP_ADAPTER_INFO));
 	}
 	else if (rc != ERROR_SUCCESS)
 	{
-		return;
+		throw SystemException("cannot get network adapter list");
 	}
-	if (GetAdaptersInfo(pAdapterInfo, &len) == NO_ERROR) 
+
+	if (GetAdaptersInfo(pAdapterInfo.get(), &len) == NO_ERROR)
 	{
-		pAdapter = pAdapterInfo;
-		bool found = false;
-		while (pAdapter && !found) 
+		IP_ADAPTER_INFO* pAdapter = pAdapterInfo.get();
+
+		while (pAdapter)
 		{
 			if (pAdapter->Type == MIB_IF_TYPE_ETHERNET && pAdapter->AddressLength == sizeof(id))
 			{
-				found = true;
 				std::memcpy(&id, pAdapter->Address, pAdapter->AddressLength);
+
+				// found an ethernet adapter, we can return now
+				return;
+			}
+			pAdapter = pAdapter->Next;
+		}
+
+		// if an ethernet adapter was not found, search for a wifi adapter
+		pAdapter = pAdapterInfo.get();
+
+		while (pAdapter)
+		{
+			if (pAdapter->Type == IF_TYPE_IEEE80211 && pAdapter->AddressLength == sizeof(id))
+			{
+				std::memcpy(&id, pAdapter->Address, pAdapter->AddressLength);
+
+				// found a wifi adapter, we can return now
+				return;
 			}
 			pAdapter = pAdapter->Next;
 		}
 	}
-	delete [] reinterpret_cast<char*>(pAdapterInfo);
+	else
+	{
+		throw SystemException("cannot get network adapter list");
+	}
+
+	// ethernet and wifi adapters not found, fail the search
+	throw SystemException("no ethernet or wifi adapter found");
 }
 
 
