@@ -27,6 +27,7 @@ namespace Poco {
 Message::Message():
 	_prio(PRIO_FATAL),
 	_tid(0),
+	_ostid(0),
 	_pid(0),
 	_file(0),
 	_line(0),
@@ -41,6 +42,7 @@ Message::Message(const std::string& source, const std::string& text, Priority pr
 	_text(text),
 	_prio(prio),
 	_tid(0),
+	_ostid(0),
 	_pid(0),
 	_file(0),
 	_line(0),
@@ -55,6 +57,7 @@ Message::Message(const std::string& source, const std::string& text, Priority pr
 	_text(text),
 	_prio(prio),
 	_tid(0),
+	_ostid(0),
 	_pid(0),
 	_file(file),
 	_line(line),
@@ -70,6 +73,7 @@ Message::Message(const Message& msg):
 	_prio(msg._prio),
 	_time(msg._time),
 	_tid(msg._tid),
+	_ostid(msg._ostid),
 	_thread(msg._thread),
 	_pid(msg._pid),
 	_file(msg._file),
@@ -88,6 +92,7 @@ Message::Message(Message&& msg) noexcept:
 	_prio(std::move(msg._prio)),
 	_time(std::move(msg._time)),
 	_tid(std::move(msg._tid)),
+	_ostid(std::move(msg._ostid)),
 	_thread(std::move(msg._thread)),
 	_pid(std::move(msg._pid)),
 	_file(std::move(msg._file)),
@@ -104,6 +109,7 @@ Message::Message(const Message& msg, const std::string& text):
 	_prio(msg._prio),
 	_time(msg._time),
 	_tid(msg._tid),
+	_ostid(msg._ostid),
 	_thread(msg._thread),
 	_pid(msg._pid),
 	_file(msg._file),
@@ -127,6 +133,7 @@ void Message::init()
 #if !defined(POCO_VXWORKS)
 	_pid = Process::id();
 #endif
+	_ostid = (IntPtr)Thread::currentOsTid();
 	Thread* pThread = Thread::current();
 	if (pThread)
 	{
@@ -154,6 +161,7 @@ Message& Message::operator = (Message&& msg) noexcept
 	_prio = std::move(msg._prio);
 	_time = std::move(msg._time);
 	_tid = std::move(msg._tid);
+	_ostid = std::move(msg._ostid);
 	_thread = std::move(msg._thread);
 	_pid = std::move(msg._pid);
 	_file = std::move(msg._file);
@@ -173,6 +181,7 @@ void Message::swap(Message& msg)
 	swap(_prio, msg._prio);
 	swap(_time, msg._time);
 	swap(_tid, msg._tid);
+	swap(_ostid, msg._ostid);
 	swap(_thread, msg._thread);
 	swap(_pid, msg._pid);
 	swap(_file, msg._file);
@@ -266,6 +275,15 @@ const std::string& Message::get(const std::string& param, const std::string& def
 	return defaultValue;
 }
 
+const Message::StringMap& Message::getAll() const
+{
+	static StringMap empty;
+
+	if (_pMap)
+		return *_pMap;
+
+	return empty;
+}
 
 void Message::set(const std::string& param, const std::string& value)
 {
