@@ -14,13 +14,10 @@
 
 #include "Poco/Mutex.h"
 
-
-#if defined(POCO_OS_FAMILY_WINDOWS)
-#if defined(_WIN32_WCE)
-#include "Mutex_WINCE.cpp"
-#else
+#if defined(POCO_ENABLE_STD_MUTEX)
+#include "Mutex_STD.cpp"
+#elif defined(POCO_OS_FAMILY_WINDOWS)
 #include "Mutex_WIN32.cpp"
-#endif
 #elif defined(POCO_VXWORKS)
 #include "Mutex_VX.cpp"
 #else
@@ -51,4 +48,14 @@ FastMutex::~FastMutex()
 }
 
 
+SpinlockMutex::SpinlockMutex()
+{
+}
+
+
+SpinlockMutex::~SpinlockMutex()
+{
+}
+
+
 } // namespace Poco
