@@ -13,23 +13,23 @@
 
 
 #include "Poco/Bugcheck.h"
-
+#include "Poco/NumericString.h"
 
 // +++ double conversion +++
 // don't collide with standalone double_conversion library
 #define double_conversion poco_double_conversion
 #define UNIMPLEMENTED poco_bugcheck
-#include "diy-fp.cc"
+#include "double-conversion.h"
 #include "cached-powers.cc"
 #include "bignum-dtoa.cc"
 #include "bignum.cc"
 #include "fast-dtoa.cc"
 #include "fixed-dtoa.cc"
 #include "strtod.cc"
-#include "double-conversion.cc"
+#include "double-to-string.cc"
+#include "string-to-double.cc"
 // --- double conversion ---
 
-#include "Poco/NumericString.h"
 poco_static_assert(POCO_MAX_FLT_STRING_LEN == double_conversion::kMaxSignificantDecimalDigits);
 #include "Poco/String.h"
 #include <memory>
