@@ -16,39 +16,104 @@
 #include "Poco/Exception.h"
 #include <sstream>
 #if defined(POCO_UNBUNDLED)
-#include <pcre.h>
+#define PCRE2_CODE_UNIT_WIDTH 8
+#include <pcre2.h>
 #else
-#include "pcre_config.h"
-#include "pcre.h"
+#include "pcre2_config.h"
+#include "pcre2.h"
 #endif
 
 
+namespace
+{
+	class MatchData
+	{
+	public:
+		MatchData(pcre2_code_8* code):
+			_match(pcre2_match_data_create_from_pattern_8(reinterpret_cast<pcre2_code_8*>(code), nullptr))
+		{
+			if (!_match) throw Poco::RegularExpressionException("cannot create match data");
+		}
+
+		~MatchData()
+		{
+			if (_match) pcre2_match_data_free_8(_match);
+		}
+
+		std::uint32_t count() const
+		{
+			return pcre2_get_ovector_count_8(_match);
+		}
+
+		const PCRE2_SIZE* data() const
+		{
+			return pcre2_get_ovector_pointer_8(_match);
+		}
+
+		operator pcre2_match_data_8*()
+		{
+			return _match;
+		}
+
+	private:
+		pcre2_match_data_8* _match;
+	};
+}
+
+
 namespace Poco {
 
 
-const int RegularExpression::OVEC_SIZE = 63; // must be multiple of 3
-
-
-RegularExpression::RegularExpression(const std::string& pattern, int options, bool study): _pcre(0), _extra(0)
+RegularExpression::RegularExpression(const std::string& pattern, int options, bool /*study*/): _pcre(nullptr)
 {
-	const char* error;
-	int offs;
-	_pcre = pcre_compile(pattern.c_str(), options, &error, &offs, 0);
+	int errorCode;
+	PCRE2_SIZE errorOffset;
+	unsigned nameCount;
+	unsigned nameEntrySize;
+	unsigned char* nameTable;
+
+	pcre2_compile_context_8* context = pcre2_compile_context_create_8(nullptr);
+	if (!context) throw Poco::RegularExpressionException("cannot create compile context");
+
+	if (options & RE_NEWLINE_LF)
+		pcre2_set_newline_8(context, PCRE2_NEWLINE_LF);
+	else if (options & RE_NEWLINE_CRLF)
+		pcre2_set_newline_8(context, PCRE2_NEWLINE_CRLF);
+	else if (options & RE_NEWLINE_ANY)
+		pcre2_set_newline_8(context, PCRE2_NEWLINE_ANY);
+	else if (options & RE_NEWLINE_ANYCRLF)
+		pcre2_set_newline_8(context, PCRE2_NEWLINE_ANYCRLF);
+	else // default RE_NEWLINE_CR
+		pcre2_set_newline_8(context, PCRE2_NEWLINE_CR);
+
+	_pcre = pcre2_compile_8(reinterpret_cast<const PCRE2_SPTR>(pattern.c_str()), pattern.length(), compileOptions(options), &errorCode, &errorOffset, context);
+	pcre2_compile_context_free_8(context);
+
 	if (!_pcre)
 	{
+		PCRE2_UCHAR buffer[256];
+		pcre2_get_error_message_8(errorCode, buffer, sizeof(buffer));
 		std::ostringstream msg;
-		msg << error << " (at offset " << offs << ")";
+		msg << reinterpret_cast<char*>(buffer) << " (at offset " << errorOffset << ")";
 		throw RegularExpressionException(msg.str());
 	}
-	if (study)
-		_extra = pcre_study(reinterpret_cast<pcre*>(_pcre), 0, &error);
+
+	pcre2_pattern_info_8(reinterpret_cast<pcre2_code_8*>(_pcre), PCRE2_INFO_NAMECOUNT, &nameCount);
+	pcre2_pattern_info_8(reinterpret_cast<pcre2_code_8*>(_pcre), PCRE2_INFO_NAMEENTRYSIZE, &nameEntrySize);
+	pcre2_pattern_info_8(reinterpret_cast<pcre2_code_8*>(_pcre), PCRE2_INFO_NAMETABLE, &nameTable);
+
+	for (int i = 0; i < nameCount; i++)
+	{
+		unsigned char* group = nameTable + 2 + (nameEntrySize * i);
+		int n = pcre2_substring_number_from_name_8(reinterpret_cast<pcre2_code_8*>(_pcre), group);
+		_groups[n] = std::string(reinterpret_cast<char*>(group));
+	}
 }
 
 
 RegularExpression::~RegularExpression()
 {
-	if (_pcre)  pcre_free(reinterpret_cast<pcre*>(_pcre));
-	if (_extra) pcre_free(reinterpret_cast<struct pcre_extra*>(_extra));
+	if (_pcre) pcre2_code_free_8(reinterpret_cast<pcre2_code_8*>(_pcre));
 }
 
 
@@ -56,15 +121,15 @@ int RegularExpression::match(const std::string& subject, std::string::size_type
 {
 	poco_assert (offset <= subject.length());
 
-	int ovec[OVEC_SIZE];
-	int rc = pcre_exec(reinterpret_cast<pcre*>(_pcre), reinterpret_cast<struct pcre_extra*>(_extra), subject.c_str(), int(subject.size()), int(offset), options & 0xFFFF, ovec, OVEC_SIZE);
-	if (rc == PCRE_ERROR_NOMATCH)
+	MatchData matchData(reinterpret_cast<pcre2_code_8*>(_pcre));
+	int rc = pcre2_match_8(reinterpret_cast<pcre2_code_8*>(_pcre), reinterpret_cast<const PCRE2_SPTR>(subject.c_str()), subject.size(), offset, matchOptions(options), matchData, nullptr);
+	if (rc == PCRE2_ERROR_NOMATCH)
 	{
 		mtch.offset = std::string::npos;
 		mtch.length = 0;
 		return 0;
 	}
-	else if (rc == PCRE_ERROR_BADOPTION)
+	else if (rc == PCRE2_ERROR_BADOPTION)
 	{
 		throw RegularExpressionException("bad option");
 	}
@@ -74,10 +139,11 @@ int RegularExpression::match(const std::string& subject, std::string::size_type
 	}
 	else if (rc < 0)
 	{
-		std::ostringstream msg;
-		msg << "PCRE error " << rc;
-		throw RegularExpressionException(msg.str());
+		PCRE2_UCHAR buffer[256];
+		pcre2_get_error_message_8(rc, buffer, sizeof(buffer));
+		throw RegularExpressionException(std::string(reinterpret_cast<char*>(buffer)));
 	}
+	const PCRE2_SIZE* ovec = matchData.data();
 	mtch.offset = ovec[0] < 0 ? std::string::npos : ovec[0];
 	mtch.length = ovec[1] - mtch.offset;
 	return rc;
@@ -90,13 +156,13 @@ int RegularExpression::match(const std::string& subject, std::string::size_type
 
 	matches.clear();
 
-	int ovec[OVEC_SIZE];
-	int rc = pcre_exec(reinterpret_cast<pcre*>(_pcre), reinterpret_cast<struct pcre_extra*>(_extra), subject.c_str(), int(subject.size()), int(offset), options & 0xFFFF, ovec, OVEC_SIZE);
-	if (rc == PCRE_ERROR_NOMATCH)
+	MatchData matchData(reinterpret_cast<pcre2_code_8*>(_pcre));
+	int rc = pcre2_match_8(reinterpret_cast<pcre2_code_8*>(_pcre), reinterpret_cast<const PCRE2_SPTR>(subject.c_str()), subject.size(), offset, options & 0xFFFF, matchData, nullptr);
+	if (rc == PCRE2_ERROR_NOMATCH)
 	{
 		return 0;
 	}
-	else if (rc == PCRE_ERROR_BADOPTION)
+	else if (rc == PCRE2_ERROR_BADOPTION)
 	{
 		throw RegularExpressionException("bad option");
 	}
@@ -106,16 +172,26 @@ int RegularExpression::match(const std::string& subject, std::string::size_type
 	}
 	else if (rc < 0)
 	{
-		std::ostringstream msg;
-		msg << "PCRE error " << rc;
-		throw RegularExpressionException(msg.str());
+		PCRE2_UCHAR buffer[256];
+		pcre2_get_error_message_8(rc, buffer, sizeof(buffer));
+		throw RegularExpressionException(std::string(reinterpret_cast<char*>(buffer)));
 	}
 	matches.reserve(rc);
+	const PCRE2_SIZE* ovec = matchData.data();
 	for (int i = 0; i < rc; ++i)
 	{
 		Match m;
+		GroupMap::const_iterator it;
+
 		m.offset = ovec[i*2] < 0 ? std::string::npos : ovec[i*2] ;
 		m.length = ovec[i*2 + 1] - m.offset;
+
+		it = _groups.find(i);
+		if (it != _groups.end())
+		{
+			m.name = (*it).second;
+		}
+
 		matches.push_back(m);
 	}
 	return rc;
@@ -203,13 +279,13 @@ std::string::size_type RegularExpression::substOne(std::string& subject, std::st
 {
 	if (offset >= subject.length()) return std::string::npos;
 
-	int ovec[OVEC_SIZE];
-	int rc = pcre_exec(reinterpret_cast<pcre*>(_pcre), reinterpret_cast<struct pcre_extra*>(_extra), subject.c_str(), int(subject.size()), int(offset), options & 0xFFFF, ovec, OVEC_SIZE);
-	if (rc == PCRE_ERROR_NOMATCH)
+	MatchData matchData(reinterpret_cast<pcre2_code_8*>(_pcre));
+	int rc = pcre2_match_8(reinterpret_cast<pcre2_code_8*>(_pcre), reinterpret_cast<const PCRE2_SPTR>(subject.c_str()), subject.size(), offset, matchOptions(options), matchData, nullptr);
+	if (rc == PCRE2_ERROR_NOMATCH)
 	{
 		return std::string::npos;
 	}
-	else if (rc == PCRE_ERROR_BADOPTION)
+	else if (rc == PCRE2_ERROR_BADOPTION)
 	{
 		throw RegularExpressionException("bad option");
 	}
@@ -219,10 +295,11 @@ std::string::size_type RegularExpression::substOne(std::string& subject, std::st
 	}
 	else if (rc < 0)
 	{
-		std::ostringstream msg;
-		msg << "PCRE error " << rc;
-		throw RegularExpressionException(msg.str());
+		PCRE2_UCHAR buffer[256];
+		pcre2_get_error_message_8(rc, buffer, sizeof(buffer));
+		throw RegularExpressionException(std::string(reinterpret_cast<char*>(buffer)));
 	}
+	const PCRE2_SIZE* ovec = matchData.data();
 	std::string result;
 	std::string::size_type len = subject.length();
 	std::string::size_type pos = 0;
@@ -246,8 +323,8 @@ std::string::size_type RegularExpression::substOne(std::string& subject, std::st
 							int c = d - '0';
 							if (c < rc)
 							{
-								int o = ovec[c*2];
-								int l = ovec[c*2 + 1] - o;
+								std::size_t o = ovec[c*2];
+								std::size_t l = ovec[c*2 + 1] - o;
 								result.append(subject, o, l);
 							}
 						}
@@ -281,4 +358,56 @@ bool RegularExpression::match(const std::string& subject, const std::string& pat
 }
 
 
+int RegularExpression::compileOptions(int options)
+{
+	int pcreOptions = 0;
+
+	if (options & RE_CASELESS)
+		pcreOptions |= PCRE2_CASELESS;
+	if (options & RE_MULTILINE)
+		pcreOptions |= PCRE2_MULTILINE;
+	if (options & RE_DOTALL)
+		pcreOptions |= PCRE2_DOTALL;
+	if (options & RE_EXTENDED)
+		pcreOptions |= PCRE2_EXTENDED;
+	if (options & RE_ANCHORED)
+		pcreOptions |= PCRE2_ANCHORED;
+	if (options & RE_DOLLAR_ENDONLY)
+		pcreOptions |= PCRE2_DOLLAR_ENDONLY;
+	if (options & RE_UNGREEDY)
+		pcreOptions |= PCRE2_UNGREEDY;
+	if (options & RE_UTF8)
+		pcreOptions |= PCRE2_UTF | PCRE2_UCP;
+	if (options & RE_NO_AUTO_CAPTURE)
+		pcreOptions |= PCRE2_NO_AUTO_CAPTURE;
+	if (options & RE_FIRSTLINE)
+		pcreOptions |= PCRE2_FIRSTLINE;
+	if (options & RE_DUPNAMES)
+		pcreOptions |= PCRE2_DUPNAMES;
+
+	return pcreOptions;
+}
+
+
+int RegularExpression::matchOptions(int options)
+{
+	int pcreOptions = 0;
+
+	if (options & RE_ANCHORED)
+		pcreOptions |= PCRE2_ANCHORED;
+	if (options & RE_NOTBOL)
+		pcreOptions |= PCRE2_NOTBOL;
+	if (options & RE_NOTEOL)
+		pcreOptions |= PCRE2_NOTEOL;
+	if (options & RE_NOTEMPTY)
+		pcreOptions |= PCRE2_NOTEMPTY;
+	if (options & RE_NO_AUTO_CAPTURE)
+		pcreOptions |= PCRE2_NO_AUTO_CAPTURE;
+	if (options & RE_NO_UTF8_CHECK)
+		pcreOptions |= PCRE2_NO_UTF_CHECK;
+
+	return pcreOptions;
+}
+
+
 } // namespace Poco
