@@ -15,10 +15,19 @@
 #include "Poco/Thread_POSIX.h"
 #include "Poco/Thread.h"
 #include "Poco/Exception.h"
+#include "Poco/Error.h"
 #include "Poco/ErrorHandler.h"
 #include "Poco/Timespan.h"
 #include "Poco/Timestamp.h"
+#include "Poco/Format.h"
 #include <signal.h>
+
+#if POCO_OS == POCO_OS_FREE_BSD
+#    include <sys/thr.h>
+#    include <pthread_np.h>
+#    include <osreldate.h>
+#endif
+
 #if defined(__sun) && defined(__SVR4)
 #	if !defined(__EXTENSIONS__)
 #		define __EXTENSIONS__
@@ -28,6 +37,24 @@
 #	include <time.h>
 #endif
 
+#if POCO_OS == POCO_OS_LINUX || POCO_OS == POCO_OS_ANDROID || POCO_OS == POCO_OS_FREE_BSD
+#	include <sys/prctl.h>
+#endif
+
+#if POCO_OS == POCO_OS_LINUX
+	#ifndef _GNU_SOURCE
+		#define _GNU_SOURCE         /* See feature_test_macros(7) */
+	#endif
+	#include <unistd.h>
+	#include <sys/syscall.h>   /* For SYS_xxx definitions */
+#endif
+#include <iostream>
+
+
+#if POCO_OS == POCO_OS_LINUX || POCO_OS == POCO_OS_ANDROID || POCO_OS == POCO_OS_FREE_BSD
+#	include <sys/prctl.h>
+#endif
+
 //
 // Block SIGPIPE in main thread.
 //
@@ -53,29 +80,43 @@ namespace
 }
 #endif
 
-
-#if defined(POCO_POSIX_DEBUGGER_THREAD_NAMES)
-
-
-namespace {
-void setThreadName(pthread_t thread, const std::string& threadName)
+namespace
 {
-#if (POCO_OS == POCO_OS_MAC_OS_X)
-	pthread_setname_np(threadName.c_str()); // __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2)
-#else
-	if (pthread_setname_np(thread, threadName.c_str()) == ERANGE && threadName.size() > 15)
+	std::string truncName(const std::string& name)
 	{
-		std::string truncName(threadName, 0, 7);
-		truncName.append("~");
-		truncName.append(threadName, threadName.size() - 7, 7);
-		pthread_setname_np(thread, truncName.c_str());
+		if (name.size() > POCO_MAX_THREAD_NAME_LEN)
+			return name.substr(0, POCO_MAX_THREAD_NAME_LEN).append("~");
+		return name;
 	}
-#endif
-}
-}
-
 
+	void setThreadName(const std::string& threadName)
+		/// Sets thread name. Support for this feature varies
+		/// on platforms. Any errors are ignored.
+	{
+#if POCO_OS == POCO_OS_FREE_BSD && __FreeBSD_version < 1300000
+		pthread_setname_np(pthread_self(), truncName(threadName).c_str());
+#elif (POCO_OS == POCO_OS_MAC_OS_X)
+	#ifdef __MAC_OS_X_VERSION_MIN_REQUIRED
+		#if __MAC_OS_X_VERSION_MIN_REQUIRED >= 1060
+			pthread_setname_np(truncName(threadName).c_str()); // __OSX_AVAILABLE_STARTING(__MAC_10_6, __IPHONE_3_2)
+		#endif
+	#endif // __MAC_OS_X_VERSION_MIN_REQUIRED
+#else
+		prctl(PR_SET_NAME, truncName(threadName).c_str());
 #endif
+	}
+
+	std::string getThreadName()
+	{
+		char name[POCO_MAX_THREAD_NAME_LEN + 1]{'\0'};
+#if POCO_OS == POCO_OS_LINUX || POCO_OS == POCO_OS_ANDROID || POCO_OS == POCO_OS_FREE_BSD
+		prctl(PR_GET_NAME, name);
+#else
+		pthread_getname_np(pthread_self(), name, POCO_MAX_THREAD_NAME_LEN + 1);
+#endif
+		return name;
+	}
+}
 
 
 namespace Poco {
@@ -98,6 +139,44 @@ ThreadImpl::~ThreadImpl()
 	}
 }
 
+void ThreadImpl::setNameImpl(const std::string& threadName)
+{
+	std::string realName = threadName;
+#if (POCO_OS == POCO_OS_MAC_OS_X)
+	if (threadName.size() > POCO_MAX_THREAD_NAME_LEN)
+	{
+		int half = (POCO_MAX_THREAD_NAME_LEN - 1) / 2;
+#else
+	if (threadName.size() > std::min(POCO_MAX_THREAD_NAME_LEN, 15))
+	{
+		int half = (std::min(POCO_MAX_THREAD_NAME_LEN, 15) - 1) / 2;
+#endif
+		std::string truncName(threadName, 0, half);
+		truncName.append("~");
+		truncName.append(threadName, threadName.size() - half);
+		realName = truncName;
+	}
+
+	ScopedLock<FastMutex> lock(_pData->mutex);
+	if (realName != _pData->name)
+	{
+		_pData->name = realName;
+	}
+}
+
+
+std::string ThreadImpl::getNameImpl() const
+{
+	ScopedLock<FastMutex> lock(_pData->mutex);
+	return _pData->name;
+}
+
+
+std::string ThreadImpl::getOSThreadNameImpl()
+{
+	return isRunningImpl() ? getThreadName() : "";
+}
+
 
 void ThreadImpl::setPriorityImpl(int prio)
 {
@@ -178,10 +257,28 @@ void ThreadImpl::setStackSizeImpl(int size)
 }
 
 
+void ThreadImpl::setSignalMaskImpl(uint32_t sigMask)
+{
+	sigset_t sset;
+	sigemptyset(&sset);
+
+	for (int sig = 0; sig < sizeof(uint32_t) * 8; ++sig)
+	{
+		if ((sigMask & (1 << sig)) != 0)
+			sigaddset(&sset, sig);
+	}
+
+	pthread_sigmask(SIG_BLOCK, &sset, 0);
+}
+
+
 void ThreadImpl::startImpl(SharedPtr<Runnable> pTarget)
 {
-	if (_pData->pRunnableTarget)
-		throw SystemException("thread already running");
+	{
+		FastMutex::ScopedLock l(_pData->mutex);
+		if (_pData->pRunnableTarget)
+			throw SystemException("thread already running");
+	}
 
 	pthread_attr_t attributes;
 	pthread_attr_init(&attributes);
@@ -195,12 +292,15 @@ void ThreadImpl::startImpl(SharedPtr<Runnable> pTarget)
 		}
 	}
 
-	_pData->pRunnableTarget = pTarget;
-	if (pthread_create(&_pData->thread, &attributes, runnableEntry, this))
 	{
-		_pData->pRunnableTarget = 0;
-		pthread_attr_destroy(&attributes);
-		throw SystemException("cannot start thread");
+		FastMutex::ScopedLock l(_pData->mutex);
+		_pData->pRunnableTarget = pTarget;
+		if (pthread_create(&_pData->thread, &attributes, runnableEntry, this))
+		{
+			_pData->pRunnableTarget = 0;
+			pthread_attr_destroy(&attributes);
+			throw SystemException("cannot start thread");
+		}
 	}
 	_pData->started = true;
 	pthread_attr_destroy(&attributes);
@@ -262,59 +362,22 @@ ThreadImpl::TIDImpl ThreadImpl::currentTidImpl()
 	return pthread_self();
 }
 
-
-void ThreadImpl::sleepImpl(long milliseconds)
+long ThreadImpl::currentOsTidImpl()
 {
-#if defined(__digital__)
-		// This is specific to DECThreads
-		struct timespec interval;
-		interval.tv_sec  = milliseconds / 1000;
-		interval.tv_nsec = (milliseconds % 1000)*1000000;
-		pthread_delay_np(&interval);
-#elif POCO_OS == POCO_OS_LINUX || POCO_OS == POCO_OS_ANDROID || POCO_OS == POCO_OS_MAC_OS_X || POCO_OS == POCO_OS_QNX || POCO_OS == POCO_OS_VXWORKS
-	Poco::Timespan remainingTime(1000*Poco::Timespan::TimeDiff(milliseconds));
-	int rc;
-	do
-	{
-		struct timespec ts;
-		ts.tv_sec  = (long) remainingTime.totalSeconds();
-		ts.tv_nsec = (long) remainingTime.useconds()*1000;
-		Poco::Timestamp start;
-		rc = ::nanosleep(&ts, 0);
-		if (rc < 0 && errno == EINTR)
-		{
-			Poco::Timestamp end;
-			Poco::Timespan waited = start.elapsed();
-			if (waited < remainingTime)
-				remainingTime -= waited;
-			else
-				remainingTime = 0;
-		}
+#if defined(POCO_EMSCRIPTEN)
+	return ::pthread_self();
+#elif POCO_OS == POCO_OS_LINUX
+	return ::syscall(SYS_gettid);
+#elif POCO_OS == POCO_OS_MAC_OS_X
+	return ::pthread_mach_thread_np(::pthread_self());
+#elif POCO_OS == POCO_OS_FREE_BSD
+	long id;
+	if(thr_self(&id) < 0) {
+		return 0;
 	}
-	while (remainingTime > 0 && rc < 0 && errno == EINTR);
-	if (rc < 0 && remainingTime > 0) throw Poco::SystemException("Thread::sleep(): nanosleep() failed");
+	return id;
 #else
-	Poco::Timespan remainingTime(1000*Poco::Timespan::TimeDiff(milliseconds));
-	int rc;
-	do
-	{
-		struct timeval tv;
-		tv.tv_sec  = (long) remainingTime.totalSeconds();
-		tv.tv_usec = (long) remainingTime.useconds();
-		Poco::Timestamp start;
-		rc = ::select(0, NULL, NULL, NULL, &tv);
-		if (rc < 0 && errno == EINTR)
-		{
-			Poco::Timestamp end;
-			Poco::Timespan waited = start.elapsed();
-			if (waited < remainingTime)
-				remainingTime -= waited;
-			else
-				remainingTime = 0;
-		}
-	}
-	while (remainingTime > 0 && rc < 0 && errno == EINTR);
-	if (rc < 0 && remainingTime > 0) throw Poco::SystemException("Thread::sleep(): select() failed");
+	return ::pthread_self();
 #endif
 }
 
@@ -333,10 +396,14 @@ void* ThreadImpl::runnableEntry(void* pThread)
 #endif
 
 	ThreadImpl* pThreadImpl = reinterpret_cast<ThreadImpl*>(pThread);
-#if defined(POCO_POSIX_DEBUGGER_THREAD_NAMES)
-	setThreadName(pThreadImpl->_pData->thread, reinterpret_cast<Thread*>(pThread)->getName());
-#endif
+	setThreadName(reinterpret_cast<Thread*>(pThread)->getName());
 	AutoPtr<ThreadData> pData = pThreadImpl->_pData;
+
+	{
+		FastMutex::ScopedLock lock(pData->mutex);
+		setThreadName(pData->name);
+	}
+
 	try
 	{
 		pData->pRunnableTarget->run();
@@ -354,6 +421,7 @@ void* ThreadImpl::runnableEntry(void* pThread)
 		ErrorHandler::handle();
 	}
 
+	FastMutex::ScopedLock l(pData->mutex);
 	pData->pRunnableTarget = 0;
 	pData->done.set();
 	return 0;
@@ -406,4 +474,39 @@ int ThreadImpl::reverseMapPrio(int prio, int policy)
 }
 
 
+bool ThreadImpl::setAffinityImpl(int coreID)
+{
+#if POCO_OS == POCO_OS_LINUX
+	int numCores = sysconf(_SC_NPROCESSORS_ONLN);
+	if (coreID < 0 || coreID >= numCores)
+		return false;
+
+	cpu_set_t cpuset;
+	CPU_ZERO(&cpuset);
+	CPU_SET(coreID, &cpuset);
+
+	return 0 == pthread_setaffinity_np(_pData->thread, sizeof(cpu_set_t), &cpuset);
+#else
+	return false;
+#endif
+}
+
+
+int ThreadImpl::getAffinityImpl() const
+{
+#if POCO_OS == POCO_OS_LINUX
+	cpu_set_t cpuset;
+	CPU_ZERO(&cpuset);
+	if (0 == pthread_getaffinity_np(_pData->thread, sizeof(cpu_set_t), &cpuset))
+	{
+		for (int i = 0; i < CPU_SETSIZE; ++i)
+		{
+			if (CPU_ISSET(i, &cpuset)) return i;
+		}
+	}
+#endif
+	return -1;
+}
+
+
 } // namespace Poco
