@@ -30,9 +30,6 @@
 #endif
 #elif defined(POCO_OS_FAMILY_WINDOWS)
 #include "Poco/UnWindows.h"
-#if defined(_WIN32_WCE)
-#include <cmath>
-#endif
 #endif
 
 
@@ -45,109 +42,6 @@
 #endif
 
 
-#if defined(_WIN32_WCE) && defined(POCO_WINCE_TIMESTAMP_HACK)
-
-
-//
-// See <http://community.opennetcf.com/articles/cf/archive/2007/11/20/getting-a-millisecond-resolution-datetime-under-windows-ce.aspx>
-// for an explanation of the following code.
-//
-// In short: Windows CE system time in most cases only has a resolution of one second.
-// But we want millisecond resolution.
-//
-
-
-namespace {
-
-
-class TickOffset
-{
-public:
-	TickOffset()
-	{
-		SYSTEMTIME st1, st2;
-		std::memset(&st1, 0, sizeof(SYSTEMTIME));
-		std::memset(&st2, 0, sizeof(SYSTEMTIME));
-		GetSystemTime(&st1);
-		while (true)
-		{
-			GetSystemTime(&st2);
-
-			// wait for a rollover
-			if (st1.wSecond != st2.wSecond)
-			{
-				_offset = GetTickCount() % 1000;
-				break;
-			}
-		}
-	}
-
-	void calibrate(int seconds)
-	{
-		SYSTEMTIME st1, st2;
-		systemTime(&st1);
-
-		WORD s = st1.wSecond;
-		int sum = 0;
-		int remaining = seconds;
-		while (remaining > 0)
-		{
-			systemTime(&st2);
-			WORD s2 = st2.wSecond;
-
-			if (s != s2)
-			{
-				remaining--;
-				// store the offset from zero
-				sum += (st2.wMilliseconds > 500) ? (st2.wMilliseconds - 1000) : st2.wMilliseconds;
-				s = st2.wSecond;
-			}
-		}
-
-		// adjust the offset by the average deviation from zero (round to the integer farthest from zero)
-		if (sum < 0)
-			_offset += (int) std::floor(sum / (float)seconds);
-		else
-			_offset += (int) std::ceil(sum / (float)seconds);
-	}
-
-	void systemTime(SYSTEMTIME* pST)
-	{
-		std::memset(pST, 0, sizeof(SYSTEMTIME));
-
-		WORD tick = GetTickCount() % 1000;
-		GetSystemTime(pST);
-		WORD ms = (tick >= _offset) ? (tick - _offset) : (1000 - (_offset - tick));
-		pST->wMilliseconds = ms;
-	}
-
-	void systemTimeAsFileTime(FILETIME* pFT)
-	{
-		SYSTEMTIME st;
-		systemTime(&st);
-		SystemTimeToFileTime(&st, pFT);
-	}
-
-private:
-	WORD _offset;
-};
-
-
-static TickOffset offset;
-
-
-void GetSystemTimeAsFileTimeWithMillisecondResolution(FILETIME* pFT)
-{
-	offset.systemTimeAsFileTime(pFT);
-}
-
-
-} // namespace
-
-
-#endif // defined(_WIN32_WCE) && defined(POCO_WINCE_TIMESTAMP_HACK)
-
-
 namespace Poco {
 
 
@@ -192,7 +86,7 @@ Timestamp& Timestamp::operator = (TimeVal tv)
 }
 
 
-void Timestamp::swap(Timestamp& timestamp)
+void Timestamp::swap(Timestamp& timestamp) noexcept
 {
 	std::swap(_ts, timestamp._ts);
 }
@@ -217,11 +111,7 @@ void Timestamp::update()
 #if defined(POCO_OS_FAMILY_WINDOWS)
 
 	FILETIME ft;
-#if defined(_WIN32_WCE) && defined(POCO_WINCE_TIMESTAMP_HACK)
-	GetSystemTimeAsFileTimeWithMillisecondResolution(&ft);
-#else
 	GetSystemTimeAsFileTime(&ft);
-#endif
 
 	ULARGE_INTEGER epoch; // UNIX epoch (1970-01-01 00:00:00) expressed in Windows NT FILETIME
 	epoch.LowPart  = 0xD53E8000;
