@@ -197,7 +197,7 @@ URI& URI::operator = (const char* uri)
 }
 
 
-void URI::swap(URI& uri)
+void URI::swap(URI& uri) noexcept
 {
 	std::swap(_scheme, uri._scheme);
 	std::swap(_userInfo, uri._userInfo);
@@ -257,7 +257,7 @@ std::string URI::toString() const
 	if (!_fragment.empty())
 	{
 		uri += '#';
-		encode(_fragment, RESERVED_FRAGMENT, uri);
+		uri.append(_fragment);
 	}
 	return uri;
 }
@@ -370,7 +370,7 @@ std::string URI::getQuery() const
 }
 
 
-URI::QueryParameters URI::getQueryParameters() const
+URI::QueryParameters URI::getQueryParameters(bool plusIsSpace) const
 {
 	QueryParameters result;
 	std::string::const_iterator it(_query.begin());
@@ -381,7 +381,7 @@ URI::QueryParameters URI::getQueryParameters() const
 		std::string value;
 		while (it != end && *it != '=' && *it != '&')
 		{
-			if (*it == '+')
+			if (plusIsSpace && (*it == '+'))
 				name += ' ';
 			else
 				name += *it;
@@ -392,7 +392,7 @@ URI::QueryParameters URI::getQueryParameters() const
 			++it;
 			while (it != end && *it != '&')
 			{
-				if (*it == '+')
+				if (plusIsSpace && (*it == '+'))
 					value += ' ';
 				else
 					value += *it;
@@ -420,10 +420,24 @@ void URI::setQueryParameters(const QueryParameters& params)
 }
 
 
+std::string URI::getFragment() const
+{
+	std::string fragment;
+	decode(_fragment, fragment);
+	return fragment;
+}
+
+
 void URI::setFragment(const std::string& fragment)
 {
 	_fragment.clear();
-	decode(fragment, _fragment);
+	encode(fragment, RESERVED_FRAGMENT, _fragment);
+}
+
+
+void URI::setRawFragment(const std::string& fragment)
+{
+	_fragment = fragment;
 }
 
 
@@ -450,7 +464,7 @@ std::string URI::getPathEtc() const
 	if (!_fragment.empty())
 	{
 		pathEtc += '#';
-		encode(_fragment, RESERVED_FRAGMENT, pathEtc);
+		pathEtc += _fragment;
 	}
 	return pathEtc;
 }
@@ -882,9 +896,8 @@ void URI::parseQuery(std::string::const_iterator& it, const std::string::const_i
 
 void URI::parseFragment(std::string::const_iterator& it, const std::string::const_iterator& end)
 {
-	std::string fragment;
-	while (it != end) fragment += *it++;
-	decode(fragment, _fragment);
+	_fragment.clear();
+	while (it != end) _fragment += *it++;
 }
 
 
