@@ -66,15 +66,19 @@ void appendJSONKey(std::string& val, const Var& any)
 }
 
 
-void appendJSONValue(std::string& val, const Var& any)
+void appendJSONValue(std::string& val, const Var& any, bool wrap)
 {
 	if (any.isEmpty())
 	{
 		val.append("null");
 	}
+	else if (any.isString() && any.extract<std::string>().empty())
+	{
+		val.append("\"\"");
+	}
 	else
 	{
-		bool isStr = isJSONString(any);
+		bool isStr = wrap && isJSONString(any);
 		if (isStr)
 		{
 			appendJSONString(val, any.convert<std::string>());
