@@ -231,15 +231,13 @@ void FileTest::testFileAttributes3()
 #else
  	File f("/dev/console");
 #endif
-#elif defined(POCO_OS_FAMILY_WINDOWS) && !defined(_WIN32_WCE)
+#elif defined(POCO_OS_FAMILY_WINDOWS)
 	File f("CON");
 #endif
 
-#if !defined(_WIN32_WCE)
 	assertTrue (f.isDevice());
 	assertTrue (!f.isFile());
 	assertTrue (!f.isDirectory());
-#endif
 }
 
 
@@ -271,12 +269,6 @@ void FileTest::testCompare()
 void FileTest::testRootDir()
 {
 #if defined(POCO_OS_FAMILY_WINDOWS)
-#if defined(_WIN32_WCE)
-	File f1("\\");
-	File f2("/");
-	assertTrue (f1.exists());
-	assertTrue (f2.exists());
-#else
 	File f1("/");
 	File f2("c:/");
 	File f3("c:\\");
@@ -285,7 +277,6 @@ void FileTest::testRootDir()
 	assertTrue (f2.exists());
 	assertTrue (f3.exists());
 	assertTrue (f4.exists());
-#endif
 #else
 	File f1("/");
 	assertTrue (f1.exists());
@@ -380,6 +371,7 @@ void FileTest::testCopy()
 	f1.setWriteable().remove();
 }
 
+
 void FileTest::testCopyFailIfDestinationFileExists()
 {
 	std::ofstream ostr("testfile.dat");
@@ -414,6 +406,7 @@ void FileTest::testMove()
 	assertTrue (f1 == f2);
 }
 
+
 void FileTest::testMoveFailIfDestinationFileExists() {
 	std::ofstream ostr("testfile.dat");
 	ostr << "Hello, world!" << std::endl;
@@ -430,6 +423,7 @@ void FileTest::testMoveFailIfDestinationFileExists() {
 	f1.setWriteable().remove();
 }
 
+
 void FileTest::testCopyDirectory()
 {
 	Path pd1("testdir");
@@ -499,6 +493,7 @@ void FileTest::testCopyDirectory()
 	fd3.remove(true);
 }
 
+
 void FileTest::testCopyDirectoryFailIfExists()
 {
 	Path pd1("testdir");
@@ -538,6 +533,7 @@ void FileTest::testCopyDirectoryFailIfExists()
 	fd2.remove(true);
 }
 
+
 void FileTest::testRename()
 {
 	std::ofstream ostr("testfile.dat");
@@ -555,6 +551,7 @@ void FileTest::testRename()
 	f2.remove();
 }
 
+
 void FileTest::testRenameFailIfExists() {
 	std::ofstream ostr("testfile.dat");
 	ostr << "Hello, world!" << std::endl;
@@ -580,11 +577,9 @@ void FileTest::testRenameFailIfExists() {
 }
 
 
-
-
 void FileTest::testLongPath()
 {
-#if defined(_WIN32) && !defined(_WIN32_WCE)
+#if defined(_WIN32)
 	Poco::Path p("longpathtest");
 	p.makeAbsolute();
 	std::string longpath(p.toString());
@@ -605,6 +600,34 @@ void FileTest::testLongPath()
 #endif
 }
 
+void FileTest::testUnixFileExtension()
+{
+	std::string filePath1 = "/a/b/c/.notextension";
+	Poco::Path path1(filePath1, Poco::Path::Style::PATH_UNIX);
+
+	assertEqual(".notextension", path1.getBaseName());
+	assertEqual("", path1.getExtension());
+
+	std::string filePath2 = "/a/b/c/emptyextension.";
+	Poco::Path path2(filePath2, Poco::Path::Style::PATH_UNIX);
+
+	assertEqual("emptyextension", path2.getBaseName());
+	assertEqual("", path2.getExtension());
+}
+
+
+void FileTest::testTemporaryFile()
+{
+	const int COUNT = 10000;
+	std::set<std::string> paths;
+	for (int i = 0; i < COUNT; i++)
+	{
+		Poco::TemporaryFile f;
+		paths.insert(f.path());
+	}
+	assertTrue (paths.size() == COUNT);
+}
+
 
 void FileTest::setUp()
 {
@@ -654,6 +677,8 @@ CppUnit::Test* FileTest::suite()
 	CppUnit_addTest(pSuite, FileTest, testRenameFailIfExists);
 	CppUnit_addTest(pSuite, FileTest, testRootDir);
 	CppUnit_addTest(pSuite, FileTest, testLongPath);
+	CppUnit_addTest(pSuite, FileTest, testUnixFileExtension);
+	CppUnit_addTest(pSuite, FileTest, testTemporaryFile);
 
 	return pSuite;
 }
