@@ -19,6 +19,12 @@
 #include <iostream>
 
 
+#ifdef POCO_COMPILER_MSVC
+#pragma warning(push)
+#pragma warning(disable : 4834) // divide by zero
+#endif // POCO_COMPILER_MSVC
+
+
 using Poco::LinearHashTable;
 using Poco::Hash;
 using Poco::HashTable;
@@ -41,9 +47,9 @@ void LinearHashTableTest::testInsert()
 	const int N = 1000;
 
 	LinearHashTable<int, Hash<int> > ht;
-	
+
 	assertTrue (ht.empty());
-	
+
 	for (int i = 0; i < N; ++i)
 	{
 		std::pair<LinearHashTable<int, Hash<int> >::Iterator, bool> res = ht.insert(i);
@@ -53,18 +59,18 @@ void LinearHashTableTest::testInsert()
 		assertTrue (it != ht.end());
 		assertTrue (*it == i);
 		assertTrue (ht.size() == i + 1);
-	}		
+	}
 	assertTrue (ht.buckets() == N + 1);
-	
+
 	assertTrue (!ht.empty());
-	
+
 	for (int i = 0; i < N; ++i)
 	{
 		LinearHashTable<int, Hash<int> >::Iterator it = ht.find(i);
 		assertTrue (it != ht.end());
 		assertTrue (*it == i);
 	}
-	
+
 	for (int i = 0; i < N; ++i)
 	{
 		std::pair<LinearHashTable<int, Hash<int> >::Iterator, bool> res = ht.insert(i);
@@ -72,7 +78,7 @@ void LinearHashTableTest::testInsert()
 		assertTrue (!res.second);
 		assertTrue (ht.size() == N);
 		assertTrue (ht.buckets() == N + 1);
-	}		
+	}
 }
 
 
@@ -87,7 +93,7 @@ void LinearHashTableTest::testErase()
 		ht.insert(i);
 	}
 	assertTrue (ht.size() == N);
-	
+
 	for (int i = 0; i < N; i += 2)
 	{
 		ht.erase(i);
@@ -95,13 +101,13 @@ void LinearHashTableTest::testErase()
 		assertTrue (it == ht.end());
 	}
 	assertTrue (ht.size() == N/2);
-	
+
 	for (int i = 0; i < N; i += 2)
 	{
 		LinearHashTable<int, Hash<int> >::Iterator it = ht.find(i);
 		assertTrue (it == ht.end());
 	}
-	
+
 	for (int i = 1; i < N; i += 2)
 	{
 		LinearHashTable<int, Hash<int> >::Iterator it = ht.find(i);
@@ -113,7 +119,7 @@ void LinearHashTableTest::testErase()
 	{
 		ht.insert(i);
 	}
-	
+
 	for (int i = 0; i < N; ++i)
 	{
 		LinearHashTable<int, Hash<int> >::Iterator it = ht.find(i);
@@ -133,7 +139,7 @@ void LinearHashTableTest::testIterator()
 	{
 		ht.insert(i);
 	}
-	
+
 	std::set<int> values;
 	LinearHashTable<int, Hash<int> >::Iterator it = ht.begin();
 	while (it != ht.end())
@@ -142,7 +148,7 @@ void LinearHashTableTest::testIterator()
 		values.insert(*it);
 		++it;
 	}
-	
+
 	assertTrue (values.size() == N);
 }
 
@@ -166,9 +172,9 @@ void LinearHashTableTest::testConstIterator()
 		values.insert(*it);
 		++it;
 	}
-	
+
 	assertTrue (values.size() == N);
-	
+
 	values.clear();
 	const LinearHashTable<int, Hash<int> > cht(ht);
 
@@ -179,8 +185,8 @@ void LinearHashTableTest::testConstIterator()
 		values.insert(*cit);
 		++cit;
 	}
-	
-	assertTrue (values.size() == N);	
+
+	assertTrue (values.size() == N);
 }
 
 
@@ -199,7 +205,7 @@ void LinearHashTableTest::testPerformanceInt()
 		sw.stop();
 		std::cout << "Insert LHT: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -212,7 +218,7 @@ void LinearHashTableTest::testPerformanceInt()
 
 	{
 		HashTable<int, int> ht;
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -221,7 +227,7 @@ void LinearHashTableTest::testPerformanceInt()
 		sw.stop();
 		std::cout << "Insert HT: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -230,7 +236,7 @@ void LinearHashTableTest::testPerformanceInt()
 		sw.stop();
 		std::cout << "Find HT: " << sw.elapsedSeconds() << std::endl;
 	}
-	
+
 	{
 		std::set<int> s;
 		sw.start();
@@ -241,17 +247,17 @@ void LinearHashTableTest::testPerformanceInt()
 		sw.stop();
 		std::cout << "Insert set: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
-			s.find(i);
+			auto it = s.find(i);
 		}
 		sw.stop();
 		std::cout << "Find set: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
 	}
-	
+
 }
 
 
@@ -259,7 +265,7 @@ void LinearHashTableTest::testPerformanceStr()
 {
 	const int N = 5000000;
 	Stopwatch sw;
-	
+
 	std::vector<std::string> values;
 	for (int i = 0; i < N; ++i)
 	{
@@ -276,7 +282,7 @@ void LinearHashTableTest::testPerformanceStr()
 		sw.stop();
 		std::cout << "Insert LHT: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -289,7 +295,7 @@ void LinearHashTableTest::testPerformanceStr()
 
 	{
 		HashTable<std::string, int> ht;
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -298,7 +304,7 @@ void LinearHashTableTest::testPerformanceStr()
 		sw.stop();
 		std::cout << "Insert HT: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
@@ -307,7 +313,7 @@ void LinearHashTableTest::testPerformanceStr()
 		sw.stop();
 		std::cout << "Find HT: " << sw.elapsedSeconds() << std::endl;
 	}
-	
+
 	{
 		std::set<std::string> s;
 		sw.start();
@@ -318,11 +324,11 @@ void LinearHashTableTest::testPerformanceStr()
 		sw.stop();
 		std::cout << "Insert set: " << sw.elapsedSeconds() << std::endl;
 		sw.reset();
-		
+
 		sw.start();
 		for (int i = 0; i < N; ++i)
 		{
-			s.find(values[i]);
+			auto it = s.find(values[i]);
 		}
 		sw.stop();
 		std::cout << "Find set: " << sw.elapsedSeconds() << std::endl;
@@ -354,3 +360,7 @@ CppUnit::Test* LinearHashTableTest::suite()
 
 	return pSuite;
 }
+
+#ifdef POCO_COMPILER_MSVC
+#pragma warning(pop)
+#endif // POCO_COMPILER_MSVC
