@@ -13,6 +13,7 @@
 #include "CppUnit/TestSuite.h"
 #include "Poco/ObjectPool.h"
 #include "Poco/Exception.h"
+#include "Poco/Thread.h"
 
 
 using Poco::ObjectPool;
@@ -30,18 +31,18 @@ ObjectPoolTest::~ObjectPoolTest()
 
 void ObjectPoolTest::testObjectPool()
 {
-	ObjectPool<std::string, Poco::SharedPtr<std::string> > pool(3, 4);
-	
+	ObjectPool<std::string, Poco::SharedPtr<std::string>> pool(3, 4);
+
 	assertTrue (pool.capacity() == 3);
 	assertTrue (pool.peakCapacity() == 4);
 	assertTrue (pool.size() == 0);
 	assertTrue (pool.available() == 4);
-	
+
 	Poco::SharedPtr<std::string> pStr1 = pool.borrowObject();
 	pStr1->assign("first");
 	assertTrue (pool.size() == 1);
 	assertTrue (pool.available() == 3);
-	
+
 	Poco::SharedPtr<std::string> pStr2 = pool.borrowObject();
 	pStr2->assign("second");
 	assertTrue (pool.size() == 2);
@@ -51,19 +52,19 @@ void ObjectPoolTest::testObjectPool()
 	pStr3->assign("third");
 	assertTrue (pool.size() == 3);
 	assertTrue (pool.available() == 1);
-	
+
 	Poco::SharedPtr<std::string> pStr4 = pool.borrowObject();
 	pStr4->assign("fourth");
 	assertTrue (pool.size() == 4);
 	assertTrue (pool.available() == 0);
-	
+
 	Poco::SharedPtr<std::string> pStr5 = pool.borrowObject();
 	assertTrue (pStr5.isNull());
-	
+
 	pool.returnObject(pStr4);
 	assertTrue (pool.size() == 4);
 	assertTrue (pool.available() == 1);
-	
+
 	pool.returnObject(pStr3);
 	assertTrue (pool.size() == 4);
 	assertTrue (pool.available() == 2);
@@ -75,10 +76,10 @@ void ObjectPoolTest::testObjectPool()
 	pool.returnObject(pStr3);
 	pool.returnObject(pStr2);
 	pool.returnObject(pStr1);
-	
+
 	assertTrue (pool.size() == 3);
 	assertTrue (pool.available() == 4);
-	
+
 	pStr1 = pool.borrowObject();
 	assertTrue (*pStr1 == "second");
 	assertTrue (pool.available() == 3);
@@ -88,6 +89,27 @@ void ObjectPoolTest::testObjectPool()
 }
 
 
+void ObjectPoolTest::testObjectPoolWaitOnBorrowObject()
+{
+	ObjectPool<std::string, Poco::SharedPtr<std::string>> pool(1, 1);
+
+	Poco::SharedPtr<std::string> objectToReturnDuringBorrow = pool.borrowObject();
+
+	Poco::Thread threadToReturnObject;
+	threadToReturnObject.startFunc(
+		[&pool, &objectToReturnDuringBorrow]()
+		{
+			pool.returnObject(objectToReturnDuringBorrow);
+		}
+	);
+
+	Poco::SharedPtr<std::string> object = pool.borrowObject(1000);
+
+	threadToReturnObject.join();
+	assertFalse(object.isNull());
+}
+
+
 void ObjectPoolTest::setUp()
 {
 }
@@ -103,6 +125,7 @@ CppUnit::Test* ObjectPoolTest::suite()
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("ObjectPoolTest");
 
 	CppUnit_addTest(pSuite, ObjectPoolTest, testObjectPool);
+	CppUnit_addTest(pSuite, ObjectPoolTest, testObjectPoolWaitOnBorrowObject);
 
 	return pSuite;
 }
