@@ -14,12 +14,15 @@
 #include "Poco/Process.h"
 #include "Poco/Pipe.h"
 #include "Poco/PipeStream.h"
+#include "Poco/Path.h"
+#include "Poco/Format.h"
 
 
 using namespace std::string_literals;
 using Poco::Process;
 using Poco::ProcessHandle;
 using Poco::Pipe;
+using Poco::Path;
 using Poco::PipeInputStream;
 using Poco::PipeOutputStream;
 
@@ -62,10 +65,6 @@ void ProcessTest::testLaunch()
 
 #if defined(POCO_OS_FAMILY_UNIX)
 	cmd += name;
-#elif defined(_WIN32_WCE)
-	cmd = "\\";
-	cmd += name;
-	cmd += ".EXE";
 #else
 	cmd = name;
 #endif
@@ -82,7 +81,6 @@ void ProcessTest::testLaunch()
 
 void ProcessTest::testLaunchRedirectIn()
 {
-#if !defined(_WIN32_WCE)
 	std::string name("TestApp");
 	std::string cmd;
 #if defined(_DEBUG) && (POCO_OS != POCO_OS_ANDROID)
@@ -104,13 +102,11 @@ void ProcessTest::testLaunchRedirectIn()
 	ostr.close();
 	int rc = ph.wait();
 	assertTrue (rc == 100);
-#endif // !defined(_WIN32_WCE)
 }
 
 
 void ProcessTest::testLaunchRedirectOut()
 {
-#if !defined(_WIN32_WCE)
 	std::string name("TestApp");
 	std::string cmd;
 #if defined(_DEBUG) && (POCO_OS != POCO_OS_ANDROID)
@@ -134,13 +130,11 @@ void ProcessTest::testLaunchRedirectOut()
 	assertTrue (s == "Hello, world!");
 	int rc = ph.wait();
 	assertTrue (rc == 1);
-#endif // !defined(_WIN32_WCE)
 }
 
 
 void ProcessTest::testLaunchEnv()
 {
-#if !defined(_WIN32_WCE)
 	std::string name("TestApp");
 	std::string cmd;
 #if defined(_DEBUG) && (POCO_OS != POCO_OS_ANDROID)
@@ -166,13 +160,12 @@ void ProcessTest::testLaunchEnv()
 	assertTrue (s == "test");
 	int rc = ph.wait();
 	assertTrue (rc == 0);
-#endif // !defined(_WIN32_WCE)
 }
 
 
 void ProcessTest::testLaunchArgs()
 {
-#if defined (_WIN32) && !defined(_WIN32_WCE)
+#if defined (_WIN32)
 	std::string name("TestApp");
 #if defined(_DEBUG)
 	name += 'd';
@@ -208,7 +201,7 @@ void ProcessTest::testLaunchArgs()
 			std::string expectedArg = args[argNumber];
 			if (expectedArg.npos != expectedArg.find("already quoted")) {
 				expectedArg = "already quoted \" \\";
-			} 
+			}
 			assertTrue (receivedArg == expectedArg);
 			++argNumber;
 			receivedArg = "";
@@ -222,13 +215,46 @@ void ProcessTest::testLaunchArgs()
 	assertTrue (argNumber == args.size());
 	int rc = ph.wait();
 	assertTrue (rc == args.size());
-#endif // !defined(_WIN32_WCE)
+#endif // defined (_WIN32)
+}
+
+
+void ProcessTest::testLaunchInvalidCommand()
+{
+	std::string name("InvalidCmd");
+	std::string cmd;
+#if defined(_DEBUG) && (POCO_OS != POCO_OS_ANDROID)
+	name += "d";
+#endif
+
+#if defined(POCO_OS_FAMILY_UNIX)
+	cmd += name;
+#else
+	cmd = name;
+#endif
+
+	std::vector<std::string> args;
+	args.push_back("arg1");
+	args.push_back("arg2");
+	args.push_back("arg3");
+#if defined(POCO_OS_FAMILY_UNIX)
+	ProcessHandle ph = Process::launch(cmd, args);
+	int rc = ph.wait();
+	assertTrue (rc == 72);
+#elif defined(POCO_OS_FAMILY_WINDOWS)
+	try
+	{
+		ProcessHandle ph = Process::launch(cmd, args);
+		int rc = ph.wait();
+		fail("must fail");
+	}
+	catch (...){}
+#endif
 }
 
 
 void ProcessTest::testIsRunning()
 {
-#if !defined(_WIN32_WCE)
 	std::string name("TestApp");
 	std::string cmd;
 #if defined(_DEBUG) && (POCO_OS != POCO_OS_ANDROID)
@@ -254,7 +280,6 @@ void ProcessTest::testIsRunning()
 	int POCO_UNUSED rc = ph.wait();
 	assertTrue (!Process::isRunning(ph));
 	assertTrue (!Process::isRunning(id));
-#endif // !defined(_WIN32_WCE)
 }
 
 
@@ -278,6 +303,7 @@ CppUnit::Test* ProcessTest::suite()
 	CppUnit_addTest(pSuite, ProcessTest, testLaunchRedirectOut);
 	CppUnit_addTest(pSuite, ProcessTest, testLaunchEnv);
 	CppUnit_addTest(pSuite, ProcessTest, testLaunchArgs);
+	CppUnit_addTest(pSuite, ProcessTest, testLaunchInvalidCommand);
 	CppUnit_addTest(pSuite, ProcessTest, testIsRunning);
 
 	return pSuite;
