@@ -15,6 +15,7 @@
 #include "Poco/Thread.h"
 #include "Poco/Event.h"
 #include "Poco/AutoPtr.h"
+#include <iostream>
 
 
 using Poco::Task;
@@ -28,30 +29,60 @@ namespace
 	class TestTask: public Task
 	{
 	public:
-		TestTask(): Task("TestTask")
+		TestTask(): Task("TestTask"),
+			_started(false)
 		{
 		}
-		
+
 		void runTask()
 		{
-			_event.wait();
-			if (sleep(10))
-				return;
-			setProgress(0.5);
-			_event.wait();
-			if (isCancelled())
-				return;
-			setProgress(1.0);
-			_event.wait();
+			_started = true;
+			try
+			{
+				_event.wait();
+				if (sleep(100))
+					return;
+				setProgress(0.5);
+				_event.wait();
+				if (isCancelled())
+					return;
+				setProgress(1.0);
+				_event.wait();
+			}
+			catch(const Poco::Exception& e)
+			{
+				std::cerr << "TestTask::run(): " << e.displayText() << '\n';
+			}
+			catch(const std::exception& e)
+			{
+				std::cerr << "TestTask::run(): " << e.what() << '\n';
+			}
+			catch(...)
+			{
+				std::cerr << "TestTask::run(): unknown exception." << '\n';
+			}
 		}
-		
+
 		void cont()
 		{
-			_event.set();
+			try
+			{
+				_event.set();
+			}
+			catch(const Poco::SystemException& e)
+			{
+				std::cerr << "TestTask::cont(): " << e.displayText() << '\n';
+			}
 		}
-		
+
+		bool started() const
+		{
+			return _started;
+		}
+
 	private:
 		Event _event;
+		std::atomic<bool> _started;
 	};
 }
 
@@ -81,6 +112,20 @@ void TaskTest::testFinish()
 	pTT->cont();
 	thr.join();
 	assertTrue (pTT->state() == Task::TASK_FINISHED);
+
+	pTT->reset();
+	assertTrue (pTT->progress() == 0);
+	assertTrue (pTT->state() == Task::TASK_IDLE);
+	thr.start(*pTT);
+	assertTrue (pTT->progress() == 0);
+	pTT->cont();
+	while (pTT->progress() != 0.5) Thread::sleep(50);
+	assertTrue (pTT->state() == Task::TASK_RUNNING);
+	pTT->cont();
+	while (pTT->progress() != 1.0) Thread::sleep(50);
+	pTT->cont();
+	thr.join();
+	assertTrue (pTT->state() == Task::TASK_FINISHED);
 }
 
 
@@ -108,6 +153,8 @@ void TaskTest::testCancel2()
 	assertTrue (pTT->state() == Task::TASK_IDLE);
 	Thread thr;
 	thr.start(*pTT);
+	while (pTT->state() != Task::TASK_RUNNING)
+		Thread::sleep(50);
 	assertTrue (pTT->progress() == 0);
 	pTT->cancel();
 	assertTrue (pTT->state() == Task::TASK_CANCELLING);
@@ -117,6 +164,21 @@ void TaskTest::testCancel2()
 }
 
 
+void TaskTest::testCancelNoStart()
+{
+	AutoPtr<TestTask> pTT = new TestTask;
+	assertTrue (pTT->state() == Task::TASK_IDLE);
+	pTT->cancel();
+	assertTrue (pTT->state() == Task::TASK_CANCELLING);
+	Thread thr;
+	thr.start(*pTT);
+	while (pTT->state() != Task::TASK_FINISHED)
+		Thread::sleep(50);
+	assertTrue (pTT->state() == Task::TASK_FINISHED);
+	assertFalse (pTT->started());
+}
+
+
 void TaskTest::setUp()
 {
 }
@@ -134,6 +196,7 @@ CppUnit::Test* TaskTest::suite()
 	CppUnit_addTest(pSuite, TaskTest, testFinish);
 	CppUnit_addTest(pSuite, TaskTest, testCancel1);
 	CppUnit_addTest(pSuite, TaskTest, testCancel2);
+	CppUnit_addTest(pSuite, TaskTest, testCancelNoStart);
 
 	return pSuite;
 }
