@@ -67,7 +67,11 @@ public:
 	void testComment();
 	void testPrintHandler();
 	void testStringify();
+	void testStringifyNaN();
 	void testStringifyPreserveOrder();
+	void testVarConvert();
+
+	void testBasicJson();
 
 	void testValidJanssonFiles();
 	void testInvalidJanssonFiles();
