@@ -48,19 +48,14 @@ public:
 		/// The socket will be created for the
 		/// given address family.
 
-	DatagramSocket(const SocketAddress& address, bool reuseAddress = false);
-		/// Creates a datagram socket and binds it
-		/// to the given address.
-		///
-		/// Depending on the address family, the socket
-		/// will be either an IPv4 or an IPv6 socket.
-
-	DatagramSocket(const SocketAddress& address, bool reuseAddress, bool reusePort);
+	DatagramSocket(const SocketAddress& address, bool reuseAddress, bool reusePort = false, bool ipV6Only = false);
 		/// Creates a datagram socket and binds it
 		/// to the given address.
 		///
 		/// Depending on the address family, the socket
 		/// will be either an IPv4 or an IPv6 socket.
+		/// If ipV6Only is true, socket will be bound
+		/// to the IPv6 address only.
 
 	DatagramSocket(const Socket& socket);
 		/// Creates the DatagramSocket with the SocketImpl
@@ -68,6 +63,10 @@ public:
 		/// a DatagramSocketImpl, otherwise an InvalidArgumentException
 		/// will be thrown.
 
+	DatagramSocket(const DatagramSocket& socket);
+		/// Creates the DatagramSocket with the SocketImpl
+		/// from another socket.
+
 	~DatagramSocket();
 		/// Destroys the DatagramSocket.
 
@@ -78,6 +77,43 @@ public:
 		/// attaches the SocketImpl from the other socket and
 		/// increments the reference count of the SocketImpl.
 
+#if POCO_NEW_STATE_ON_MOVE
+
+	DatagramSocket(Socket&& socket);
+		/// Creates the DatagramSocket with the SocketImpl
+		/// from another socket and zeroes the other socket's
+		/// SocketImpl.The SocketImpl must be
+		/// a DatagramSocketImpl, otherwise an InvalidArgumentException
+		/// will be thrown.
+
+	DatagramSocket(DatagramSocket&& socket);
+		/// Creates the DatagramSocket with the SocketImpl
+		/// from another socket and zeroes the other socket's
+		/// SocketImpl.
+
+	DatagramSocket& operator = (Socket&& socket);
+		/// Assignment move operator.
+		///
+		/// Releases the socket's SocketImpl and
+		/// attaches the SocketImpl from the other socket and
+		/// zeroes the other socket's SocketImpl.
+
+	DatagramSocket& operator = (DatagramSocket&& socket);
+		/// Assignment move operator.
+		///
+		/// Releases the socket's SocketImpl and
+		/// attaches the SocketImpl from the other socket and
+		/// zeroes the other socket's SocketImpl.
+
+#endif // POCO_NEW_STATE_ON_MOVE
+
+	DatagramSocket& operator = (const DatagramSocket& socket);
+		/// Assignment operator.
+		///
+		/// Releases the socket's SocketImpl and
+		/// attaches the SocketImpl from the other socket and
+		/// increments the reference count of the SocketImpl.
+
 	void connect(const SocketAddress& address);
 		/// Restricts incoming and outgoing
 		/// packets to the specified address.
@@ -109,6 +145,23 @@ public:
 		///
 		/// Calls to connect cannot() come before calls to bind().
 
+	void bind6(const SocketAddress& address, bool reuseAddress, bool reusePort, bool ipV6Only = false);
+		/// Bind a local address to the socket.
+		///
+		/// This is usually only done when establishing a server
+		/// socket.
+		///
+		/// If reuseAddress is true, sets the SO_REUSEADDR
+		/// socket option.
+		///
+		/// If reusePort is true, sets the SO_REUSEPORT
+		/// socket option.
+		///
+		/// Sets the IPV6_V6ONLY socket option in accordance with
+		/// the supplied ipV6Only value.
+		///
+		/// Calls to connect cannot() come before calls to bind().
+
 	int sendBytes(const void* buffer, int length, int flags = 0);
 		/// Sends the contents of the given buffer through
 		/// the socket.
@@ -231,7 +284,7 @@ protected:
 		/// Creates the Socket and attaches the given SocketImpl.
 		/// The socket takes ownership of the SocketImpl.
 		///
-		/// The SocketImpl must be a StreamSocketImpl, otherwise
+		/// The SocketImpl must be a DatagramSocketImpl, otherwise
 		/// an InvalidArgumentException will be thrown.
 };
 
