@@ -18,12 +18,15 @@
 #include "Poco/DateTimeFormatter.h"
 #include "Poco/Exception.h"
 #include "Poco/MD5Engine.h"
+#include "Poco/SHA1Engine.h"
+#include "Poco/SHA2Engine.h"
 #include "Poco/Net/HTTPDigestCredentials.h"
 #include "Poco/Net/HTTPRequest.h"
 #include "Poco/Net/HTTPResponse.h"
 #include "Poco/NumberFormatter.h"
 #include "Poco/StringTokenizer.h"
 
+#include <iostream>
 
 namespace
 {
@@ -68,7 +71,28 @@ namespace Net {
 
 
 const std::string HTTPDigestCredentials::SCHEME = "Digest";
-const std::string HTTPDigestCredentials::DEFAULT_ALGORITHM("MD5");
+const std::vector<std::string> HTTPDigestCredentials::SUPPORTED_ALGORITHMS = {
+	"MD5",
+	"MD5-sess",
+	"SHA",
+	"SHA-sess",
+	"SHA-256",
+	"SHA-256-sess",
+	"SHA-512-256",
+	"SHA-512-256-sess",
+	"SHA-512",
+	"SHA-512-sess"
+};
+const std::string HTTPDigestCredentials::MD_5_ALGORITHM = "MD5";
+const std::string HTTPDigestCredentials::MD_5_SESS_ALGORITHM = "MD5-sess";
+const std::string HTTPDigestCredentials::SHA_ALGORITHM = "SHA";
+const std::string HTTPDigestCredentials::SHA_SESS_ALGORITHM = "SHA-sess";
+const std::string HTTPDigestCredentials::SHA_256_ALGORITHM = "SHA-256";
+const std::string HTTPDigestCredentials::SHA_256_SESS_ALGORITHM = "SHA-256-sess";
+const std::string HTTPDigestCredentials::SHA_512_256_ALGORITHM = "SHA-512-256";
+const std::string HTTPDigestCredentials::SHA_512_256_SESS_ALGORITHM = "SHA-512-256-sess";
+const std::string HTTPDigestCredentials::SHA_512_ALGORITHM = "SHA-512";
+const std::string HTTPDigestCredentials::SHA_512_SESS_ALGORITHM = "SHA-512-sess";
 const std::string HTTPDigestCredentials::DEFAULT_QOP("");
 const std::string HTTPDigestCredentials::NONCE_PARAM("nonce");
 const std::string HTTPDigestCredentials::REALM_PARAM("realm");
@@ -84,6 +108,44 @@ const std::string HTTPDigestCredentials::NC_PARAM("nc");
 int HTTPDigestCredentials::_nonceCounter(0);
 Poco::FastMutex HTTPDigestCredentials::_nonceMutex;
 
+class HTTPDigestCredentials::DigestEngineProvider {
+public:
+	DigestEngineProvider(std::string algorithm): _algorithm(algorithm) {
+		_isSessionAlgorithm = _algorithm.find("sess") != std::string::npos;
+	}
+
+	DigestEngine& engine() {
+		if (icompare(_algorithm, SHA_ALGORITHM) == 0 || icompare(_algorithm, SHA_SESS_ALGORITHM) == 0)
+		{
+			return _sha1Engine;
+		}
+		if (icompare(_algorithm, SHA_256_ALGORITHM) == 0 || icompare(_algorithm, SHA_256_SESS_ALGORITHM) == 0)
+		{
+			return _sha256Engine;
+		} else if (icompare(_algorithm, SHA_512_256_ALGORITHM) == 0 || icompare(_algorithm, SHA_512_256_SESS_ALGORITHM) == 0)
+		{
+			return _sha512_256Engine;
+		} else if (icompare(_algorithm, SHA_512_ALGORITHM) == 0 || icompare(_algorithm, SHA_512_SESS_ALGORITHM) == 0)
+		{
+			return _sha512;
+		}
+		else {
+			return _md5Engine;
+		}
+	}
+
+	bool isSessionAlgorithm() {
+		return _isSessionAlgorithm;
+	}
+private:
+	std::string _algorithm;
+	SHA1Engine _sha1Engine;
+	MD5Engine _md5Engine;
+	SHA2Engine _sha256Engine { SHA2Engine::ALGORITHM::SHA_256 };
+	SHA2Engine _sha512_256Engine { SHA2Engine::ALGORITHM::SHA_512_256 };
+	SHA2Engine _sha512 { SHA2Engine::ALGORITHM::SHA_512 };
+	bool _isSessionAlgorithm;
+};
 
 HTTPDigestCredentials::HTTPDigestCredentials()
 {
@@ -191,11 +253,6 @@ void HTTPDigestCredentials::createAuthParams(const HTTPRequest& request, const H
 	if (!responseAuthParams.has(NONCE_PARAM) || !responseAuthParams.has(REALM_PARAM))
 		throw InvalidArgumentException("Invalid HTTP authentication parameters");
 
-	const std::string& algorithm = responseAuthParams.get(ALGORITHM_PARAM, DEFAULT_ALGORITHM);
-
-	if (icompare(algorithm, DEFAULT_ALGORITHM) != 0)
-		throw NotImplementedException("Unsupported digest algorithm", algorithm);
-
 	const std::string& nonce = responseAuthParams.get(NONCE_PARAM);
 	const std::string& qop = responseAuthParams.get(QOP_PARAM, DEFAULT_QOP);
 	const std::string& realm = responseAuthParams.getRealm();
@@ -208,6 +265,10 @@ void HTTPDigestCredentials::createAuthParams(const HTTPRequest& request, const H
 	{
 		_requestAuthParams.set(OPAQUE_PARAM, responseAuthParams.get(OPAQUE_PARAM));
 	}
+	if (responseAuthParams.has(ALGORITHM_PARAM))
+	{
+		_requestAuthParams.set(ALGORITHM_PARAM, responseAuthParams.get(ALGORITHM_PARAM));
+	}
 
 	if (qop.empty())
 	{
@@ -233,10 +294,8 @@ void HTTPDigestCredentials::createAuthParams(const HTTPRequest& request, const H
 	}
 }
 
-
 void HTTPDigestCredentials::updateAuthParams(const HTTPRequest& request)
 {
-	MD5Engine engine;
 	const std::string qop = _requestAuthParams.get(QOP_PARAM, DEFAULT_QOP);
 	const std::string realm = _requestAuthParams.getRealm();
 	const std::string nonce = _requestAuthParams.get(NONCE_PARAM);
@@ -245,6 +304,11 @@ void HTTPDigestCredentials::updateAuthParams(const HTTPRequest& request)
 
 	if (qop.empty())
 	{
+		/// Assume that https://tools.ietf.org/html/rfc7616 is not supported
+		/// and still using https://tools.ietf.org/html/rfc2069#section-2.4
+
+		MD5Engine engine;
+
 		const std::string ha1 = digest(engine, _username, realm, _password);
 		const std::string ha2 = digest(engine, request.getMethod(), request.getURI());
 
@@ -252,13 +316,28 @@ void HTTPDigestCredentials::updateAuthParams(const HTTPRequest& request)
 	}
 	else if (icompare(qop, AUTH_PARAM) == 0)
 	{
-		const std::string cnonce = _requestAuthParams.get(CNONCE_PARAM);
+		const std::string algorithm = _requestAuthParams.get(ALGORITHM_PARAM, MD_5_ALGORITHM);
 
-		const std::string ha1 = digest(engine, _username, realm, _password);
-		const std::string ha2 = digest(engine, request.getMethod(), request.getURI());
+		if (!isAlgorithmSupported(algorithm)) {
+			throw NotImplementedException("Unsupported digest algorithm", algorithm);
+		}
+
+		const std::string cnonce = _requestAuthParams.get(CNONCE_PARAM);
 		const std::string nc = formatNonceCounter(updateNonceCounter(nonce));
 
+		DigestEngineProvider engineProvider(algorithm);
+		DigestEngine &engine = engineProvider.engine();
+
+		std::string ha1 = digest(engine, _username, realm, _password);
+
+		if (engineProvider.isSessionAlgorithm()) {
+			ha1 = digest(engine, ha1, nonce, cnonce);
+		}
+
+		const std::string ha2 = digest(engine, request.getMethod(), request.getURI());
+
 		_requestAuthParams.set(NC_PARAM, nc);
+		_requestAuthParams.set(CNONCE_PARAM, cnonce);
 		_requestAuthParams.set(RESPONSE_PARAM, digest(engine, ha1, nonce, nc, cnonce, qop, ha2));
 	}
 }
@@ -277,18 +356,34 @@ bool HTTPDigestCredentials::verifyAuthParams(const HTTPRequest& request, const H
 	const std::string& realm = params.getRealm();
 	const std::string& qop   = params.get(QOP_PARAM, DEFAULT_QOP);
 	std::string response;
-	MD5Engine engine;
 	if (qop.empty())
 	{
+		MD5Engine engine;
+
 		const std::string ha1 = digest(engine, _username, realm, _password);
 		const std::string ha2 = digest(engine, request.getMethod(), request.getURI());
 		response = digest(engine, ha1, nonce, ha2);
 	}
 	else if (icompare(qop, AUTH_PARAM) == 0)
 	{
+		const std::string& algorithm = params.get(ALGORITHM_PARAM, MD_5_ALGORITHM);
+
+		if (!isAlgorithmSupported(algorithm)) {
+			throw NotImplementedException("Unsupported digest algorithm", algorithm);
+		}
+
+		DigestEngineProvider engineProvider(algorithm);
+		DigestEngine& engine = engineProvider.engine();
+
 		const std::string& cnonce = params.get(CNONCE_PARAM);
 		const std::string& nc = params.get(NC_PARAM);
-		const std::string ha1 = digest(engine, _username, realm, _password);
+
+		std::string ha1 = digest(engine, _username, realm, _password);
+
+		if (engineProvider.isSessionAlgorithm()) {
+			ha1 = digest(engine, ha1, nonce, cnonce);
+		}
+
 		const std::string ha2 = digest(engine, request.getMethod(), request.getURI());
 		response = digest(engine, ha1, nonce, nc, cnonce, qop, ha2);
 	}
@@ -309,5 +404,16 @@ int HTTPDigestCredentials::updateNonceCounter(const std::string& nonce)
 	return iter->second;
 }
 
+bool HTTPDigestCredentials::isAlgorithmSupported(const std::string& algorithm) const
+{
+	bool isAlgorithmSupported = std::find_if(std::begin(SUPPORTED_ALGORITHMS),
+			std::end(SUPPORTED_ALGORITHMS),
+			[&algorithm](const std::string& supportedAlgorithm)
+	{
+		return icompare(algorithm, supportedAlgorithm) == 0;
+	}) != std::end(SUPPORTED_ALGORITHMS);
+
+	return isAlgorithmSupported;
+}
 
 } } // namespace Poco::Net
