@@ -30,7 +30,7 @@ HostEntry::HostEntry(struct hostent* entry)
 {
 	poco_check_ptr (entry);
 
-	_name = entry->h_name;	
+	_name = entry->h_name;
 	char** alias = entry->h_aliases;
 	if (alias)
 	{
@@ -61,7 +61,7 @@ HostEntry::HostEntry(struct hostent* entry)
 HostEntry::HostEntry(struct addrinfo* ainfo)
 {
 	poco_check_ptr (ainfo);
-	
+
 	for (struct addrinfo* ai = ainfo; ai; ai = ai->ai_next)
 	{
 		if (ai->ai_canonname)
@@ -123,7 +123,7 @@ HostEntry& HostEntry::operator = (const HostEntry& entry)
 }
 
 
-void HostEntry::swap(HostEntry& hostEntry)
+void HostEntry::swap(HostEntry& hostEntry) noexcept
 {
 	std::swap(_name, hostEntry._name);
 	std::swap(_aliases, hostEntry._aliases);
