@@ -49,7 +49,7 @@ RemoteSyslogChannel::RemoteSyslogChannel():
 {
 }
 
-		
+
 RemoteSyslogChannel::RemoteSyslogChannel(const std::string& address, const std::string& name, int facility, bool bsdFormat):
 	_logHost(address),
 	_name(name),
@@ -107,7 +107,7 @@ void RemoteSyslogChannel::open()
 	_open = true;
 }
 
-	
+
 void RemoteSyslogChannel::close()
 {
 	if (_open)
@@ -117,7 +117,7 @@ void RemoteSyslogChannel::close()
 	}
 }
 
-	
+
 void RemoteSyslogChannel::log(const Message& msg)
 {
 	Poco::FastMutex::ScopedLock lock(_mutex);
@@ -163,7 +163,7 @@ void RemoteSyslogChannel::log(const Message& msg)
 	_socket.sendTo(m.data(), static_cast<int>(m.size()), _socketAddress);
 }
 
-	
+
 void RemoteSyslogChannel::setProperty(const std::string& name, const std::string& value)
 {
 	if (name == PROP_NAME)
@@ -176,11 +176,11 @@ void RemoteSyslogChannel::setProperty(const std::string& name, const std::string
 		std::string facility;
 		if (Poco::icompare(value, 4, "LOG_") == 0)
 			facility = Poco::toUpper(value.substr(4));
-		else if (Poco::icompare(value, 4, "SYSLOG_") == 0)
+		else if (Poco::icompare(value, 7, "SYSLOG_") == 0)
 			facility = Poco::toUpper(value.substr(7));
 		else
 			facility = Poco::toUpper(value);
-		
+
 		if (facility == "KERN")
 			_facility = SYSLOG_KERN;
 		else if (facility == "USER")
@@ -252,7 +252,7 @@ void RemoteSyslogChannel::setProperty(const std::string& name, const std::string
 	}
 }
 
-	
+
 std::string RemoteSyslogChannel::getProperty(const std::string& name) const
 {
 	if (name == PROP_NAME)
@@ -362,6 +362,63 @@ int RemoteSyslogChannel::getPrio(const Message& msg)
 	}
 }
 
+const char* RemoteSyslogChannel::facilityToString(const Facility facility)
+{
+	switch(facility)
+	{
+	case RemoteSyslogChannel::SYSLOG_KERN:
+		return "KERN";
+	case RemoteSyslogChannel::SYSLOG_USER:
+		return "USER";
+	case RemoteSyslogChannel::SYSLOG_MAIL:
+		return "MAIL";
+	case RemoteSyslogChannel::SYSLOG_DAEMON:
+		return "DAEMON";
+	case RemoteSyslogChannel::SYSLOG_AUTH:
+		return "AUTH";
+	case RemoteSyslogChannel::SYSLOG_SYSLOG:
+		return "SYSLOG";
+	case RemoteSyslogChannel::SYSLOG_LPR:
+		return "LPR";
+	case RemoteSyslogChannel::SYSLOG_NEWS:
+		return "NEWS";
+	case RemoteSyslogChannel::SYSLOG_UUCP:
+		return "UUCP";
+	case RemoteSyslogChannel::SYSLOG_CRON:
+		return "CRON";
+	case RemoteSyslogChannel::SYSLOG_AUTHPRIV:
+		return "AUTHPRIV";
+	case RemoteSyslogChannel::SYSLOG_FTP:
+		return "FTP";
+	case RemoteSyslogChannel::SYSLOG_NTP:
+		return "NTP";
+	case RemoteSyslogChannel::SYSLOG_LOGAUDIT:
+		return "LOGAUDIT";
+	case RemoteSyslogChannel::SYSLOG_LOGALERT:
+		return "LOGALERT";
+	case RemoteSyslogChannel::SYSLOG_CLOCK:
+		return "CLOCK";
+	case RemoteSyslogChannel::SYSLOG_LOCAL0:
+		return "LOCAL0";
+	case RemoteSyslogChannel::SYSLOG_LOCAL1:
+		return "LOCAL1";
+	case RemoteSyslogChannel::SYSLOG_LOCAL2:
+		return "LOCAL2";
+	case RemoteSyslogChannel::SYSLOG_LOCAL3:
+		return "LOCAL3";
+	case RemoteSyslogChannel::SYSLOG_LOCAL4:
+		return "LOCAL4";
+	case RemoteSyslogChannel::SYSLOG_LOCAL5:
+		return "LOCAL5";
+	case RemoteSyslogChannel::SYSLOG_LOCAL6:
+		return "LOCAL6";
+	case RemoteSyslogChannel::SYSLOG_LOCAL7:
+		return "LOCAL7";
+	default:
+		return "";
+	}
+}
+
 
 void RemoteSyslogChannel::registerChannel()
 {
