@@ -29,14 +29,14 @@ SocketNotification::~SocketNotification()
 {
 }
 
-	
+
 void SocketNotification::setSocket(const Socket& socket)
 {
 	_socket = socket;
 }
 
 
-ReadableNotification::ReadableNotification(SocketReactor* pReactor): 
+ReadableNotification::ReadableNotification(SocketReactor* pReactor):
 	SocketNotification(pReactor)
 {
 }
@@ -47,7 +47,7 @@ ReadableNotification::~ReadableNotification()
 }
 
 
-WritableNotification::WritableNotification(SocketReactor* pReactor): 
+WritableNotification::WritableNotification(SocketReactor* pReactor):
 	SocketNotification(pReactor)
 {
 }
@@ -58,18 +58,30 @@ WritableNotification::~WritableNotification()
 }
 
 
-ErrorNotification::ErrorNotification(SocketReactor* pReactor): 
-	SocketNotification(pReactor)
+ErrorNotification::ErrorNotification(SocketReactor* pReactor, int code, const std::string& description):
+	SocketNotification(pReactor),
+	_code(code),
+	_description(description)
 {
 }
 
 
+ErrorNotification::ErrorNotification(SocketReactor* pReactor, const Socket& socket,
+	int code, const std::string& description):
+	SocketNotification(pReactor),
+	_code(code),
+	_description(description)
+{
+	setSocket(socket);
+}
+
+
 ErrorNotification::~ErrorNotification()
 {
 }
 
 
-TimeoutNotification::TimeoutNotification(SocketReactor* pReactor): 
+TimeoutNotification::TimeoutNotification(SocketReactor* pReactor):
 	SocketNotification(pReactor)
 {
 }
@@ -80,7 +92,7 @@ TimeoutNotification::~TimeoutNotification()
 }
 
 
-IdleNotification::IdleNotification(SocketReactor* pReactor): 
+IdleNotification::IdleNotification(SocketReactor* pReactor):
 	SocketNotification(pReactor)
 {
 }
@@ -91,7 +103,7 @@ IdleNotification::~IdleNotification()
 }
 
 
-ShutdownNotification::ShutdownNotification(SocketReactor* pReactor): 
+ShutdownNotification::ShutdownNotification(SocketReactor* pReactor):
 	SocketNotification(pReactor)
 {
 }
