@@ -51,6 +51,11 @@ StreamSocket::StreamSocket(const Socket& socket): Socket(socket)
 }
 
 
+StreamSocket::StreamSocket(const StreamSocket& socket): Socket(socket)
+{
+}
+
+
 StreamSocket::StreamSocket(SocketImpl* pImpl): Socket(pImpl)
 {
 	if (!dynamic_cast<StreamSocketImpl*>(impl()))
@@ -73,6 +78,50 @@ StreamSocket& StreamSocket::operator = (const Socket& socket)
 }
 
 
+StreamSocket& StreamSocket::operator = (const StreamSocket& socket)
+{
+	Socket::operator = (socket);
+	return *this;
+}
+
+#if POCO_NEW_STATE_ON_MOVE
+
+StreamSocket::StreamSocket(Socket&& socket): Socket(std::move(socket))
+{
+	if (!dynamic_cast<StreamSocketImpl*>(impl()))
+		throw InvalidArgumentException("Cannot assign incompatible socket");
+}
+
+
+StreamSocket::StreamSocket(StreamSocket&& socket): Socket(std::move(socket))
+{
+}
+
+StreamSocket& StreamSocket::operator = (Socket&& socket)
+{
+	Socket::operator = (std::move(socket));
+	return *this;
+}
+
+
+StreamSocket& StreamSocket::operator = (StreamSocket&& socket)
+{
+	Socket::operator = (std::move(socket));
+	return *this;
+}
+
+#endif // POCO_NEW_STATE_ON_MOVE
+
+
+void StreamSocket::bind(const SocketAddress& address, bool reuseAddress, bool ipV6Only)
+{
+	if (address.family() == IPAddress::IPv4)
+		impl()->bind(address, reuseAddress);
+	else
+		impl()->bind6(address, reuseAddress, ipV6Only);
+}
+
+
 void StreamSocket::connect(const SocketAddress& address)
 {
 	impl()->connect(address);
@@ -96,7 +145,7 @@ void StreamSocket::shutdownReceive()
 	impl()->shutdownReceive();
 }
 
-	
+
 void StreamSocket::shutdownSend()
 {
 	impl()->shutdownSend();
@@ -164,5 +213,9 @@ void StreamSocket::sendUrgent(unsigned char data)
 	impl()->sendUrgent(data);
 }
 
+Poco::Int64 StreamSocket::sendFile(FileInputStream &fileInputStream, Poco::UInt64 offset)
+{
+	return impl()->sendFile(fileInputStream, offset);
+}
 
 } } // namespace Poco::Net
