@@ -65,6 +65,30 @@ WebSocket::WebSocket(const Socket& socket):
 }
 
 
+#ifdef POCO_NEW_STATE_ON_MOVE
+
+WebSocket::WebSocket(Socket&& socket):
+	StreamSocket(std::move(socket))
+{
+	if (!dynamic_cast<WebSocketImpl*>(impl()))
+		throw InvalidArgumentException("Cannot assign incompatible socket");
+}
+
+
+WebSocket::WebSocket(WebSocket&& socket):
+	StreamSocket(std::move(socket))
+{
+}
+
+#endif // POCO_NEW_STATE_ON_MOVE
+
+
+WebSocket::WebSocket(const WebSocket& socket):
+	StreamSocket(socket)
+{
+}
+
+
 WebSocket::~WebSocket()
 {
 }
@@ -80,6 +104,34 @@ WebSocket& WebSocket::operator = (const Socket& socket)
 }
 
 
+#ifdef POCO_NEW_STATE_ON_MOVE
+
+WebSocket& WebSocket::operator = (Socket&& socket)
+{
+	if (dynamic_cast<WebSocketImpl*>(socket.impl()))
+		Socket::operator = (std::move(socket));
+	else
+		throw InvalidArgumentException("Cannot assign incompatible socket");
+	return *this;
+}
+
+
+WebSocket& WebSocket::operator = (WebSocket&& socket)
+{
+	Socket::operator = (std::move(socket));
+	return *this;
+}
+
+#endif // POCO_NEW_STATE_ON_MOVE
+
+
+WebSocket& WebSocket::operator = (const WebSocket& socket)
+{
+	Socket::operator = (socket);
+	return *this;
+}
+
+
 void WebSocket::shutdown()
 {
 	shutdown(WS_NORMAL_CLOSE);
