@@ -9,6 +9,7 @@
 
 
 #include "EchoServer.h"
+#include "Poco/Net/ServerSocket.h"
 #include "Poco/Net/StreamSocket.h"
 #include "Poco/Net/SocketAddress.h"
 #include "Poco/Timespan.h"
@@ -42,6 +43,17 @@ EchoServer::EchoServer(const Poco::Net::SocketAddress& address):
 }
 
 
+EchoServer::EchoServer(const Poco::Net::ServerSocket& sock):
+	_socket(sock),
+	_thread("EchoServer"),
+	_stop(false),
+	_done(false)
+{
+	_thread.start(*this);
+	_ready.wait();
+}
+
+
 EchoServer::~EchoServer()
 {
 	_stop = true;
@@ -72,14 +84,21 @@ void EchoServer::run()
 				{
 					ss.sendBytes(buffer, n);
 					n = ss.receiveBytes(buffer, sizeof(buffer));
+					if (n == 0)
+					{
+						_stop = true;
+						break;
+					}
 				}
 			}
 			catch (Poco::Exception& exc)
 			{
 				std::cerr << "EchoServer: " << exc.displayText() << std::endl;
 			}
+			ss.close();
 		}
 	}
+	_socket.close();
 	_done = true;
 }
 
@@ -94,4 +113,3 @@ bool EchoServer::done()
 {
 	return _done;
 }
-
