@@ -25,6 +25,7 @@ public:
 	~HTTPClientSessionTest();
 
 	void testGetSmall();
+	void testGetSmallUnix();
 	void testGetLarge();
 	void testHead();
 	void testPostSmallIdentity();
@@ -34,6 +35,7 @@ public:
 	void testPostSmallClose();
 	void testPostLargeClose();
 	void testKeepAlive();
+	void testTrailer();
 	void testProxy();
 	void testProxyAuth();
 	void testBypassProxy();
