@@ -13,6 +13,7 @@
 #include "HTTPResponseTest.h"
 #include "HTTPCookieTest.h"
 #include "HTTPCredentialsTest.h"
+#include "NTLMCredentialsTest.h"
 
 
 CppUnit::Test* HTTPTestSuite::suite()
@@ -23,6 +24,7 @@ CppUnit::Test* HTTPTestSuite::suite()
 	pSuite->addTest(HTTPResponseTest::suite());
 	pSuite->addTest(HTTPCookieTest::suite());
 	pSuite->addTest(HTTPCredentialsTest::suite());
+	pSuite->addTest(NTLMCredentialsTest::suite());
 
 	return pSuite;
 }
