@@ -12,6 +12,7 @@
 #include "CppUnit/TestCaller.h"
 #include "CppUnit/TestSuite.h"
 #include "Poco/Net/MailMessage.h"
+#include "Poco/Net/MailStream.h"
 #include "Poco/Net/MailRecipient.h"
 #include "Poco/Net/PartHandler.h"
 #include "Poco/Net/StringPartSource.h"
@@ -20,11 +21,16 @@
 #include "Poco/Timestamp.h"
 #include "Poco/FileStream.h"
 #include "Poco/String.h"
+#include "Poco/TemporaryFile.h"
 #include <sstream>
+#include <fstream>
 #include <vector>
+#include <iostream>
 
 
 using Poco::Net::MailMessage;
+using Poco::Net::MailInputStream;
+using Poco::Net::MailOutputStream;
 using Poco::Net::MailRecipient;
 using Poco::Net::MessageHeader;
 using Poco::Net::PartHandler;
@@ -36,6 +42,7 @@ using Poco::Timestamp;
 using Poco::FileInputStream;
 using Poco::replaceInPlace;
 using Poco::icompare;
+using Poco::TemporaryFile;
 
 
 namespace
@@ -46,7 +53,7 @@ namespace
 		StringPartHandler()
 		{
 		}
-		
+
 		void handlePart(const MessageHeader& header, std::istream& stream)
 		{
 			_disp.push_back(header["Content-Disposition"]);
@@ -60,7 +67,7 @@ namespace
 			}
 			_data.push_back(data);
 		}
-		
+
 		const std::vector<std::string>& data() const
 		{
 			return _data;
@@ -75,7 +82,7 @@ namespace
 		{
 			return _type;
 		}
-		
+
 	private:
 		std::vector<std::string> _data;
 		std::vector<std::string> _disp;
@@ -115,14 +122,14 @@ void MailMessageTest::testWriteQP()
 	);
 	Timestamp ts(0);
 	message.setDate(ts);
-	
+
 	assertTrue (!message.isMultipart());
-	
+
 	std::ostringstream str;
 	message.write(str);
 	std::string s = str.str();
 
-	assertTrue (s == 
+	assertTrue (s ==
 		"Date: Thu, 1 Jan 1970 00:00:00 GMT\r\n"
 		"Content-Type: text/plain\r\n"
 		"Subject: Test Message\r\n"
@@ -154,11 +161,11 @@ void MailMessageTest::testWrite8Bit()
 	);
 	Timestamp ts(0);
 	message.setDate(ts);
-	
+
 	std::ostringstream str;
 	message.write(str);
 	std::string s = str.str();
-	assertTrue (s == 
+	assertTrue (s ==
 		"Date: Thu, 1 Jan 1970 00:00:00 GMT\r\n"
 		"Content-Type: text/plain\r\n"
 		"Subject: Test Message\r\n"
@@ -190,7 +197,7 @@ void MailMessageTest::testWriteBase64()
 	std::ostringstream str;
 	message.write(str);
 	std::string s = str.str();
-	assertTrue (s == 
+	assertTrue (s ==
 		"Date: Thu, 1 Jan 1970 00:00:00 GMT\r\n"
 		"Content-Type: text/plain\r\n"
 		"Subject: Test Message\r\n"
@@ -226,11 +233,11 @@ void MailMessageTest::testWriteManyRecipients()
 	);
 	Timestamp ts(0);
 	message.setDate(ts);
-	
+
 	std::ostringstream str;
 	message.write(str);
 	std::string s = str.str();
-	assertTrue (s == 
+	assertTrue (s ==
 		"Date: Thu, 1 Jan 1970 00:00:00 GMT\r\n"
 		"Content-Type: text/plain\r\n"
 		"Subject: Test Message\r\n"
@@ -321,13 +328,13 @@ void MailMessageTest::testReadQP()
 		"his should be enough.\r\n"
 		"And here is some more =3Dfe.\r\n"
 	);
-	
+
 	MailMessage message;
 	message.read(istr);
-	
+
 	assertTrue (message.getSender() == "poco@appinf.com");
 	assertTrue (message.getContentType() == "text/plain");
-	assertTrue (message.getContent() == 
+	assertTrue (message.getContent() ==
 		"Hello, world!\r\n"
 		"This is a test for the MailMessage class.\r\n"
 		"To test the quoted-printable encoding, we'll put an extra long line here. This should be enough.\r\n"
@@ -361,6 +368,55 @@ void MailMessageTest::testReadDefaultTransferEncoding()
 }
 
 
+void MailMessageTest::testContentDisposition()
+{
+	/*
+	// see https://github.com/pocoproject/poco/issues/3650
+	// Note "Content-disposition" casing,
+	// "Content-type" or "Content-transfer-encoding" do not cause problem
+	auto rawMessage =
+		"Date: Wed, 29 Jun 2022 08:25:48 GMT" "\r\n"
+		"Content-Type: multipart/mixed; boundary=MIME_boundary_5DBC66DE2780DE93" "\r\n"
+		"From: mySenderName<sender@send.pl>" "\r\n"
+		"Subject: mySubjct" "\r\n"
+		"To: <aja@o.pl>" "\r\n"
+		"Mime-Version: 1.0" "\r\n"
+		"\r\n"
+		"--MIME_boundary_5DBC66DE2780DE93" "\r\n"
+		"Content-Type: text/plain; charset=UTF-8" "\r\n"
+		"Content-Transfer-Encoding: quoted-printable" "\r\n"
+		"Content-Disposition: inline" "\r\n"
+		"\r\n"
+		"MyRealContent" "\r\n"
+		"--MIME_boundary_5DBC66DE2780DE93" "\r\n"
+		"Content-Type: text/plain; name=Plik" "\r\n"
+		"Content-Transfer-Encoding: base64" "\r\n"
+		"Content-disposition: attachment; filename=attachment.txt" "\r\n"
+		"\r\n"
+		"TXlBdHRhY2htZW50" "\r\n"
+		"--MIME_boundary_5DBC66DE2780DE93--" "\r\n"
+		"." "\r\n";
+
+	Poco::Net::MailMessage  message;
+	//Convert raw message to message
+	std::istringstream is(rawMessage);
+	MailInputStream mis(is);
+	message.read(mis);
+
+	//get raw message again:
+	std::ostringstream oss;
+	MailOutputStream mos(oss);
+	message.write(mos);
+	mos.close();
+	auto plainMessage = oss.str();
+
+	assertEqual(rawMessage, plainMessage);
+
+	//std::cout << plain_message <<std::endl;
+*/
+}
+
+
 void MailMessageTest::testRead8Bit()
 {
 	std::istringstream istr(
@@ -374,13 +430,13 @@ void MailMessageTest::testRead8Bit()
 		"Hello, world!\r\n"
 		"This is a test for the MailMessage class.\r\n"
 	);
-	
+
 	MailMessage message;
 	message.read(istr);
-	
+
 	assertTrue (message.getSender() == "poco@appinf.com");
 	assertTrue (message.getContentType() == "text/plain");
-	assertTrue (message.getContent() == 
+	assertTrue (message.getContent() ==
 		"Hello, world!\r\n"
 		"This is a test for the MailMessage class.\r\n"
 	);
@@ -413,11 +469,11 @@ void MailMessageTest::testReadMultiPart()
 		"VGhpcyBpcyBzb21lIGJpbmFyeSBkYXRhLiBSZWFsbHku\r\n"
 		"--MIME_boundary_01234567--\r\n"
 	);
-	
+
 	StringPartHandler handler;
 	MailMessage message;
 	message.read(istr, handler);
-	
+
 	assertTrue (handler.data().size() == 2);
 	assertTrue (handler.data()[0] == "Hello World!\r\n");
 	assertTrue (handler.type()[0] == "text/plain");
@@ -455,10 +511,10 @@ void MailMessageTest::testReadMultiPartWithAttachmentNames()
 		"VGhpcyBpcyBzb21lIGJpbmFyeSBkYXRhLiBSZWFsbHku\r\n"
 		"--MIME_boundary_01234567--\r\n"
 	);
-	
+
 	MailMessage message;
 	message.read(istr);
-	
+
 	assertTrue (message.parts().size() == 2);
 	assertTrue (message.parts()[1].name == "sample");
 	assertTrue (message.parts()[1].pSource->filename() == "sample.dat");
@@ -506,6 +562,54 @@ void MailMessageTest::testReadMultiPartDefaultTransferEncoding()
 }
 
 
+void MailMessageTest::testReadMultiPartNoFinalBoundaryFromFile()
+{
+	std::string data(
+		"Content-Type: multipart/mixed; boundary=MIME_boundary_01234567\r\n"
+		"Date: Thu, 1 Jan 1970 00:00:00 GMT\r\n"
+		"From: poco@appinf.com\r\n"
+		"Mime-Version: 1.0\r\n"
+		"Subject: Test Message\r\n"
+		"To: John Doe <john.doe@no.where>\r\n"
+		"\r\n"
+		"\r\n"
+		"--MIME_boundary_01234567\r\n"
+		"Content-Disposition: inline\r\n"
+		"Content-Transfer-Encoding: 8bit\r\n"
+		"Content-Type: text/plain\r\n"
+		"\r\n"
+		"Hello World!\r\n"
+		"\r\n"
+		"--MIME_boundary_01234567\r\n"
+		"Content-Disposition: attachment; filename=sample.dat\r\n"
+		"Content-Transfer-Encoding: base64\r\n"
+		"Content-Type: application/octet-stream; name=sample\r\n"
+		"\r\n"
+		"VGhpcyBpcyBzb21lIGJpbmFyeSBkYXRhLiBSZWFsbHku\r\n"
+	);
+
+	// The problem occurs during reading message from file.
+	// (For stringstreams it works fine.)
+	// https://github.com/pocoproject/poco/issues/2401
+	TemporaryFile file;
+	std::ofstream(file.path()) << data;
+	std::ifstream istr(file.path());
+
+	StringPartHandler handler;
+	MailMessage message;
+	message.read(istr, handler);
+
+	assertTrue (handler.data().size() == 2);
+	assertTrue (handler.data()[0] == "Hello World!\r\n");
+	assertTrue (handler.type()[0] == "text/plain");
+	assertTrue (handler.disp()[0] == "inline");
+
+	assertTrue (handler.data()[1] == "This is some binary data. Really.");
+	assertTrue (handler.type()[1] == "application/octet-stream; name=sample");
+	assertTrue (handler.disp()[1] == "attachment; filename=sample.dat");
+}
+
+
 void MailMessageTest::testReadWriteMultiPart()
 {
 	std::string msgin(
@@ -539,7 +643,7 @@ void MailMessageTest::testReadWriteMultiPart()
 
 	message.read(istr);
 	message.write(ostr);
-	
+
 	std::string msgout(ostr.str());
 	assertTrue (msgout == msgin);
 }
@@ -578,7 +682,7 @@ void MailMessageTest::testReadWriteMultiPartStore()
 	MailMessage message(&pfsf);
 
 	message.read(istr);
-	
+
 	MailMessage::PartVec::const_iterator it = message.parts().begin();
 	MailMessage::PartVec::const_iterator end = message.parts().end();
 	for (; it != end; ++it)
@@ -593,7 +697,7 @@ void MailMessageTest::testReadWriteMultiPartStore()
 			// filename is not the same as attachment name
 			std::size_t sz = (path.size() > filename.size()) ? filename.size() : path.size();
 			assertTrue (0 != icompare(path, path.size() - sz, sz, path));
-			
+
 			Poco::FileInputStream fis(path);
 			assertTrue (fis.good());
 			std::string read;
@@ -604,7 +708,7 @@ void MailMessageTest::testReadWriteMultiPartStore()
 			assertTrue (read == "This is some binary data. Really.");
 		}
 	}
-	
+
 	message.write(ostr);
 	std::string msgout(ostr.str());
 	assertTrue (msgout == msgin);
@@ -616,11 +720,11 @@ void MailMessageTest::testEncodeWord()
 	std::string plain("this is pure ASCII");
 	std::string encoded = MailMessage::encodeWord(plain, "ISO-8859-1");
 	assertTrue (encoded == plain);
-	
+
 	plain = "This text contains German Umlauts: \304\326";
 	encoded = MailMessage::encodeWord(plain, "ISO-8859-1");
 	assertTrue (encoded == "=?ISO-8859-1?q?This_text_contains_German_Umlauts=3A_=C4=D6?=");
-	
+
 	plain = "This text contains German Umlauts: \304\326. "
 	        "It is also a very long text. Longer than 75 "
 	        "characters. Long enough to become three lines "
@@ -654,9 +758,11 @@ CppUnit::Test* MailMessageTest::suite()
 	CppUnit_addTest(pSuite, MailMessageTest, testWriteMultiPart);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadQP);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadDefaultTransferEncoding);
+	CppUnit_addTest(pSuite, MailMessageTest, testContentDisposition);
 	CppUnit_addTest(pSuite, MailMessageTest, testRead8Bit);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadMultiPart);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadMultiPartDefaultTransferEncoding);
+	CppUnit_addTest(pSuite, MailMessageTest, testReadMultiPartNoFinalBoundaryFromFile);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadWriteMultiPart);
 	CppUnit_addTest(pSuite, MailMessageTest, testReadWriteMultiPartStore);
 	CppUnit_addTest(pSuite, MailMessageTest, testEncodeWord);
