@@ -10,6 +10,7 @@
 
 #include "ReactorTestSuite.h"
 #include "SocketReactorTest.h"
+#include "SocketConnectorTest.h"
 
 
 CppUnit::Test* ReactorTestSuite::suite()
@@ -17,6 +18,7 @@ CppUnit::Test* ReactorTestSuite::suite()
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("ReactorTestSuite");
 
 	pSuite->addTest(SocketReactorTest::suite());
+	pSuite->addTest(SocketConnectorTest::suite());
 
 	return pSuite;
 }
