@@ -20,6 +20,7 @@
 #include "Poco/Net/ServerSocket.h"
 #include "Poco/Net/SocketAddress.h"
 #include "Poco/Observer.h"
+#include "Poco/Stopwatch.h"
 #include "Poco/Exception.h"
 #include "Poco/Thread.h"
 #include <sstream>
@@ -36,14 +37,20 @@ using Poco::Net::SocketNotification;
 using Poco::Net::ReadableNotification;
 using Poco::Net::WritableNotification;
 using Poco::Net::TimeoutNotification;
+using Poco::Net::ErrorNotification;
 using Poco::Net::ShutdownNotification;
 using Poco::Observer;
+using Poco::Stopwatch;
 using Poco::IllegalStateException;
 using Poco::Thread;
 
 
 namespace
 {
+	int DATA_SIZE = 1024;
+	int REACTORS_COUNT = 8;
+	int MAX_DATA_SIZE = DATA_SIZE * REACTORS_COUNT;
+
 	class EchoServiceHandler
 	{
 	public:
@@ -130,12 +137,18 @@ namespace
 				checkReadableObserverCount(1);
 				_reactor.removeEventHandler(_socket, Observer<ClientServiceHandler, ReadableNotification>(*this, &ClientServiceHandler::onReadable));
 				checkReadableObserverCount(0);
-				if (_once || _data.size() == 8192)
+				if (_once)
 				{
 					_reactor.stop();
 					delete this;
+					return;
 				}
 			}
+			if (_data.size() == MAX_DATA_SIZE)
+			{
+				_reactor.stop();
+				delete this;
+			}
 		}
 
 		void onWritable(WritableNotification* pNf)
@@ -144,7 +157,7 @@ namespace
 			checkWritableObserverCount(1);
 			_reactor.removeEventHandler(_socket, Observer<ClientServiceHandler, WritableNotification>(*this, &ClientServiceHandler::onWritable));
 			checkWritableObserverCount(0);
-			std::string data(1024, 'x');
+			std::string data(DATA_SIZE, 'x');
 			_socket.sendBytes(data.data(), (int) data.length());
 			_socket.shutdownSend();
 		}
@@ -255,7 +268,6 @@ namespace
 		static bool                                          _once;
 	};
 
-
 	std::string ClientServiceHandler::_data;
 	bool ClientServiceHandler::_readableError = false;
 	bool ClientServiceHandler::_writableError = false;
@@ -290,12 +302,6 @@ namespace
 			reactor()->stop();
 		}
 
-		void onError(int error)
-		{
-			_failed = true;
-			reactor()->stop();
-		}
-
 		bool failed() const
 		{
 			return _failed;
@@ -380,6 +386,54 @@ namespace
 	};
 
 	DataServiceHandler::Data DataServiceHandler::_data;
+
+	class SleepClientServiceHandler
+	{
+	public:
+		SleepClientServiceHandler(Poco::Net::StreamSocket& socket, Poco::Net::SocketReactor& reactor)
+		{
+			Poco::Thread::sleep(500);
+		}
+	};
+
+	class DummyServiceHandler
+	{
+	public:
+		DummyServiceHandler(StreamSocket& socket, SocketReactor& reactor) : _socket(socket),
+			_reactor(reactor)
+		{
+			_reactor.addEventHandler(_socket, Observer<DummyServiceHandler, ReadableNotification>(*this, &DummyServiceHandler::onReadable));
+			_reactor.addEventHandler(_socket, Observer<DummyServiceHandler, ShutdownNotification>(*this, &DummyServiceHandler::onShutdown));
+			_socket.setBlocking(false);
+		}
+
+		~DummyServiceHandler()
+		{
+			_reactor.removeEventHandler(_socket, Observer<DummyServiceHandler, ReadableNotification>(*this, &DummyServiceHandler::onReadable));
+			_reactor.removeEventHandler(_socket, Observer<DummyServiceHandler, ShutdownNotification>(*this, &DummyServiceHandler::onShutdown));
+		}
+
+		void onReadable(ReadableNotification* pNf)
+		{
+			pNf->release();
+			char buffer[64];
+			do
+			{
+				if (0 == _socket.receiveBytes(&buffer[0], sizeof(buffer)))
+					break;
+			} while (true);
+		}
+
+		void onShutdown(ShutdownNotification* pNf)
+		{
+			pNf->release();
+			delete this;
+		}
+
+	private:
+		StreamSocket   _socket;
+		SocketReactor& _reactor;
+	};
 }
 
 
@@ -405,7 +459,7 @@ void SocketReactorTest::testSocketReactor()
 	ClientServiceHandler::resetData();
 	reactor.run();
 	std::string data(ClientServiceHandler::data());
-	assertTrue (data.size() == 1024);
+	assertTrue (data.size() == DATA_SIZE);
 	assertTrue (!ClientServiceHandler::readableError());
 	assertTrue (!ClientServiceHandler::writableError());
 	assertTrue (!ClientServiceHandler::timeoutError());
@@ -425,7 +479,7 @@ void SocketReactorTest::testSetSocketReactor()
 	ClientServiceHandler::resetData();
 	reactor.run();
 	std::string data(ClientServiceHandler::data());
-	assertTrue (data.size() == 1024);
+	assertTrue (data.size() == DATA_SIZE);
 	assertTrue (!ClientServiceHandler::readableError());
 	assertTrue (!ClientServiceHandler::writableError());
 	assertTrue (!ClientServiceHandler::timeoutError());
@@ -434,27 +488,26 @@ void SocketReactorTest::testSetSocketReactor()
 
 void SocketReactorTest::testParallelSocketReactor()
 {
-	SocketAddress ssa;
+	SocketAddress ssa("127.0.0.1:22087");
 	ServerSocket ss(ssa);
 	SocketReactor reactor;
-	ParallelSocketAcceptor<EchoServiceHandler, SocketReactor> acceptor(ss, reactor);
+	ParallelSocketAcceptor<EchoServiceHandler, SocketReactor> acceptor(ss, reactor, REACTORS_COUNT);
+
 	SocketAddress sa("127.0.0.1", ss.address().port());
-	SocketConnector<ClientServiceHandler> connector1(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector2(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector3(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector4(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector5(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector6(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector7(sa, reactor);
-	SocketConnector<ClientServiceHandler> connector8(sa, reactor);
+	std::vector<SocketConnector<ClientServiceHandler>*> connectors;
+	for (int i = 0; i < REACTORS_COUNT; ++i)
+		connectors.push_back(new SocketConnector<ClientServiceHandler>(sa, reactor));
+
 	ClientServiceHandler::setOnce(false);
 	ClientServiceHandler::resetData();
 	reactor.run();
+
 	std::string data(ClientServiceHandler::data());
-	assertTrue (data.size() == 8192);
+	assertTrue (data.size() == MAX_DATA_SIZE);
 	assertTrue (!ClientServiceHandler::readableError());
 	assertTrue (!ClientServiceHandler::writableError());
 	assertTrue (!ClientServiceHandler::timeoutError());
+	for (auto& c : connectors) delete c;
 }
 
 
@@ -573,6 +626,63 @@ void SocketReactorTest::testDataCollection()
 }
 
 
+void SocketReactorTest::testSocketConnectorDeadlock()
+{
+	{
+		SocketAddress ssa;
+		ServerSocket ss(ssa);
+		SocketAddress sa("127.0.0.1", ss.address().port());
+		SocketReactor reactor;
+		Thread thread;
+		int i = 0;
+		while (++i < 10)
+		{
+			auto sc = new SocketConnector<SleepClientServiceHandler>(sa, reactor);
+			thread.startFunc([&reactor]() { reactor.run(); });
+			reactor.stop();
+			thread.join();
+			delete sc;
+		}
+	}
+
+	int i = 0;
+	while (++i < 10)
+	{
+		SocketAddress ssa;
+		ServerSocket ss(ssa);
+		SocketReactor reactor;
+		SocketAcceptor<DummyServiceHandler> acceptor(ss, reactor);
+		Thread thread;
+		thread.start(reactor);
+
+		SocketAddress sa("127.0.0.1", ss.address().port());
+		StreamSocket sock(sa);
+
+		std::string data("HELLO");
+		sock.sendBytes(data.data(), static_cast<int>(data.size()));
+		reactor.stop();
+		thread.join();
+	}
+}
+
+
+void SocketReactorTest::testSocketReactorWakeup()
+{
+	SocketReactor::Params params;
+	params.pollTimeout = 1000000000;
+	params.sleepLimit = 1000000000;
+	SocketReactor reactor(params);
+	Thread thread;
+	Stopwatch sw;
+	sw.start();
+	thread.start(reactor);
+	reactor.stop();
+	thread.join();
+	sw.stop();
+	assertTrue (sw.elapsed() < 100000);
+}
+
+
 void SocketReactorTest::setUp()
 {
 	ClientServiceHandler::setCloseOnTimeout(false);
@@ -594,6 +704,8 @@ CppUnit::Test* SocketReactorTest::suite()
 	CppUnit_addTest(pSuite, SocketReactorTest, testSocketConnectorFail);
 	CppUnit_addTest(pSuite, SocketReactorTest, testSocketConnectorTimeout);
 	CppUnit_addTest(pSuite, SocketReactorTest, testDataCollection);
+	CppUnit_addTest(pSuite, SocketReactorTest, testSocketConnectorDeadlock);
+	CppUnit_addTest(pSuite, SocketReactorTest, testSocketReactorWakeup);
 
 	return pSuite;
 }
