@@ -25,8 +25,10 @@ public:
 	~SyslogTest();
 
 	void testListener();
+	void testChannelFacility();
 	void testChannelOpenClose();
 	void testOldBSD();
+	void testStructuredData();
 
 	void setUp();
 	void tearDown();
