@@ -324,6 +324,7 @@ void TCPServerTest::testReuseSession()
 		9,
 		true,
 		"ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
+	pServerContext->disableProtocols(Context::PROTO_TLSV1_3);
 	pServerContext->enableSessionCache(true, "TestSuite");
 	pServerContext->setSessionTimeout(10);
 	pServerContext->setSessionCacheSize(1000);
@@ -363,6 +364,11 @@ void TCPServerTest::testReuseSession()
 	assertTrue (srv.totalConnections() == 1);
 
 	Session::Ptr pSession = ss1.currentSession();
+	if (!pSession || !pSession->isResumable())
+	{
+		std::cerr << "WARNING: Server did not return a session or session is not resumable. Aborting test." << std::endl;
+		return;
+	}
 
 	ss1.close();
 	Thread::sleep(300);
@@ -370,15 +376,15 @@ void TCPServerTest::testReuseSession()
 
 	ss1.useSession(pSession);
 	ss1.connect(sa);
-	assertTrue (ss1.sessionWasReused());
-	assertTrue (ss1.currentSession() == pSession);
 	ss1.sendBytes(data.data(), (int) data.size());
 	n = ss1.receiveBytes(buffer, sizeof(buffer));
+	assertTrue (ss1.sessionWasReused());
 	assertTrue (n > 0);
 	assertTrue (std::string(buffer, n) == data);
 	assertTrue (srv.currentConnections() == 1);
 	assertTrue (srv.queuedConnections() == 0);
 	assertTrue (srv.totalConnections() == 2);
+	pSession = ss1.currentSession();
 	ss1.close();
 	Thread::sleep(300);
 	assertTrue (srv.currentConnections() == 0);
@@ -388,10 +394,9 @@ void TCPServerTest::testReuseSession()
 
 	ss1.useSession(pSession);
 	ss1.connect(sa);
-	assertTrue (!ss1.sessionWasReused());
-	assertTrue (ss1.currentSession() != pSession);
 	ss1.sendBytes(data.data(), (int) data.size());
 	n = ss1.receiveBytes(buffer, sizeof(buffer));
+	assertTrue (!ss1.sessionWasReused());
 	assertTrue (n > 0);
 	assertTrue (std::string(buffer, n) == data);
 	assertTrue (srv.currentConnections() == 1);
