@@ -103,7 +103,7 @@ XMLConfiguration::XMLConfiguration(const Poco::XML::Document* pDocument, char de
 	load(pDocument);
 }
 
-	
+
 XMLConfiguration::XMLConfiguration(const Poco::XML::Node* pNode):
 	_delim('.')
 {
@@ -126,7 +126,7 @@ XMLConfiguration::~XMLConfiguration()
 void XMLConfiguration::load(Poco::XML::InputSource* pInputSource, unsigned long namePoolSize)
 {
 	poco_check_ptr (pInputSource);
-	
+
 	Poco::XML::DOMParser parser(namePoolSize);
 	parser.setFeature(Poco::XML::XMLReader::FEATURE_NAMESPACES, false);
 	parser.setFeature(Poco::XML::DOMParser::FEATURE_FILTER_WHITESPACE, true);
@@ -144,21 +144,23 @@ void XMLConfiguration::load(Poco::XML::InputSource* pInputSource)
 void XMLConfiguration::load(std::istream& istr)
 {
 	Poco::XML::InputSource src(istr);
-	load(&src);	
+	load(&src);
 }
 
 
 void XMLConfiguration::load(const std::string& path)
 {
 	Poco::XML::InputSource src(path);
-	load(&src);	
+	load(&src);
 }
 
-	
+
 void XMLConfiguration::load(const Poco::XML::Document* pDocument)
 {
 	poco_check_ptr (pDocument);
-	
+
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	_pDocument = Poco::XML::AutoPtr<Poco::XML::Document>(const_cast<Poco::XML::Document*>(pDocument), true);
 	_pRoot     = Poco::XML::AutoPtr<Poco::XML::Node>(pDocument->documentElement(), true);
 }
@@ -174,6 +176,8 @@ void XMLConfiguration::load(const Poco::XML::Node* pNode)
 	}
 	else
 	{
+		AbstractConfiguration::ScopedLock lock(*this);
+
 		_pDocument = Poco::XML::AutoPtr<Poco::XML::Document>(pNode->ownerDocument(), true);
 		_pRoot     = Poco::XML::AutoPtr<Poco::XML::Node>(const_cast<Poco::XML::Node*>(pNode), true);
 	}
@@ -182,6 +186,8 @@ void XMLConfiguration::load(const Poco::XML::Node* pNode)
 
 void XMLConfiguration::loadEmpty(const std::string& rootElementName)
 {
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	_pDocument = new Poco::XML::Document;
 	_pRoot     = _pDocument->createElement(rootElementName);
 	_pDocument->appendChild(_pRoot);
@@ -190,6 +196,8 @@ void XMLConfiguration::loadEmpty(const std::string& rootElementName)
 
 void XMLConfiguration::save(const std::string& path) const
 {
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	Poco::XML::DOMWriter writer;
 	writer.setNewLine("\n");
 	writer.setOptions(Poco::XML::XMLWriter::PRETTY_PRINT);
@@ -199,6 +207,8 @@ void XMLConfiguration::save(const std::string& path) const
 
 void XMLConfiguration::save(std::ostream& ostr) const
 {
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	Poco::XML::DOMWriter writer;
 	writer.setNewLine("\n");
 	writer.setOptions(Poco::XML::XMLWriter::PRETTY_PRINT);
@@ -208,12 +218,16 @@ void XMLConfiguration::save(std::ostream& ostr) const
 
 void XMLConfiguration::save(Poco::XML::DOMWriter& writer, const std::string& path) const
 {
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	writer.writeNode(path, _pDocument);
 }
 
 
 void XMLConfiguration::save(Poco::XML::DOMWriter& writer, std::ostream& ostr) const
 {
+	AbstractConfiguration::ScopedLock lock(*this);
+
 	writer.writeNode(ostr, _pDocument);
 }
 
@@ -265,8 +279,8 @@ void XMLConfiguration::setRaw(const std::string& key, const std::string& value)
 void XMLConfiguration::enumerate(const std::string& key, Keys& range) const
 {
 	using Poco::NumberFormatter;
-	
-	std::multiset<std::string> keys;
+
+	std::map<std::string, size_t> keys;
 	const Poco::XML::Node* pNode = findNode(key);
 	if (pNode)
 	{
@@ -276,12 +290,12 @@ void XMLConfiguration::enumerate(const std::string& key, Keys& range) const
 			if (pChild->nodeType() == Poco::XML::Node::ELEMENT_NODE)
 			{
 				const std::string& nodeName = pChild->nodeName();
-				int n = (int) keys.count(nodeName);
-				if (n)
-					range.push_back(nodeName + "[" + NumberFormatter::format(n) + "]");
+				size_t& count = keys[nodeName];
+				if (count)
+					range.push_back(nodeName + "[" + NumberFormatter::format(count) + "]");
 				else
 					range.push_back(nodeName);
-				keys.insert(nodeName);
+				++count;
 			}
 			pChild = pChild->nextSibling();
 		}
@@ -476,4 +490,5 @@ Poco::XML::Node* XMLConfiguration::findAttribute(const std::string& name, Poco::
 
 } } // namespace Poco::Util
 
+
 #endif // POCO_UTIL_NO_XMLCONFIGURATION
