@@ -41,12 +41,12 @@ void TimerTest::testScheduleTimestamp()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	timer.schedule(pTask, time);
 
 	_event.wait();
-	assert (pTask->lastExecution() >= time);
+	assertTrue (pTask->lastExecution() >= time);
 }
 
 
@@ -63,12 +63,12 @@ void TimerTest::testScheduleClock()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	timer.schedule(pTask, clock);
 
 	_event.wait();
-	assert (pTask->lastExecution() >= time);
+	assertTrue (pTask->lastExecution() >= time);
 }
 
 
@@ -80,24 +80,24 @@ void TimerTest::testScheduleInterval()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	timer.schedule(pTask, 500, 500);
 
 	_event.wait();
-	assert (time.elapsed() >= 590000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 590000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1190000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1190000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1790000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1790000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	pTask->cancel();
-	assert (pTask->isCancelled());
+	assertTrue (pTask->isCancelled());
 }
 
 
@@ -109,7 +109,7 @@ void TimerTest::testScheduleIntervalTimestamp()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	Timestamp scheduleTime;
 	scheduleTime += 500 * 1000;
@@ -117,19 +117,19 @@ void TimerTest::testScheduleIntervalTimestamp()
 	timer.schedule(pTask, scheduleTime, 500);
 
 	_event.wait();
-	assert (time.elapsed() >= 590000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 590000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1190000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1190000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1790000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1790000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	pTask->cancel();
-	assert (pTask->isCancelled());
+	assertTrue (pTask->isCancelled());
 }
 
 
@@ -141,7 +141,7 @@ void TimerTest::testScheduleIntervalClock()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	Clock scheduleClock;
 	scheduleClock += 500 * 1000;
@@ -149,19 +149,19 @@ void TimerTest::testScheduleIntervalClock()
 	timer.schedule(pTask, scheduleClock, 500);
 
 	_event.wait();
-	assert (time.elapsed() >= 590000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 590000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1190000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1190000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1790000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1790000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	pTask->cancel();
-	assert (pTask->isCancelled());
+	assertTrue (pTask->isCancelled());
 }
 
 
@@ -173,24 +173,24 @@ void TimerTest::testScheduleAtFixedRate()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	timer.scheduleAtFixedRate(pTask, 500, 500);
 
 	_event.wait();
-	assert (time.elapsed() >= 500000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 500000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1000000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1000000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	_event.wait();
-	assert (time.elapsed() >= 1500000);
-	assert (pTask->lastExecution().elapsed() < 130000);
+	assertTrue (time.elapsed() >= 1500000);
+	assertTrue (pTask->lastExecution().elapsed() < 130000);
 
 	pTask->cancel();
-	assert (pTask->isCancelled());
+	assertTrue (pTask->isCancelled());
 }
 
 
@@ -202,12 +202,12 @@ void TimerTest::testCancel()
 
 	TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-	assert (pTask->lastExecution() == 0);
+	assertTrue (pTask->lastExecution() == 0);
 
 	timer.scheduleAtFixedRate(pTask, 5000, 5000);
 
 	pTask->cancel();
-	assert (pTask->isCancelled());
+	assertTrue (pTask->isCancelled());
 
 	try
 	{
@@ -231,14 +231,19 @@ void TimerTest::testCancelAllStop()
 
 		TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-		timer.scheduleAtFixedRate(pTask, 5000, 5000);
-
-		Poco::Thread::sleep(100);
+		// We are scheduling a timer event in 100ms
+		Timestamp time;
+		time += 100000;
+		timer.schedule(pTask, time);
 
 		timer.cancel(false);
+		// Timer should fire in 100ms and onTimer has 100ms sleep in it.
+		// So we are waiting 2 times that plus a small buffer that to make sure that event was never executed.
+		bool timerExecuted = _event.tryWait(200 + 50);
+		assertFalse (timerExecuted);
 	}
 
-	assert (true); // don't hang
+	assertTrue (true); // don't hang
 }
 
 
@@ -249,14 +254,63 @@ void TimerTest::testCancelAllWaitStop()
 
 		TimerTask::Ptr pTask = new TimerTaskAdapter<TimerTest>(*this, &TimerTest::onTimer);
 
-		timer.scheduleAtFixedRate(pTask, 5000, 5000);
-
-		Poco::Thread::sleep(100);
+		// We are scheduling a timer event in 100ms
+		Timestamp time;
+		time += 100000;
+		timer.schedule(pTask, time);
 
 		timer.cancel(true);
+		// Timer should fire in 100ms and onTimer has 100ms sleep in it.
+		// So we are waiting 2 times that plus a small buffer that to make sure that event was never executed.
+		bool timerExecuted = _event.tryWait(200 + 50);
+		assertFalse (timerExecuted);
 	}
 
-	assert (true); // don't hang
+	assertTrue (true); // don't hang
+}
+
+
+void TimerTest::testMultiCancelAllWaitStop()
+{
+	Timer timer;
+
+	// We will schedule a task and wait for it to start.
+	// After that we will schedule 2 cancel Notifications, one async and the other sync.
+	// But we want to make sure that both are scheduled and present in internal queue, thus we need to wait for this
+	// first task to start.
+	Poco::Event startEvent;
+	Poco::Event canceledScheduledEvent;
+	timer.schedule(Timer::func([&startEvent, &canceledScheduledEvent]()
+	{
+		startEvent.set();
+		canceledScheduledEvent.wait();
+		Poco::Thread::sleep(100);
+	}), Poco::Clock());
+	// We wait for simple task to start.
+	startEvent.wait();
+	// Schedule async cancel notification.
+	timer.cancel();
+	// Now allow simple task to proceed to sleep, in other words give time for next cancel to block.
+	canceledScheduledEvent.set();
+	// Schedule sync cancel, now we should have 2 cancel notifications in internal queue.
+	timer.cancel(true);
+
+	assertTrue (true); // don't hang
+}
+
+
+void TimerTest::testFunc()
+{
+	Timer timer;
+
+	std::atomic<int> count(0);
+	timer.schedule(Timer::func([&count]()
+	{
+		count++;
+	}), Poco::Clock());
+	Poco::Thread::sleep(100);
+
+	assertTrue (count == 1);
 }
 
 
@@ -290,6 +344,8 @@ CppUnit::Test* TimerTest::suite()
 	CppUnit_addTest(pSuite, TimerTest, testCancel);
 	CppUnit_addTest(pSuite, TimerTest, testCancelAllStop);
 	CppUnit_addTest(pSuite, TimerTest, testCancelAllWaitStop);
+	CppUnit_addTest(pSuite, TimerTest, testMultiCancelAllWaitStop);
+	CppUnit_addTest(pSuite, TimerTest, testFunc);
 
 	return pSuite;
 }
